@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -47,8 +47,8 @@ from beartype.roar import BeartypeCallUnavailableTypeException
 from beartype._cave._caveabc import BoolType
 from beartype._util.py.utilpyversion import (
     IS_PYTHON_AT_LEAST_3_12,
+    IS_PYTHON_AT_LEAST_3_11,
     IS_PYTHON_AT_LEAST_3_10,
-    IS_PYTHON_AT_LEAST_3_9,
 )
 from collections import deque as _deque
 from collections.abc import (
@@ -607,36 +607,10 @@ else:
     strings).
     '''
 
-# ....................{ TYPES ~ kind : concrete            }....................
-# Temporary dictionary to be deleted below.
-_dict: dict = {}
+# ....................{ TYPES ~ container : abc            }....................
+#FIXME: Extremely silly, honestly. Just use "collections.abc" directly. This is
+#an obvious facepalm. We sigh. *sigh*
 
-
-DictItemsViewType: type = type(_dict.items())
-'''
-Type of all **dictionary items views** (i.e., objects created and returned by
-the :meth:`dict.items` method).
-'''
-
-
-DictKeysViewType: type = type(_dict.keys())
-'''
-Type of all **dictionary keys views** (i.e., objects created and returned by the
-:meth:`dict.keys` method).
-'''
-
-
-DictValuesViewType: type = type(_dict.values())
-'''
-Type of all **dictionary values views** (i.e., objects created and returned by
-the :meth:`dict.values` method).
-'''
-
-
-# Delete the dictionary defined above for negligible space gains.
-del _dict
-
-# ....................{ TYPES ~ kind : abc                 }....................
 ContainerType = _Container
 '''
 Type of all **containers** (i.e., concrete instances of the abstract
@@ -792,7 +766,7 @@ See Also
     Further details on structural subtyping.
 '''
 
-# ....................{ TYPES ~ kind : abc : mapping       }....................
+# ....................{ TYPES ~ container : abc : mapping  }....................
 HashableType = _Hashable
 '''
 Type of all **hashable objects** (i.e., both concrete and structural instances
@@ -927,6 +901,35 @@ See Also
     Further details on sequences.
 '''
 
+# ....................{ TYPES ~ container : dict           }....................
+# Temporary dictionary to be deleted below.
+_dict: dict = {}
+
+
+DictItemsViewType: type = type(_dict.items())
+'''
+Type of all **dictionary items views** (i.e., objects created and returned by
+the :meth:`dict.items` method).
+'''
+
+
+DictKeysViewType: type = type(_dict.keys())
+'''
+Type of all **dictionary keys views** (i.e., objects created and returned by the
+:meth:`dict.keys` method).
+'''
+
+
+DictValuesViewType: type = type(_dict.values())
+'''
+Type of all **dictionary values views** (i.e., objects created and returned by
+the :meth:`dict.values` method).
+'''
+
+
+# Delete the dictionary defined above for negligible space gains.
+del _dict
+
 # ....................{ TYPES ~ enum                       }....................
 # Enumeration types are sufficiently obscure to warrant formalization here.
 
@@ -999,35 +1002,25 @@ that enumeration's type and should be directly referenced as such: e.g.,
 # type-checker, ignore false positives complaining that this type is not a type.
 # Notably, mypy inexplicably refuses to accept this by emitting "errors"
 # resembling the following wherever this type is accessed:
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695Type" is not valid as a type [valid-type]
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+#     beartype._util.hint.pep.proposal.pep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695TypeAlias" is not valid as a type [valid-type]
+#     beartype._util.hint.pep.proposal.pep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
 if TYPE_CHECKING:
     class HintGenericSubscriptedType(object): pass
 # Else, this submodule is *NOT* currently being statically type-checked by a
 # pure static type-checker. In this case, define this type properly. *sigh*
 else:
-    # Define this type as either...
-    HintGenericSubscriptedType: type = (
-        # If the active Python interpreter targets at least Python >= 3.9 and thus
-        # supports PEP 585, this type;
-        type(list[str])  # type: ignore[misc]
-        if IS_PYTHON_AT_LEAST_3_9 else
-        # Else, a placeholder type.
-        UnavailableType
-    )
+    HintGenericSubscriptedType: type = type(list[str])  # type: ignore[misc]
     '''
-    C-based type of all subscripted generics if the active Python interpreter
-    targets Python >= 3.9 *or* :class:`.UnavailableType` otherwise.
+    C-based type of all subscripted generics.
 
     This type is a version-agnostic generalization of the standard
-    :class:`types.GenericAlias` type available only under Python >= 3.9. Subscripted
-    generics include:
+    :class:`types.GenericAlias` type. Subscripted generics include:
 
     * :pep:`585`-compliant **builtin type hints** (i.e., C-based type hints
-      instantiated by subscripting either a concrete builtin container class like
-      :class:`list` or :class:`tuple` *or* an abstract base class (ABC) declared by
-      the :mod:`collections.abc` submodule like :class:`collections.abc.Iterable`
-      or :class:`collections.abc.Sequence`).
+      instantiated by subscripting either a concrete builtin container class
+      like :class:`list` or :class:`tuple` *or* an abstract base class (ABC)
+      declared by the :mod:`collections.abc` submodule like
+      :class:`collections.abc.Iterable` or :class:`collections.abc.Sequence`).
     * :pep:`484`-compliant **subscripted generics** (i.e., user-defined classes
       subclassing one or more :pep:`484`-compliant type hints subsequently
       subscripted by one or more PEP-compliant type hints).
@@ -1037,17 +1030,17 @@ else:
 
     Caveats
     -------
-    **This low-level type ambiguously matches semantically unrelated PEP-compliant
-    type hints,** rendering this type all but useless for most practical purposes.
-    To distinguish between the various semantic types of hints ambiguously matched
-    by this type, higher-level PEP-specific functions *must* be called instead.
-    These include:
+    **This low-level type ambiguously matches semantically unrelated
+    PEP-compliant type hints,** rendering this type all but useless for most
+    practical purposes. To distinguish between the various semantic types of
+    hints ambiguously matched by this type, higher-level PEP-specific functions
+    *must* be called instead. These include:
 
-    * :func:`beartype._util.hint.pep.proposal.pep484.utilpep484.is_hint_pep484_generic`,
+    * :func:`beartype._util.hint.pep.proposal.pep484.pep484.is_hint_pep484_generic`,
       detecting :pep:`484`-compliant generic type hints.
-    * :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_builtin_subscripted`,
+    * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_builtin_subscripted`,
       detecting :pep:`585`-compliant builtin type hints.
-    * :func:`beartype._util.hint.pep.proposal.utilpep585.is_hint_pep585_generic`,
+    * :func:`beartype._util.hint.pep.proposal.pep585.is_hint_pep585_generic`,
       detecting :pep:`585`-compliant generic type hints.
     '''
 
@@ -1162,20 +1155,55 @@ objects annotating variadic parameters with syntax resembling
 :obj:`typing.ParamSpec` parent object).
 '''
 
+# ....................{ TYPES ~ hint : pep : 646           }....................
+# If this submodule is currently being statically type-checked by a pure static
+# type-checker, ignore false positives complaining that these types are not
+# types.
+if TYPE_CHECKING:
+    class HintPep646TypeVarTupleType(object): pass
+# Else, this submodule is *NOT* currently being statically type-checked by a
+# pure static type-checker.
+#
+# If the active Python interpreter targets at least Python >= 3.11 and thus
+# supports PEP 646, define these types properly. *sigh*
+elif IS_PYTHON_AT_LEAST_3_11:
+    HintPep646TypeVarTupleType = _typing.TypeVarTuple
+    '''
+    C-based type of all :pep:`646`-compliant **type variable tuples** (i.e.,
+    low-level C-based :obj:`typing.TypeVarTuple` objects) if the active Python
+    interpreter targets Python >= 3.11 *or* :class:`.UnavailableType` otherwise.
+
+    This type is a version-agnostic generalization of the standard
+    :class:`typing.TypeVarTuple` type available only under Python >= 3.11.
+    '''
+# Else, the active Python interpreter targets Python < 3.11 and thus fails to
+# support PEP 646. In this case, define these types as placeholders. *sigh*
+else:
+    HintPep646TypeVarTupleType = UnavailableType
+
+
+TypeParamTypes = (
+    _typing.TypeVar, HintPep612ParamSpecType, HintPep646TypeVarTupleType)
+'''
+Tuple of all **type parameters types** (i.e., types of :pep:`484`-compliant type
+variables, pep:`612`-compliant parameter specifications, and
+:pep:`646`-compliant type variable tuples).
+'''
+
 # ....................{ TYPES ~ hint : pep : 695           }....................
 # If this submodule is currently being statically type-checked by a pure static
 # type-checker, ignore false positives complaining that this type is not a type.
 # Notably, mypy inexplicably refuses to accept this by emitting "errors"
 # resembling the following wherever this type is accessed:
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695Type" is not valid as a type [valid-type]
-#     beartype/_util/hint/pep/proposal/utilpep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
+#     beartype._util.hint.pep.proposal.pep695.py:120: error: Variable "beartype._cave._cavefast.HintPep695TypeAlias" is not valid as a type [valid-type]
+#     beartype._util.hint.pep.proposal.pep695.py:120: note: See https://mypy.readthedocs.io/en/stable/common_issues.html#variables-vs-type-aliases
 if TYPE_CHECKING:
-    class HintPep695Type(object): pass
+    class HintPep695TypeAlias(object): pass
 # Else, this submodule is *NOT* currently being statically type-checked by a
 # pure static type-checker. In this case, define this type properly. *sigh*
 else:
     # Define this type as either...
-    HintPep695Type = (
+    HintPep695TypeAlias = (
         # If the active Python interpreter targets at least Python >= 3.12 and
         # thus supports PEP 695, this type;
         _typing.TypeAliasType
@@ -1193,6 +1221,21 @@ else:
     :class:`typing.TypeAliasType` type available only under Python >= 3.12.
     '''
 
+
+Pep695ParameterizableTypes = (type, FunctionType, HintPep695TypeAlias)
+'''
+Tuple of all :pep:`695`-compliant **parameterizable types** (i.e., types of
+objects that may be parametrized by :pep:`695`-compliant lists of one or more
+implicitly instantiated :pep:`484`-compliant type variables, pep:`612`-compliant
+parameter specifications, or :pep:`646`-compliant type variable tuples).
+
+Specifically, this tuple matches:
+
+* *Any* pure-Python class.
+* *Any* pure-Python function.
+* *Any* :pep:`695`-compliant type alias.
+'''
+
 # ....................{ TYPES ~ scalar                     }....................
 StrType = str    # Well, isn't that special.
 '''
@@ -1441,15 +1484,27 @@ classes) are *not* callable and thus intentionally excluded.
 '''
 
 
+MethodDecoratorClassOrStaticTypes = (
+    MethodDecoratorClassType,
+    MethodDecoratorStaticType,
+)
+'''
+Tuple of all **C-based unbound class or static method decorator types** (i.e.,
+builtin :class:`classmethod` or :class:`staticmethod` decorator types
+implemented in low-level C whose instances are typically uncallable, associated
+with callable methods implemented in pure Python).
+'''
+
+
 MethodDecoratorBuiltinTypes = (
     MethodDecoratorClassType,
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
 '''
-Tuple of all **C-based unbound method decorator types** (i.e., builtin decorator
-types implemented in low-level C whose instances are typically uncallable,
-associated with callable methods implemented in pure Python).
+Tuple of all **builtin unbound method decorator types** (i.e., C-based decorator
+types builtin to Python whose instances are typically uncallable but encapsulate
+callable pure-Python methods).
 '''
 
 
@@ -1588,24 +1643,7 @@ callables implemented in pure Python whose declaration is preceded by the
 ``async`` keyword).
 '''
 
-# ....................{ TUPLES ~ scalar                    }....................
-BoolOrNumberTypes = (BoolType, NumberType,)
-'''
-Tuple of all **boolean** and **number types** (i.e., classes whose instances
-are either numbers or types trivially convertible into numbers).
-
-This tuple matches booleans, integers, rational numbers, irrational numbers,
-real numbers, and complex numbers.
-
-Booleans are trivially convertible into integers. While details differ by
-implementation, common implementations in lower-level languages (e.g., C, C++,
-Perl) typically implicitly convert:
-
-* ``False`` to ``0`` and vice versa.
-* ``True`` to ``1`` and vice versa.
-'''
-
-# ....................{ TUPLES ~ post-init : container     }....................
+# ....................{ TUPLES ~ container : abc           }....................
 # Tuples of types assuming the above initialization to have been performed.
 
 MappingOrSequenceTypes = (MappingType, SequenceType)
@@ -1639,7 +1677,24 @@ Tuple of all numeric types *and* all container base classes conforming to (but
 API.
 '''
 
-# ....................{ TUPLES ~ post-init : scalar        }....................
+# ....................{ TUPLES ~ scalar                    }....................
+BoolOrNumberTypes = (BoolType, NumberType,)
+'''
+Tuple of all **boolean** and **number types** (i.e., classes whose instances
+are either numbers or types trivially convertible into numbers).
+
+This tuple matches booleans, integers, rational numbers, irrational numbers,
+real numbers, and complex numbers.
+
+Booleans are trivially convertible into integers. While details differ by
+implementation, common implementations in lower-level languages (e.g., C, C++,
+Perl) typically implicitly convert:
+
+* ``False`` to ``0`` and vice versa.
+* ``True`` to ``1`` and vice versa.
+'''
+
+
 ScalarTypes = BoolOrNumberTypes + (StrType,)
 '''
 Tuple of all **scalar types** (i.e., classes whose instances are atomic scalar
@@ -1652,7 +1707,7 @@ This tuple matches all:
 * **Textual types** (i.e., types contained in the :class:`StrTypes` tuple).
 '''
 
-# ....................{ TUPLES ~ stdlib                    }....................
+
 RegexTypes = (RegexCompiledType, StrType)
 '''
 Tuple of all **regular expression-like types** (i.e., types either defining
