@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -14,6 +14,7 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.typing import (
+    Any,
     Callable,
     Optional,
 )
@@ -28,12 +29,17 @@ from beartype._check.checkmagic import (
     CODE_PITH_ROOT_NAME_PLACEHOLDER,
     FUNC_CHECKER_NAME_PREFIX,
 )
-from beartype._check.convert.convsanify import sanify_hint_root_statement
+from beartype._check.convert.convsanify import (
+    sanify_hint_root_statement)
 from beartype._check.code.codemake import make_check_expr
 from beartype._check.error.errget import (
     get_func_pith_violation,
     get_hint_object_violation,
 )
+from beartype._check.metadata.metasane import (
+    HintOrSanifiedData,
+    # get_hint_or_sane_hint,
+)
 from beartype._check.signature.sigmake import make_func_signature
 from beartype._check._checksnip import (
     CODE_CHECKER_SIGNATURE,
@@ -51,6 +57,7 @@ from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._conf.conftest import die_unless_conf
 from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN_REPR
+from beartype._data.hint.datahintpep import Hint
 from beartype._data.hint.datahinttyping import (
     CallableRaiser,
     CallableRaiserOrTester,
@@ -63,9 +70,8 @@ from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.error.utilerrraise import reraise_exception_placeholder
 from beartype._util.error.utilerrwarn import reissue_warnings_placeholder
 from beartype._util.func.utilfuncmake import make_func
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585ref import (
+from beartype._util.hint.pep.proposal.pep484585.pep484585ref import (
     get_hint_pep484585_ref_names_relative_to)
-from beartype._util.hint.utilhinttest import is_hint_ignorable
 from itertools import count
 from warnings import (
     catch_warnings,
@@ -80,7 +86,7 @@ def make_func_raiser(
     # rather than by keyword. Care should be taken when refactoring parameters,
     # particularly with respect to parameter position.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    hint: object,
+    hint: Hint,
     conf: BeartypeConf,
     exception_prefix: str,
 ) -> CallableRaiser:
@@ -91,6 +97,9 @@ def make_func_raiser(
     this factory and either raising an exception or emitting a warning when that
     object violates that hint).
 
+    This factory underlies the public :func:`beartype.door.die_if_unbearable`
+    type-checking raiser function.
+
     This factory is memoized for efficiency.
 
     Caveats
@@ -101,7 +110,7 @@ def make_func_raiser(
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -139,7 +148,7 @@ def make_func_tester(
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
     # Mandatory parameters.
-    hint: object,
+    hint: Hint,
 
     # Optional parameters.
     conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
@@ -151,11 +160,14 @@ def make_func_tester(
     arbitrary object passed to that tester satisfies the type hint passed to
     this factory and returning that result as its boolean return).
 
+    This factory underlies the public :func:`beartype.door.is_bearable`
+    type-checking tester function.
+
     This factory is memoized for efficiency.
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be type-checked.
     conf : BeartypeConf, optional
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -182,10 +194,118 @@ def make_func_tester(
     )
 
 # ....................{ FACTORIES ~ code                   }....................
+#FIXME: Unit test us up, please.
+@callable_cached
+def make_code_raiser_hint_object_check(
+    hint_or_sane: HintOrSanifiedData,
+    hint_insane: Hint,
+    conf: BeartypeConf,
+    exception_prefix: str,
+) -> CodeGenerated:
+    '''
+    Pure-Python code snippet of a type-checking raiser function type-checking an
+    arbitrary object against the passed type hint under the passed beartype
+    configuration by either raising a fatal exception *or* emitting a non-fatal
+    warning when that object violates this hint.
+
+    This factory underlies the public :func:`beartype.door.die_if_unbearable`
+    type-checking raiser function.
+
+    This factory is memoized for efficiency.
+
+    Parameters
+    ----------
+    hint_or_sane : HintOrSanifiedData
+        Either a type hint *or* **sanified type hint metadata** (i.e.,
+        :data:`.HintSanifiedData` object) to be type-checked.
+    hint_insane : Hint
+        **Insane** (i.e., pre-sanified) type hint to be type-checked.
+    conf : BeartypeConf
+        **Beartype configuration** (i.e., self-caching dataclass encapsulating
+        all settings configuring type-checking for the passed object).
+    exception_prefix : str
+        Human-readable label prefixing the representation of this object in the
+        exception message.
+
+    Returns
+    -------
+    CodeGenerated
+        Tuple containing the Python code snippet dynamically generated by this
+        code factory and metadata describing that code. See the
+        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
+
+    See Also
+    --------
+    :func:`.make_check_expr`
+        Further details.
+    '''
+
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+    # CAUTION: Synchronize with the make_code_raiser_func_pith_check() factory.
+    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+
+    # Python code snippet comprising a single boolean expression type-checking
+    # an arbitrary object against this hint.
+    (
+        code_expr,
+        func_scope,
+        hint_refs_type_basename,
+    ) = make_check_expr(hint_or_sane, conf)
+
+    # Code snippet passing the value of the random integer previously generated
+    # for the current call to the exception-handling function call embedded in
+    # the "CODE_HINT_ROOT_SUFFIX" snippet, defaulting to *NOT* passing this.
+    arg_random_int = (
+        CODE_GET_VIOLATION_RANDOM_INT
+        if ARG_NAME_GETRANDBITS in func_scope else
+        ''
+    )
+
+    # Pass hidden parameters to this raiser function exposing:
+    # * The passed exception prefix accessed by this snippet.
+    # * The get_hint_object_violation() getter called by the
+    #   "CODE_GET_HINT_OBJECT_VIOLATION" snippet.
+    # * The passed *INSANE* type hint accessed by this snippet. Why insane?
+    #   Because the mere act of sanifying this hint typically reduces this hint
+    #   from having a terse readable to verbose unreadable representation in
+    #   violation messages raised by this raiser function. An insane hint is
+    #   preferable for the purposes of generating readable violations.
+    func_scope[ARG_NAME_EXCEPTION_PREFIX] = exception_prefix
+    func_scope[ARG_NAME_GET_VIOLATION] = get_hint_object_violation
+    func_scope[ARG_NAME_HINT] = hint_insane
+
+    # Code snippet generating a human-readable violation exception or warning
+    # when the root pith violates the root type hint.
+    code_get_violation = CODE_GET_HINT_OBJECT_VIOLATION.format(
+        arg_random_int=arg_random_int)
+
+    # Code snippet handling the previously generated violation by either raising
+    # that violation as a fatal exception or emitting that violation as a
+    # non-fatal warning.
+    code_handle_violation = _make_code_raiser_violation(
+        conf=conf, func_scope=func_scope, is_param=None)
+
+    # Code snippet type-checking the root pith against the root hint.
+    func_code = (
+        f'{CODE_RAISER_HINT_OBJECT_CHECK_PREFIX}'
+        f'{code_expr}'
+        f'{code_get_violation}'
+        f'{code_handle_violation}'
+    )
+
+    # Return all metadata required by higher-level callers.
+    return (
+        func_code,
+        func_scope,
+        hint_refs_type_basename,
+    )
+
+
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_tester_check(
-    hint: object,
+    hint_or_sane: HintOrSanifiedData,
+    hint_insane: Hint,
     conf: BeartypeConf,
     exception_prefix : str,
 ) -> CodeGenerated:
@@ -194,12 +314,19 @@ def make_code_tester_check(
     arbitrary object against the passed type hint under the passed beartype
     configuration by returning whether that object satisfies this hint or not.
 
+    This factory underlies the public :func:`beartype.door.is_bearable`
+    type-checking tester function.
+
     This factory is memoized for efficiency.
 
     Parameters
     ----------
-    hint : object
-        Type hint to be type-checked.
+    hint_or_sane : HintOrSanifiedData
+        Either a type hint *or* **sanified type hint metadata** (i.e.,
+        :data:`.HintSanifiedData` object) to be type-checked.
+    hint_insane : Hint
+        **Insane** (i.e., pre-sanified) type hint to be type-checked. Although
+        this factory ignores this hint, alternate factories require this hint.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
@@ -226,7 +353,7 @@ def make_code_tester_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint, conf)
+    ) = make_check_expr(hint_or_sane, conf)
 
     # Code snippet type-checking the root pith against the root hint.
     func_code = f'{CODE_TESTER_CHECK_PREFIX}{code_expr}'
@@ -242,7 +369,7 @@ def make_code_tester_check(
 #FIXME: Unit test us up, please.
 @callable_cached
 def make_code_raiser_func_pith_check(
-    hint: object,
+    hint_or_sane: HintOrSanifiedData,
     conf: BeartypeConf,
     cls_stack: Optional[TypeStack],
     is_param: Optional[bool],
@@ -258,8 +385,11 @@ def make_code_raiser_func_pith_check(
 
     Parameters
     ----------
-    hint : object
-        Type hint to be type-checked.
+    hint_or_sane : HintOrSanifiedData
+        Either a sanified type hint *or* **sanified type hint metadata** (i.e.,
+        :data:`.HintSanifiedData` object) to be type-checked.
+    hint_insane : Hint
+        **Insane** (i.e., pre-sanified) type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all settings configuring type-checking for the passed object).
@@ -275,10 +405,12 @@ def make_code_raiser_func_pith_check(
         If the code snippet generated and returned by this factory is
         type-checking a previously localized:
 
-        * Parameter of a decorated callable, :data:`True`.
-        * Return of a decorated callable, :data:`False`.
+        * Parameter of a decorated callable, this parameter should be
+          :data:`True`.
+        * Return of a decorated callable, this parameter should be
+          :data:`False`.
         * Arbitrary object passed to the :func:`beartype.door.die_if_unbearable`
-          type-checker, :data:`None`.
+          type-checker,  this parameter should be :data:`None`.
 
         Defaults to :data:`None`.
 
@@ -305,7 +437,7 @@ def make_code_raiser_func_pith_check(
         code_expr,
         func_scope,
         hint_refs_type_basename,
-    ) = make_check_expr(hint, conf, cls_stack)
+    ) = make_check_expr(hint_or_sane, conf, cls_stack)
 
     # Code snippet passing the value of the random integer previously generated
     # for the current call to the exception-handling function call embedded in
@@ -321,6 +453,8 @@ def make_code_raiser_func_pith_check(
     # parameter passed to this wrapper function.
     func_scope[ARG_NAME_GET_VIOLATION] = get_func_pith_violation
 
+    #FIXME: [SPEED] Globalize CODE_GET_FUNC_PITH_VIOLATION.format() as
+    #"CODE_GET_FUNC_PITH_VIOLATION_format". *sigh*
     # Code snippet generating a human-readable violation exception or warning
     # when the root pith violates the root type hint.
     code_get_violation = CODE_GET_FUNC_PITH_VIOLATION.format(
@@ -407,102 +541,6 @@ def make_code_raiser_func_pep484_noreturn_check(
         (),  # Irrelevant "hint_refs_type_basename" tuple item. Chug it!
     )
 
-
-#FIXME: Unit test us up, please.
-@callable_cached
-def make_code_raiser_hint_object_check(
-    hint: object,
-    conf: BeartypeConf,
-    exception_prefix: str,
-) -> CodeGenerated:
-    '''
-    Pure-Python code snippet of a type-checking raiser function type-checking an
-    arbitrary object against the passed type hint under the passed beartype
-    configuration by either raising a fatal exception *or* emitting a non-fatal
-    warning when that object violates this hint.
-
-    This factory is memoized for efficiency.
-
-    Parameters
-    ----------
-    hint : object
-        Type hint to be type-checked.
-    conf : BeartypeConf
-        **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all settings configuring type-checking for the passed object).
-    exception_prefix : str
-        Human-readable label prefixing the representation of this object in the
-        exception message.
-
-    Returns
-    -------
-    CodeGenerated
-        Tuple containing the Python code snippet dynamically generated by this
-        code factory and metadata describing that code. See the
-        :attr:`beartype._data.hint.datahinttyping.CodeGenerated` type hint.
-
-    See Also
-    --------
-    :func:`.make_check_expr`
-        Further details.
-    '''
-
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # CAUTION: Synchronize with the make_code_raiser_func_pith_check() factory.
-    #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-
-    # Python code snippet comprising a single boolean expression type-checking
-    # an arbitrary object against this hint.
-    (
-        code_expr,
-        func_scope,
-        hint_refs_type_basename,
-    ) = make_check_expr(hint, conf)
-
-    # Code snippet passing the value of the random integer previously generated
-    # for the current call to the exception-handling function call embedded in
-    # the "CODE_HINT_ROOT_SUFFIX" snippet, defaulting to *NOT* passing this.
-    arg_random_int = (
-        CODE_GET_VIOLATION_RANDOM_INT
-        if ARG_NAME_GETRANDBITS in func_scope else
-        ''
-    )
-
-    # Pass hidden parameters to this raiser function exposing:
-    # * The passed exception prefix accessed by this snippet.
-    # * The get_hint_object_violation() getter called by the
-    #   "CODE_GET_HINT_OBJECT_VIOLATION" snippet.
-    # * The passed type hint accessed by this snippet.
-    func_scope[ARG_NAME_EXCEPTION_PREFIX] = exception_prefix
-    func_scope[ARG_NAME_GET_VIOLATION] = get_hint_object_violation
-    func_scope[ARG_NAME_HINT] = hint
-
-    # Code snippet generating a human-readable violation exception or warning
-    # when the root pith violates the root type hint.
-    code_get_violation = CODE_GET_HINT_OBJECT_VIOLATION.format(
-        arg_random_int=arg_random_int)
-
-    # Code snippet handling the previously generated violation by either raising
-    # that violation as a fatal exception or emitting that violation as a
-    # non-fatal warning.
-    code_handle_violation = _make_code_raiser_violation(
-        conf=conf, func_scope=func_scope, is_param=None)
-
-    # Code snippet type-checking the root pith against the root hint.
-    func_code = (
-        f'{CODE_RAISER_HINT_OBJECT_CHECK_PREFIX}'
-        f'{code_expr}'
-        f'{code_get_violation}'
-        f'{code_handle_violation}'
-    )
-
-    # Return all metadata required by higher-level callers.
-    return (
-        func_code,
-        func_scope,
-        hint_refs_type_basename,
-    )
-
 # ....................{ PRIVATE ~ globals                  }....................
 _func_checker_name_counter = count(start=0, step=1)
 '''
@@ -531,7 +569,7 @@ def _func_checker_ignorable(obj: object) -> bool:
 #FIXME: Unit test us up, please.
 def _make_func_checker(
     # Mandatory parameters.
-    hint: object,
+    hint: Hint,
     conf: BeartypeConf,
     make_code_check: Callable[..., CodeGenerated],
 
@@ -557,7 +595,7 @@ def _make_func_checker(
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be type-checked.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -612,20 +650,19 @@ def _make_func_checker(
             die_unless_conf(conf)
             # Else, "conf" is a configuration.
 
-            # Either:
-            # * If this hint is PEP-noncompliant, the PEP-compliant type hint
-            #   converted from this PEP-noncompliant type hint.
-            # * If this hint is PEP-compliant and supported, this hint as is.
-            # * Else, raise an exception (i.e., if this hint is neither
-            #   PEP-noncompliant nor a supported PEP-compliant hint).
+            # Sane hint sanified from this possibly insane parameter hint if
+            # sanifying this hint generated no supplementary metadata *OR*
+            # that metadata otherwise. Additionally, if this hint is
+            # unsupported by @beartype, raise an exception.
             #
             # Do this first *BEFORE* passing this hint to any further callables.
-            hint = sanify_hint_root_statement(
+            hint_or_sane = sanify_hint_root_statement(
                 hint=hint, conf=conf, exception_prefix=EXCEPTION_PLACEHOLDER)
+            # print(f'Reduced tester root hint {repr(hint)} to hint or metadata {repr(hint_or_sane)}.')
 
             # If this hint is ignorable, all objects satisfy this hint. In this
             # case, return a trivial function unconditionally returning true.
-            if is_hint_ignorable(hint):
+            if hint_or_sane is Any:
                 return _func_checker_ignorable
             # Else, this hint is unignorable.
 
@@ -636,7 +673,8 @@ def _make_func_checker(
                 code_check,
                 func_scope,
                 hint_refs_type_basename,
-            ) = make_code_check(hint, conf, exception_prefix)
+            ) = make_code_check(hint_or_sane, hint, conf, exception_prefix)
+            # print(f'func_scope: {func_scope}')
 
             #FIXME: Actually, nothing below is particularly significant. Users
             #now basically require this. So, let's find a way to do this. The
@@ -889,9 +927,8 @@ def _make_code_raiser_violation(
         # wrapper function wraps. Needlessly passing issue_warning() rather than
         # warn() here would only consume CPU cycles for *NO* tangible gain.
         func_scope[ARG_NAME_WARN] = warn
-    # Else...
+    # Else, raise a fatal exception.
     else:
-        # Raise a fatal exception.
         code_violation = CODE_RAISE_VIOLATION
 
     # Return this code snippet.
