@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -12,46 +12,50 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype.typing import (
-    Any,
-    Optional,
-)
+from beartype.typing import Optional
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._check.metadata.metadecor import BeartypeDecorMeta
-from beartype._check.convert.convcoerce import (
+from beartype._check.metadata.metasane import HintOrSanifiedData
+from beartype._check.convert._convcoerce import (
     coerce_func_hint_root,
     coerce_hint_any,
     coerce_hint_root,
 )
-from beartype._check.convert.convreduce import reduce_hint
+from beartype._check.convert._reduce.redhint import reduce_hint
 from beartype._conf.confcls import BeartypeConf
+from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN
+from beartype._data.hint.datahintpep import (
+    Hint,
+    TypeVarToHint,
+)
 from beartype._data.hint.datahinttyping import TypeStack
+from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
 from beartype._util.cache.map.utilmapbig import CacheUnboundedStrong
 from beartype._util.func.arg.utilfuncargiter import ArgKind
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585func import (
+from beartype._util.hint.pep.proposal.pep484585.pep484585func import (
     reduce_hint_pep484585_func_return)
-from beartype._util.hint.utilhinttest import is_hint_ignorable
 
 # ....................{ SANIFIERS ~ root                   }....................
 #FIXME: Unit test us up, please.
 def sanify_hint_root_func(
     # Mandatory parameters.
     decor_meta: BeartypeDecorMeta,
-    hint: object,
+    hint: Hint,
     pith_name: str,
 
     # Optional parameters.
     arg_kind: Optional[ArgKind] = None,
     exception_prefix: str = EXCEPTION_PLACEHOLDER,
-) -> object:
+) -> HintOrSanifiedData:
     '''
-    PEP-compliant type hint sanified (i.e., sanitized) from the passed **root
-    type hint** (i.e., possibly PEP-noncompliant type hint annotating the
-    parameter or return with the passed name of the passed callable) if this
-    hint is reducible *or* this hint as is otherwise (i.e., if this hint is
-    irreducible).
+    Type hint sanified (i.e., sanitized) from the passed **possibly insane root
+    type hint** (i.e., possibly PEP-noncompliant hint annotating the parameter
+    or return with the passed name of the passed callable) if this hint is both
+    reducible and unignorable, this hint unmodified if this hint is both
+    irreducible and unignorable, or :obj:`typing.Any` otherwise (i.e., if this
+    hint is ignorable).
 
     Specifically, this function:
 
@@ -86,7 +90,7 @@ def sanify_hint_root_func(
     ----------
     decor_meta : BeartypeDecorMeta
         Decorated callable directly annotated by this hint.
-    hint : object
+    hint : Hint
         Possibly PEP-noncompliant root type hint to be sanified.
     pith_name : str
         Either:
@@ -109,12 +113,19 @@ def sanify_hint_root_func(
 
     Returns
     -------
-    object
+    HintOrSanifiedData
         Either:
 
-        * If this hint is PEP-noncompliant, a PEP-compliant type hint converted
-          from this hint.
-        * If this hint is PEP-compliant, this hint unmodified as is.
+        * If the passed hint is reducible to:
+
+          * An ignorable lower-level hint, :obj:`typing.Any`.
+          * An unignorable lower-level hint, either:
+
+            * If reducing this hint to that lower-level hint generates
+              supplementary metadata, that metadata.
+            * Else, that lower-level hint alone.
+
+        * Else, this hint is irreducible. In this case, this hint unmodified.
 
     Raises
     ------
@@ -164,11 +175,12 @@ def sanify_hint_root_func(
         )
     # Else, this hint annotates a parameter.
 
-    # Reduce this hint to a lower-level PEP-compliant type hint if this hint is
-    # reducible *OR* this hint as is otherwise. Reductions simplify subsequent
-    # logic elsewhere by transparently converting non-trivial hints (e.g.,
-    # numpy.typing.NDArray[...]) into semantically equivalent trivial hints
-    # (e.g., beartype validators).
+    # Sane child hint reduced from this possibly insane child hint if reducing
+    # this hint did not generate supplementary metadata *OR* that metadata
+    # otherwise (i.e., if reducing this hint generated supplementary metadata).
+    # Reductions simplify subsequent logic elsewhere by transparently converting
+    # non-trivial hints (e.g., numpy.typing.NDArray[...]) into semantically
+    # equivalent trivial hints (e.g., beartype validators).
     #
     # Whereas the above coercion permanently persists for the duration of the
     # active Python process (i.e., by replacing the original type hint in the
@@ -184,11 +196,8 @@ def sanify_hint_root_func(
     # type-checkers). Reduced type hints, however, are *NOT* harmful in any
     # sense whatsoever; they're simply non-trivial for @beartype to support in
     # their current form and thus temporarily reduced in-memory into a more
-    # convenient form for beartype-specific type-checking purposes elsewhere.
-    #
-    # Note that parameters are intentionally passed positionally to both
-    # optimize memoization efficiency and circumvent memoization warnings.
-    hint = reduce_hint(
+    # convenient form for beartype-specific type-checking elsewhere.
+    hint_or_sane = reduce_hint(
         hint=hint,
         conf=decor_meta.conf,
         decor_meta=decor_meta,
@@ -198,21 +207,22 @@ def sanify_hint_root_func(
         exception_prefix=exception_prefix,
     )
 
-    # Return this sanified hint.
-    return hint
+    # Return this hint if this hint is unignorable *OR* "typing.Any" otherwise.
+    return hint_or_sane
 
 
 #FIXME: Unit test us up, please.
 def sanify_hint_root_statement(
-    hint: object,
+    hint: Hint,
     conf: BeartypeConf,
     exception_prefix: str,
-) -> object:
+) -> HintOrSanifiedData:
     '''
     PEP-compliant type hint sanified (i.e., sanitized) from the passed **root
     type hint** (i.e., possibly PEP-noncompliant type hint that has *no* parent
-    type hint) if this hint is reducible *or* this hint as is otherwise (i.e.,
-    if this hint is irreducible).
+    type hint) if this hint is both reducible and unignorable, this hint
+    unmodified if this hint is both irreducible and unignorable, or
+    :obj:`typing.Any` otherwise (i.e., if this hint is ignorable).
 
     This sanifier is principally intended to be called by a **statement-level
     type-checker factory** (i.e., a function creating and returning a runtime
@@ -228,7 +238,7 @@ def sanify_hint_root_statement(
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Possibly PEP-noncompliant root type hint to be sanified.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -239,12 +249,19 @@ def sanify_hint_root_statement(
 
     Returns
     -------
-    object
+    HintOrSanifiedData
         Either:
 
-        * If this hint is PEP-noncompliant, a PEP-compliant type hint converted
-          from this hint.
-        * If this hint is PEP-compliant, this hint unmodified as is.
+        * If the passed hint is reducible to:
+
+          * An ignorable lower-level hint, :obj:`typing.Any`.
+          * An unignorable lower-level hint, either:
+
+            * If reducing this hint to that lower-level hint generates
+              supplementary metadata, that metadata.
+            * Else, that lower-level hint alone.
+
+        * Else, this hint is irreducible. In this case, this hint unmodified.
 
     Raises
     ------
@@ -270,91 +287,50 @@ def sanify_hint_root_statement(
     # *BEFORE* validating this hint to be PEP-compliant.
     hint = coerce_hint_root(hint=hint, exception_prefix=exception_prefix)
 
-    # Reduce this hint to a lower-level PEP-compliant type hint if this hint is
-    # reducible *OR* this hint as is otherwise. See
-    # sanify_hint_root_func() for further commentary.
-    hint = reduce_hint(hint=hint, conf=conf, exception_prefix=exception_prefix)
+    # Sane child hint reduced from this possibly insane child hint if reducing
+    # this hint did not generate supplementary metadata *OR* that metadata
+    # otherwise (i.e., if reducing this hint generated supplementary metadata).
+    # See also sanify_hint_root_func().
+    hint_or_sane = reduce_hint(
+        hint=hint, conf=conf, exception_prefix=exception_prefix)
 
-    # Return this sanified hint.
-    return hint
+    # Return this hint if this hint is unignorable *OR* "typing.Any" otherwise.
+    return hint_or_sane
 
 # ....................{ SANIFIERS ~ any                    }....................
 #FIXME: Unit test us up, please.
-def sanify_hint_child_if_unignorable_or_none(*args, **kwargs) -> Any:
-    '''
-    Type hint sanified (i.e., sanitized) from the passed **possibly insane child
-    type hint** (i.e., hint transitively subscripting the root type hint
-    annotating a parameter or return of the currently decorated callable) if
-    this hint is both reducible and ignorable, this hint unmodified if this hint
-    is both irreducible and ignorable, and :data:`None` otherwise (i.e., if this
-    hint is ignorable).
-
-    This high-level sanifier effectively chains the lower-level
-    :func:`sanify_hilt_child` sanifier and
-    :func:`beartype._util.hint.utilhinttest.is_hint_ignorable` tester into a
-    single unified function, streamlining sanification and ignorability
-    detection throughout the codebase.
-
-    Note that a :data:`None` return unambiguously implies this hint to be
-    ignorable, even if the passed hint is itself :data:`None`. Why? Because if
-    the passed hint were :data:`None`, then a :pep:`484`-compliant reducer will
-    internally reduce this hint to ``type(None)``. After reduction, *all* hints
-    are guaranteed to be non-:data:`None`.
-
-    Parameters
-    ----------
-    All passed arguments are passed as is to the lower-level
-    :func:`sanify_hilt_child` sanifier.
-
-    Returns
-    -------
-    object
-        Either:
-
-        * If the passed possibly insane child type hint is ignorable after
-          reduction to a sane child type hint, :data:`None`.
-        * Else, the sane child type hint to which this hint reduces.
-    '''
-
-    # Sane child hint sanified from this possibly insane child hint if this hint
-    # is reducible *OR* this hint as is otherwise (i.e., if irreducible).
-    hint_child = sanify_hint_child(*args, **kwargs)
-
-    # Return either "None" if this hint is ignorable or this hint otherwise.
-    return None if is_hint_ignorable(hint_child) else hint_child
-
-
 def sanify_hint_child(
     # Mandatory parameters.
-    hint: object,
-    conf: BeartypeConf,
-    exception_prefix: str,
+    hint: Hint,
 
     # Optional parameters.
     cls_stack: TypeStack = None,
+    conf: BeartypeConf = BEARTYPE_CONF_DEFAULT,
     pith_name: Optional[str] = None,
-) -> Any:
+    typevar_to_hint: TypeVarToHint = FROZENDICT_EMPTY,
+    exception_prefix: str = '',
+) -> HintOrSanifiedData:
     '''
     Type hint sanified (i.e., sanitized) from the passed **possibly insane child
-    type hint** (i.e., hint transitively subscripting the root type hint
-    annotating a parameter or return of the currently decorated callable) if
-    this hint is reducible *or* this hint unmodified otherwise (i.e., if this
-    hint is irreducible).
+    type hint** (i.e., possibly PEP-noncompliant hint transitively subscripting
+    the root type hint annotating a parameter or return of the currently
+    decorated callable) if this hint is both reducible and unignorable, this
+    hint unmodified if this hint is both irreducible and unignorable, or
+    :obj:`typing.Any` otherwise (i.e., if this hint is ignorable).
 
     Parameters
     ----------
-    hint : object
-        Type hint to be sanified.
-    conf : BeartypeConf
-        **Beartype configuration** (i.e., self-caching dataclass encapsulating
-        all settings configuring type-checking for the passed object).
-    exception_prefix : str
-        Substring prefixing exception messages raised by this function.
+    hint : Hint
+        Child type hint to be sanified.
     cls_stack : TypeStack, optional
         **Type stack** (i.e., either a tuple of the one or more
         :func:`beartype.beartype`-decorated classes lexically containing the
         class variable or method annotated by this hint *or* :data:`None`).
         Defaults to :data:`None`.
+    conf : BeartypeConf, optional
+        **Beartype configuration** (i.e., self-caching dataclass encapsulating
+        all settings configuring type-checking for the passed object). Defaults
+        to :obj:`.BEARTYPE_CONF_DEFAULT`, the default beartype configuration.
     pith_name : Optional[str], optional
         Either:
 
@@ -364,32 +340,69 @@ def sanify_hint_child(
           hint of that return), the magic string ``"return"``.
         * Else, :data:`None`.
 
+        Note that:
+
+        * This parameter should only be passed during exception raising (i.e.,
+          from within the :func:`beartype._check.error` subpackage).
+        * This parameter should *never* be passed during code generation (i.e.,
+          by the :func:`beartype._check.code.codemain.make_check_expr` code
+          factory).
+
         Defaults to :data:`None`.
+    typevar_to_hint : TypeVarToHint, optional
+        **Type variable lookup table** (i.e., immutable dictionary mapping from
+        the :pep:`484`-compliant **type variables** (i.e.,
+        :class:`typing.TypeVar` objects) originally parametrizing the origins of
+        all transitive parent hints of this hint to the corresponding child
+        hints subscripting these parent hints). Defaults to
+        :data:`.FROZENDICT_EMPTY`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing raised exception messages. Defaults
+        to the empty string.
 
     Returns
     -------
-    object
-        Type hint sanified from this possibly insane child type hint.
+    HintOrSanifiedData
+        Either:
+
+        * If the passed hint is reducible to:
+
+          * An ignorable lower-level hint, :obj:`typing.Any`.
+          * An unignorable lower-level hint, either:
+
+            * If reducing this hint to that lower-level hint generates
+              supplementary metadata, that metadata.
+            * Else, that lower-level hint alone.
+
+        * Else, this hint is irreducible. In this case, this hint unmodified.
     '''
+    # print(f'Sanifying child hint {repr(hint)} with type variable lookup table {repr(typevar_to_hint)}...')
 
     # This sanifier covers the proper subset of logic performed by the
     # sanify_hint_root_statement() sanifier applicable to child type hints.
 
-    # PEP-compliant type hint coerced (i.e., permanently converted in the
-    # annotations dunder dictionary of the passed callable) from this possibly
-    # PEP-noncompliant type hint if this hint is coercible *OR* this hint as is
-    # otherwise. Since the passed hint is *NOT* necessarily PEP-compliant,
-    # perform this coercion *BEFORE* validating this hint to be PEP-compliant.
+    # PEP-compliant hint coerced (i.e., permanently converted in the annotations
+    # dictionary of the passed callable) from this possibly PEP-noncompliant
+    # hint if this hint is coercible *OR* this hint as is otherwise. Since the
+    # passed hint is *NOT* necessarily PEP-compliant, perform this coercion
+    # *BEFORE* validating this hint to be PEP-compliant.
     hint = coerce_hint_any(hint)
 
-    # Return this hint reduced.
-    return reduce_hint(
+    # Sane child hint sanified from this possibly insane child hint if reducing
+    # this hint did not generate supplementary metadata *OR* that metadata
+    # otherwise (i.e., if reducing this hint generated supplementary metadata).
+    hint_or_sane = reduce_hint(
         hint=hint,
         conf=conf,
         cls_stack=cls_stack,
         pith_name=pith_name,
+        typevar_to_hint=typevar_to_hint,
         exception_prefix=exception_prefix,
     )
+    # print(f'[sanify] Detecting hint {repr(hint)} reduction {repr(hint_or_sane)} ignorability...')
+
+    # Return this hint if this hint is unignorable *OR* "Any" otherwise.
+    return hint_or_sane
 
 # ....................{ PRIVATE ~ mappings                 }....................
 _HINT_REPR_TO_HINT = CacheUnboundedStrong()
