@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -13,6 +13,11 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ TODO                               }....................
+#FIXME: The "ViolationCause.hint_childs" tuple is arguably useless. It's only
+#used in one other submodule and can, in any case, be trivially reconstructed
+#from the more useful "ViolationCause.hint_or_sane_childs" tuple. In other
+#words, please excise "ViolationCause.hint_childs".
+
 #FIXME: The recursive "ViolationCause" class strongly overlaps with the equally
 #recursive (and substantially superior) "beartype.door.TypeHint" class. Ideally:
 #* Define a new private "beartype.door._doorerror" submodule.
@@ -24,8 +29,8 @@ This private submodule is *not* intended for importation by downstream callers.
 #  dataclass encapsulating metadata describing the current type-checking
 #  violation. That metadata (e.g., "cause_indent") is inappropriate for
 #  general-purpose type hints. Exceptions include:
-#  * "hint", "hint_sign", and "hint_childs" -- all of which are subsumed by the
-#    "TypeHint" dataclass and should thus be excised.
+#  * "hint", "hint_sign", and "hint_or_sane_childs" -- all of which are subsumed
+#    by the "TypeHint" dataclass and should thus be excised.
 #* Refactor the TypeHint._find_cause() method to accept an instance of
 #  the "_TypeHintUnbearability" dataclass: e.g.,
 #      class TypeHint(...):
@@ -33,7 +38,7 @@ This private submodule is *not* intended for importation by downstream callers.
 #              self, unbearability: _TypeHintUnbearability) -> Optional[str]:
 #              ...
 #* Refactor existing find_cause_*() getters (e.g.,
-#  find_cause_sequence_args_1(), find_cause_union()) into
+#  find_cause_sequence_args_1(), find_cause_pep484604_union()) into
 #  _get_unbearability_cause_or_none() methods of the corresponding "TypeHint"
 #  subclasses, please.
 #
@@ -47,25 +52,44 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.roar._roarexc import _BeartypeCallHintPepRaiseException
 from beartype.typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Optional,
-    Tuple,
+    Union,
 )
 from beartype._cave._cavemap import NoneTypeOr
+from beartype._check.convert.convsanify import sanify_hint_child
+from beartype._check.metadata.metasane import (
+    HintOrSanifiedData,
+    TupleHintOrSanifiedData,
+    get_hint_or_sane_hint,
+    unpack_hint_or_sane,
+)
 from beartype._conf.confcls import BeartypeConf
+from beartype._data.hint.datahintpep import (
+    Hint,
+    TupleHints,
+    TypeVarToHint,
+)
 from beartype._data.hint.datahinttyping import TypeStack
+from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
+from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED_DEEP,
     HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
 )
 from beartype._util.hint.pep.utilpepget import (
     get_hint_pep_args,
-    get_hint_pep_sign,
+    get_hint_pep_sign_or_none,
 )
 from beartype._util.hint.pep.utilpeptest import is_hint_pep
-from beartype._check.convert.convsanify import (
-    sanify_hint_child_if_unignorable_or_none)
+from beartype._util.kind.map.utilmapfrozen import FrozenDict
+from beartype._util.utilobject import (
+    SENTINEL,
+    Iota,
+)
+from beartype._util.utilobjmake import permute_object
 
 # ....................{ CLASSES                            }....................
 class ViolationCause(object):
@@ -105,19 +129,35 @@ class ViolationCause(object):
         * If this violation originates from a decorated callable, that
           callable.
         * Else, :data:`None`.
-    hint : Any
+    hint : Hint
         Type hint to validate this object against.
-    hint_sign : Any
+    hint_childs : Optional[TupleHints]
+        Either:
+
+        * If this hint is PEP-compliant, the possibly empty tuple of all child
+          hints subscripting (indexing) this hint.
+        * Else, :data:`None`.
+
+        This instance variable is effectively a streamlined variant of the
+        :attr:`hint_or_sane_childs` instance variable. Whereas the latter
+        *includes* all supplementary metadata, the former instance variable
+        *excludes* all supplementary metadata and thus only contains hints.
+    hint_or_sane_childs : Optional[TupleHintOrSanifiedData]
+        Either:
+
+        * If this hint is PEP-compliant, the possibly empty tuple of all child
+          hints subscripting (indexing) this hint such that each item is either:
+
+          * If sanifying this child hint generated supplementary metadata, that
+            metadata (i.e., a :class:`.HintSanifiedData` object).
+          * Else, this child hint as is.
+
+        * Else, :data:`None`.
+    hint_sign : Optional[HintSign]
         Either:
 
         * If this hint is PEP-compliant, the sign identifying this hint.
         * Else, :data:`None` otherwise.
-    hint_childs : Optional[Tuple]
-        Either:
-
-        * If this hint is PEP-compliant, the possibly empty tuple of all child
-          type hints subscripting (indexing) this hint.
-        * Else, :data:`None`.
     pith : Any
         Arbitrary object to be validated.
     pith_name : Optional[str]
@@ -135,8 +175,15 @@ class ViolationCause(object):
         the current call to that function) if that function generated such an
         integer *or* ``None`` otherwise (i.e., if that function generated *no*
         such integer). See the same parameter accepted by the higher-level
-        :func:`beartype._check.error.errget.get_func_pith_violation`
-        function for further details.
+        :func:`beartype._check.error.errget.get_func_pith_violation` function.
+    typevar_to_hint : TypeVarToHint
+        **Type variable lookup table** (i.e., immutable dictionary mapping from
+        each :pep:`484`-compliant type variable parametrizing either the
+        currently visited type hint *or* a transitive parent type hint of this
+        hint to the corresponding non-type variable type hint subscripting that
+        hint). See also the comparable
+        :func:`beartype._check.codecls.HintMeta.typevar_to_hint` instance
+        variable.
     '''
 
     # ..................{ CLASS VARIABLES                    }..................
@@ -151,14 +198,35 @@ class ViolationCause(object):
         'exception_prefix',
         'func',
         'hint',
-        'hint_sign',
         'hint_childs',
+        'hint_or_sane_childs',
+        'hint_sign',
         'pith',
         'pith_name',
         'random_int',
+        'typevar_to_hint',
     )
 
 
+    # Squelch false negatives from mypy. This is absurd. This is mypy. See:
+    #     https://github.com/python/mypy/issues/5941
+    if TYPE_CHECKING:
+        cause_indent: str
+        cause_str_or_none: Optional[str]
+        cls_stack: TypeStack
+        conf: BeartypeConf
+        exception_prefix: str
+        func: Optional[Callable]
+        hint: Hint
+        hint_childs: TupleHints
+        hint_or_sane_childs: TupleHintOrSanifiedData
+        hint_sign: Optional[HintSign]
+        pith: Any
+        pith_name: Optional[str]
+        random_int: Optional[int]
+        typevar_to_hint: TypeVarToHint
+
+
     _INIT_PARAM_NAMES = frozenset((
         'cause_indent',
         'cause_str_or_none',
@@ -167,9 +235,11 @@ class ViolationCause(object):
         'exception_prefix',
         'func',
         'hint',
+        'hint_or_sane',
         'pith',
         'pith_name',
         'random_int',
+        'typevar_to_hint',
     ))
     '''
     Frozen set of the names of all parameters accepted by the :meth:`init`
@@ -185,25 +255,61 @@ class ViolationCause(object):
         self,
 
         # Mandatory parameters.
-        cls_stack: TypeStack,
         cause_indent: str,
+        cls_stack: TypeStack,
         conf: BeartypeConf,
         exception_prefix: str,
         func: Optional[Callable],
-        hint: Any,
         pith: Any,
         pith_name: Optional[str],
         random_int: Optional[int],
 
         # Optional parameters.
+        hint: Union[Hint, Iota] = SENTINEL,
+        hint_or_sane: Union[HintOrSanifiedData, Iota] = SENTINEL,
         cause_str_or_none: Optional[str] = None,
+        typevar_to_hint: TypeVarToHint = FROZENDICT_EMPTY,
     ) -> None:
         '''
         Initialize this type-checking violation cause finder.
 
         Parameters
         ----------
-        See the class docstring for a description of these parameters.
+        hint : Hint
+            Unsanified hint to validate this object against. This parameter is
+            mutually exclusive with the competing ``hint_or_sane`` parameter.
+            Defaults to the sentinel placeholder such that either:
+
+            * This parameter is unpassed (thus, the sentinel) and the
+              ``hint_or_sane`` parameter is passed (thus, *not* the sentinel).
+            * This parameter is passed (thus, *not* the sentinel) and the
+              ``hint_or_sane`` parameter is unpassed (thus, the sentinel).
+        hint_or_sane : HintOrSanifiedData
+            Sanified hint *or* **supplementary metadata** (i.e.,
+            :class:`.HintSanifiedData` object) generated by the sanification of
+            this hint to validate this object against. This parameter is
+            mutually exclusive with the competing ``hint_or_sane`` parameter.
+            Defaults to the sentinel placeholder such that either:
+
+            * This parameter is unpassed (thus, the sentinel) and the
+              ``hint_or_sane`` parameter is passed (thus, *not* the sentinel).
+            * This parameter is passed (thus, *not* the sentinel) and the
+              ``hint_or_sane`` parameter is unpassed (thus, the sentinel). In
+              this case, this parameter is defined as either:
+
+              * If this hint is reducible to:
+
+                * An ignorable lower-level hint, :obj:`typing.Any`.
+                * An unignorable lower-level hint, either:
+
+                  * If reducing this hint to that lower-level hint generates
+                    supplementary metadata, that metadata.
+                  * Else, that lower-level hint alone.
+
+              * Else, this hint is irreducible. In this case, this hint
+                unmodified.
+
+        See the class docstring for a description of all remaining parameters.
         '''
         assert isinstance(cls_stack, NoneTypeOr[tuple]), (
             f'{repr(cls_stack)} neither tuple nor "None".')
@@ -211,61 +317,79 @@ class ViolationCause(object):
             f'{repr(conf)} not configuration.')
         assert func is None or callable(func), (
             f'{repr(func)} neither callable nor "None".')
-        assert isinstance(pith_name, NoneTypeOr[str]), (
-            f'{repr(pith_name)} not string or "None".')
         assert isinstance(cause_indent, str), (
             f'{repr(cause_indent)} not string.')
-        assert isinstance(exception_prefix, str), (
-            f'{repr(exception_prefix)} not string.')
-        assert isinstance(random_int, NoneTypeOr[int]), (
-            f'{repr(random_int)} not integer or "None".')
         assert isinstance(cause_str_or_none, NoneTypeOr[str]), (
             f'{repr(cause_str_or_none)} not string or "None".')
+        assert isinstance(exception_prefix, str), (
+            f'{repr(exception_prefix)} not string.')
+        # assert isinstance(is_hint_root, bool), (
+        #     f'{repr(is_hint_root)} not boolean.')
+        assert isinstance(pith_name, NoneTypeOr[str]), (
+            f'{repr(pith_name)} not string or "None".')
+        assert isinstance(random_int, NoneTypeOr[int]), (
+            f'{repr(random_int)} not integer or "None".')
+        assert isinstance(typevar_to_hint, FrozenDict), (
+            f'{repr(typevar_to_hint)} not frozen dictionary.')
 
         # Classify all passed parameters.
-        self.func = func
+        self.cause_indent = cause_indent
+        self.cause_str_or_none = cause_str_or_none
         self.cls_stack = cls_stack
         self.conf = conf
-        # self.hint = hint
+        self.exception_prefix = exception_prefix
+        self.func = func
         self.pith = pith
         self.pith_name = pith_name
-        self.cause_indent = cause_indent
-        self.exception_prefix = exception_prefix
         self.random_int = random_int
-        self.cause_str_or_none = cause_str_or_none
+        self.typevar_to_hint = typevar_to_hint
 
         # Nullify all remaining parameters for safety.
-        self.hint_sign: Any = None
-        self.hint_childs: Tuple = None  # type: ignore[assignment]
+        self.hint_childs = None  # type: ignore[assignment]
+        self.hint_or_sane_childs = None  # type: ignore[assignment]
 
-        # Unignorable sane hint sanified from this possibly ignorable insane
-        # hint *OR* "None" otherwise (i.e., if this hint is ignorable).
-        #
-        # Note that this is a bit inefficient. Since child hints are already
-        # sanitized below, the sanitization performed by this assignment
-        # effectively reduces to a noop for all type hints *EXCEPT* the root
-        # type hint. Technically, this means this could be marginally optimized
-        # by externally sanitizing the root type hint in the "errget"
-        # submodule. Pragmatically, doing so would only complicate an already
-        # overly complex workflow for little to no tangible gain.
-        self.hint = sanify_hint_child_if_unignorable_or_none(
-            hint=hint,
-            conf=self.conf,
-            cls_stack=self.cls_stack,
-            pith_name=self.pith_name,
-            exception_prefix=self.exception_prefix,
-        )
+        # If the caller passed *NO* sanified hint...
+        if hint_or_sane is SENTINEL:
+            assert hint is not SENTINEL, (
+                f'"hint" {repr(hint)} and '
+                f'"hint_or_sane" {repr(hint_or_sane)} parameters both unpassed.'
+            )
 
+            # Sane hint sanified from this possibly insane hint if sanifying
+            # this hint did not generate supplementary metadata *OR* that
+            # metadata (i.e., if doing so generated supplementary metadata).
+            hint_or_sane = self.sanify_hint_child(hint)  # type: ignore[arg-type]
+            # print(f'Sanified error parent hint {repr(hint)} to {repr(hint_or_sane)}.')
+        # Else, the caller passed a sanified hint. In this case...
+        else:
+            # Silently ignore the passed unsanified hint if any by simply
+            # deleting the latter.
+            #
+            # Note that we would ideally raise an exception if the caller also
+            # passed an unsanified hint, but that doing so would raise
+            # complications with our current implementation of the permute()
+            # method. Since this dataclass *ONLY* applies to private
+            # functionality *NEVER* exposed to end users, a bit of wonkiness in
+            # this private API is currently an acceptable tradeoff.
+            # Assert that the caller passed an unsanified hint.
+            del hint
+
+        # Sane hint sanified from this possibly insane hint *AND* the
+        # corresponding type variable lookup table unpacked from this metadata.
+        self.hint, self.typevar_to_hint = unpack_hint_or_sane(hint_or_sane)  # type: ignore[arg-type]
+
+        # Sign uniquely identifying this hint if this hint is PEP-compliant *OR*
+        # "None" otherwise (i.e., if this hint is PEP-noncompliant).
+        self.hint_sign = get_hint_pep_sign_or_none(self.hint)
+
+        #FIXME: Refactor into a new private method for maintainability, please.
         # If this hint is both...
         if (
             # Unignorable *AND*...
-            self.hint is not None and
+            self.hint is not Any and
             # PEP-compliant...
             is_hint_pep(self.hint)
         ):
-            # Arbitrary object uniquely identifying this hint.
-            self.hint_sign = get_hint_pep_sign(self.hint)
-
             # Tuple of the zero or more arguments subscripting this hint.
             hint_childs_insane = get_hint_pep_args(self.hint)
 
@@ -273,41 +397,82 @@ class ViolationCause(object):
             # subscripting this parent hint, initialized to the empty list.
             hint_childs_sane = []
 
+            # List of the zero or more possibly ignorable metadata generated by
+            # sanifying these child hints, initialized to the empty list.
+            hint_or_sane_childs_sane = []
+
             # For each possibly ignorable insane child hints subscripting this
             # parent hint...
             for hint_child_insane in hint_childs_insane:
+                # Sane child hint sanified from this possibly insane child hint.
+                hint_child_sane: Hint = None  # pyright: ignore
+
+                # Sane child hint sanified from this possibly insane child hint
+                # if sanifying this child hint did not generate supplementary
+                # metadata *OR* that metadata otherwise (i.e., if sanifying this
+                # child hint generated supplementary metadata).
+                hint_or_sane_child_sane: HintOrSanifiedData = None  # type: ignore[assignment]
+
                 # If this child hint is PEP-compliant...
                 #
                 # Note that arbitrary PEP-noncompliant arguments *CANNOT* be
                 # safely sanitized. Why? Because arbitrary arguments are *NOT*
-                # necessarily valid type hints. Consider the type hint
-                # "tuple[()]", where the argument "()" is invalid as a type hint
-                # but valid an argument to that type hint.
+                # necessarily valid hints. Consider the hint "tuple[()]", where
+                # the argument "()" is invalid as a hint but valid an argument
+                # to that hint.
                 if is_hint_pep(hint_child_insane):
-                    # Unignorable sane child hint sanified from this possibly
-                    # ignorable insane child hint *OR* "None" otherwise (i.e.,
-                    # if this child hint is ignorable).
-                    hint_child_sane = sanify_hint_child_if_unignorable_or_none(
-                        hint=hint_child_insane,
-                        conf=self.conf,
-                        cls_stack=self.cls_stack,
-                        pith_name=self.pith_name,
-                        exception_prefix=self.exception_prefix,
-                    )
+                    # Sanify this child hint into this metadata.
+                    hint_or_sane_child_sane = self.sanify_hint_child(
+                        hint_child_insane)
+
+                    # Sane child hint encapsulated by this metadata.
+                    hint_child_sane = get_hint_or_sane_hint(
+                        hint_or_sane_child_sane)
                 # Else, this child hint is PEP-noncompliant. In this case,
                 # preserve this child hint as is.
                 else:
-                    hint_child_sane = hint_child_insane
+                    hint_child_sane = hint_or_sane_child_sane = (
+                        hint_child_insane)
 
-                # Append this possibly ignorable sane child hint to this list.
+                # Append this possibly ignorable sane child hint and
+                # supplementary metadata to these lists.
                 hint_childs_sane.append(hint_child_sane)
+                hint_or_sane_childs_sane.append(hint_or_sane_child_sane)
 
-            # Tuple of the zero or more possibly ignorable sane child hints
-            # subscripting this parent hint, coerced from this list.
+            # Tuples of the zero or more possibly ignorable sane child hints and
+            # supplementary metadatum, coerced from these lists.
             self.hint_childs = tuple(hint_childs_sane)
+            self.hint_or_sane_childs = tuple(hint_or_sane_childs_sane)
         # Else, this hint is PEP-noncompliant (e.g., isinstanceable class).
 
-    # ..................{ GETTERS                            }..................
+    # ..................{ DUNDERS                            }..................
+    def __repr__(self) -> str:
+        '''
+        Machine-readable representation of this error cause.
+        '''
+
+        # Represent this metadata with just the minimal subset of metadata
+        # needed to reasonably describe this metadata.
+        return (
+            f'{self.__class__.__name__}('
+            f'hint={repr(self.hint)}, '
+            f'hint_sign={repr(self.hint_sign)}, '
+            f'hint_childs={repr(self.hint_childs)}, '
+            f'hint_or_sane_childs={repr(self.hint_or_sane_childs)}, '
+            f'conf={repr(self.conf)}, '
+            f'cause_indent={repr(self.cause_indent)}, '
+            f'cause_str_or_none={repr(self.cause_str_or_none)}, '
+            f'cls_stack={repr(self.cls_stack)}, '
+            f'func={repr(self.func)}, '
+            f'pith={repr(self.pith)}, '
+            f'pith_name={repr(self.pith_name)}, '
+            f'random_int={repr(self.random_int)}, '
+            f'typevar_to_hint={repr(self.typevar_to_hint)}, '
+            f'exception_prefix={repr(self.exception_prefix)}, '
+            f')'
+        )
+
+    # ..................{ FINDERS                            }..................
     def find_cause(self) -> 'ViolationCause':
         '''
         Output cause describing whether the pith of this input cause either
@@ -327,22 +492,20 @@ class ViolationCause(object):
         satisfy the corresponding hint transitively nested in the hint passed to
         that function.
 
-        For example, consider the PEP-compliant type hint ``List[Union[int,
-        str]]`` describing a list whose items are either integers or strings
-        and the list ``list(range(256)) + [False,]`` consisting of the integers
-        0 through 255 followed by boolean :data:`False`. Since that list is a
-        standard sequence, the
-        :func:`._peperrorsequence.find_cause_sequence_args_1`
-        function must decide the cause of this list's failure to comply with
-        this hint by finding the list item that is neither an integer nor a
-        string, implemented by by iteratively passing each list item to the
-        :func:`._peperrorunion.find_cause_union` function. Since
-        the first 256 items of this list are integers satisfying this hint,
-        :func:`._peperrorunion.find_cause_union` returns a dataclass instance
-        whose :attr:`cause` field is :data:`None` up to
-        :func:`._peperrorsequence.find_cause_sequence_args_1`
-        before finally finding the non-compliant boolean item and returning the
-        human-readable cause.
+        For example, consider the type hint ``List[Union[int, str]]`` describing
+        a list whose items are either integers or strings and the list
+        ``list(range(256)) + [False,]`` consisting of the integers 0 through 255
+        followed by boolean :data:`False`. Since that list is a sequence, the
+        :func:`._peperrorsequence.find_cause_sequence_args_1` function must
+        decide the cause of this list's failure to comply with this hint by
+        finding the list item that is neither an integer nor a string,
+        implemented by by iteratively passing each list item to the
+        :func:`._peperrorunion.find_cause_pep484604_union` function. Since the
+        first 256 items of this list are integers satisfying this hint,
+        :func:`._peperrorunion.find_cause_pep484604_union` returns a dataclass
+        instance whose :attr:`cause` field is :data:`None` up to
+        :func:`._peperrorsequence.find_cause_sequence_args_1` before finally
+        finding the non-compliant boolean item and returning its cause.
 
         Returns
         -------
@@ -362,7 +525,7 @@ class ViolationCause(object):
         # If this hint is ignorable, all possible objects satisfy this hint.
         # Since this hint *CANNOT* (by definition) be the cause of this failure,
         # return the same cause as is.
-        if self.hint is None:
+        if self.hint is Any:
             return self
         # Else, this hint is unignorable.
 
@@ -455,24 +618,24 @@ class ViolationCause(object):
     # ..................{ PERMUTERS                          }..................
     def permute(self, **kwargs) -> 'ViolationCause':
         '''
-        Shallow copy of this object such that each the passed keyword argument
+        Shallow copy of this object such that each passed keyword parameter
         overwrites the instance variable of the same name in this copy.
 
         Parameters
         ----------
-        Keyword arguments of the same name and type as instance variables of
-        this object (e.g., ``hint``, ``pith``).
+        Keyword parameters of the same name and type as instance variables of
+        this object (e.g., ``hint: Hint``, ``pith: object``).
 
         Returns
         -------
         ViolationCause
-            Shallow copy of this object such that each keyword argument
+            Shallow copy of this object such that each keyword parameter
             overwrites the instance variable of the same name in this copy.
 
         Raises
         ------
         _BeartypeCallHintPepRaiseException
-            If the name of any passed keyword argument is *not* the name of an
+            If the name of any passed keyword parameter is *not* that of an
             existing instance variable of this object.
 
         Examples
@@ -492,22 +655,61 @@ class ViolationCause(object):
            typing.List[int]
         '''
 
-        # For the name of each passed keyword argument...
-        for arg_name in kwargs.keys():
-            # If this name is *NOT* that of a parameter accepted by the
-            # __init__() method, raise an exception.
-            if arg_name not in self._INIT_PARAM_NAMES:
-                raise _BeartypeCallHintPepRaiseException(
-                    f'{self.__class__}.__init__() parameter '
-                    f'{arg_name} unrecognized.'
-                )
+        # Set us up the permutation! Make your time!
+        return permute_object(
+            obj=self,
+            init_arg_name_to_value=kwargs,
+            init_arg_names=self._INIT_PARAM_NAMES,
+            exception_cls=_BeartypeCallHintPepRaiseException,
+        )
 
-        # For the name of each parameter accepted by the __init__() method...
-        for arg_name in self._INIT_PARAM_NAMES:
-            # If this parameter was *NOT* explicitly passed by the caller,
-            # default this parameter to its current value from this object.
-            if arg_name not in kwargs:
-                kwargs[arg_name] = getattr(self, arg_name)
+    # ..................{ SANIFIERS                          }..................
+    def sanify_hint_child(self, hint: Hint) -> HintOrSanifiedData:
+        '''
+        Type hint sanified (i.e., sanitized) from the passed **possibly insane
+        child type hint** (i.e., hint transitively subscripting the root type
+        hint annotating a parameter or return of the currently decorated
+        callable) if this hint is both reducible and ignorable, this hint
+        unmodified if this hint is both irreducible and ignorable, and
+        :object:`typing.Any` otherwise (i.e., if this hint is ignorable).
 
-        # Return a new instance of this class initialized with these arguments.
-        return ViolationCause(**kwargs)
+        This method is merely a convenience wrapper for the lower-level
+        :func:`.sanify_hint_child` sanifier.
+
+        Parameters
+        ----------
+        hint : Hint
+            Type hint to be sanified.
+
+        Returns
+        -------
+        HintOrSanifiedData
+            Either:
+
+            * If the passed hint is reducible to:
+
+              * An ignorable lower-level hint, :obj:`typing.Any`.
+              * An unignorable lower-level hint, either:
+
+                * If reducing this hint to that lower-level hint generates
+                  supplementary metadata, that metadata.
+                * Else, that lower-level hint alone.
+
+            * Else, this hint is irreducible. In this case, this hint
+              unmodified.
+        '''
+
+        # Sane hint sanified from this possibly insane hint if sanifying this
+        # hint did not generate supplementary metadata *OR* that metadata
+        # otherwise (i.e., if doing so generated supplementary metadata).
+        hint_or_sane_child = sanify_hint_child(
+            hint=hint,
+            cls_stack=self.cls_stack,
+            conf=self.conf,
+            pith_name=self.pith_name,
+            typevar_to_hint=self.typevar_to_hint,
+            exception_prefix=self.exception_prefix,
+        )
+
+        # Return this metadata.
+        return hint_or_sane_child
