@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -123,6 +123,7 @@ from beartype._conf.confcls import BeartypeConf
 from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._conf.confenum import BeartypeViolationVerbosity
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN
+from beartype._data.hint.datahintpep import Hint
 from beartype._data.hint.datahinttyping import (
     TypeException,
     TypeStack,
@@ -231,7 +232,7 @@ def get_func_pith_violation(
         cls_stack=check_meta.cls_stack,
         conf=check_meta.conf,
         func=check_meta.func,
-        hint=hint,
+        hint=hint,  # type: ignore[arg-type]
         obj=pith_value,
         pith_name=pith_name,
         **kwargs
@@ -241,7 +242,7 @@ def get_func_pith_violation(
 def get_hint_object_violation(
     # Mandatory parameters.
     obj: object,
-    hint: object,
+    hint: Hint,
     conf: BeartypeConf,
 
     # Optional parameters.
@@ -294,7 +295,7 @@ def get_hint_object_violation(
     ----------
     obj : object
         Arbitrary object to be type-checked against this type hint.
-    hint : object
+    hint : Hint
         Type hint against which to type-check this object.
     conf : BeartypeConf
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
@@ -389,8 +390,8 @@ def get_hint_object_violation(
     #     hint={!r},
     #     conf={!r},
     #     pith_name={!r},
-    #     pith_value={!r}',
-    # )'''.format(func, hint, conf, pith_name, pith_value))
+    #     obj={!r},
+    # )'''.format(func, hint, conf, pith_name, obj))
 
     # ....................{ LOCALS                         }....................
     # Type of violation to be raised.
@@ -460,6 +461,7 @@ def get_hint_object_violation(
         exception_prefix=exception_prefix,
         func=func,
         hint=hint,
+        # is_hint_root=True,
         pith=obj,
         pith_name=pith_name,
         random_int=random_int,
