@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -24,14 +24,14 @@ from beartype._cave._cavefast import CallableCodeObjectType
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._check.forward.fwdscope import BeartypeForwardScope
 from beartype._conf.confcls import BeartypeConf
+from beartype._data.hint.datahintpep import DictStrToHint
 from beartype._data.hint.datahinttyping import (
-    DictStrToAny,
     LexicalScope,
     TypeStack,
 )
-from beartype._util.cache.pool.utilcachepoolobjecttyped import (
-    acquire_object_typed,
-    release_object_typed,
+from beartype._util.cache.pool.utilcachepoolinstance import (
+    acquire_instance,
+    release_instance,
 )
 from beartype._util.func.utilfunccodeobj import (
     get_func_codeobj,
@@ -92,7 +92,7 @@ class BeartypeDecorMeta(object):
         **Beartype configuration** (i.e., self-caching dataclass encapsulating
         all flags, options, settings, and other metadata configuring the
         current decoration of the decorated callable).
-    func_arg_name_to_hint : dict[str, object]
+    func_arg_name_to_hint : dict[str, Hint]
         **Type hint dictionary** (i.e., mapping from the name of each annotated
         parameter accepted by the decorated callable to the type hint annotating
         that parameter).
@@ -221,7 +221,7 @@ class BeartypeDecorMeta(object):
     if TYPE_CHECKING:
         cls_stack: TypeStack
         conf: BeartypeConf
-        func_arg_name_to_hint: DictStrToAny
+        func_arg_name_to_hint: DictStrToHint
         func_arg_name_to_hint_get: Callable[[str, object], object]
         func_wrappee: Callable
         func_wrappee_is_nested: bool
@@ -241,7 +241,7 @@ class BeartypeDecorMeta(object):
     # to be hashed (and thus also cached), since these instances are:
     # * Specific to the decorated callable and thus *NOT* safely cacheable
     #   across functions applying to different decorated callables.
-    # * Already cached via the acquire_object_typed() function called by the
+    # * Already cached via the acquire_instance() function called by the
     #   "beartype._decor.decormain" submodule.
     #
     # See also:
@@ -259,7 +259,7 @@ class BeartypeDecorMeta(object):
         callers are expected to (in order):
 
         #. Acquire cached instances of this class via the
-           :mod:`beartype._util.cache.pool.utilcachepoolobjecttyped` submodule.
+           :mod:`beartype._util.cache.pool.utilcachepoolinstance` submodule.
         #. Call the :meth:`reinit` method on these instances to properly
            initialize these instances.
         '''
@@ -742,7 +742,7 @@ class BeartypeDecorMeta(object):
         # Represent this metadata with just the minimal subset of metadata
         # needed to reasonably describe this metadata.
         return (
-            f'BeartypeDecorMeta('
+            f'{self.__class__.__name__}('
             f'func={repr(self.func_wrappee)}, '
             f'conf={repr(self.conf)}'
             f')'
@@ -782,7 +782,7 @@ def make_beartype_call(**kwargs) -> BeartypeDecorMeta:
     instantiating new :class:`.BeartypeDecorMeta` objects.
 
     **The caller must pass the metadata returned by this factory back to the**
-    :func:`beartype._util.cache.pool.utilcachepoolobjecttyped.release_object_typed`
+    :func:`beartype._util.cache.pool.utilcachepoolinstance.release_instance`
     **function.** If accidentally omitted, this metadata will simply be
     garbage-collected rather than available for efficient reuse by this factory.
     Although hardly a worst-case outcome, omitting that explicit call largely
@@ -800,7 +800,7 @@ def make_beartype_call(**kwargs) -> BeartypeDecorMeta:
     '''
 
     # Acquire previously cached beartype call metadata from its object pool.
-    decor_meta = acquire_object_typed(BeartypeDecorMeta)
+    decor_meta = acquire_instance(BeartypeDecorMeta)
 
     # Reinitialize this metadata with the passed keyword parameters.
     decor_meta.reinit(**kwargs)
@@ -826,4 +826,4 @@ def cull_beartype_call(decor_meta: BeartypeDecorMeta) -> None:
     decor_meta.deinit()
 
     # Release this beartype call metadata back to its object pool.
-    release_object_typed(decor_meta)
+    release_instance(decor_meta)
