@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -67,7 +67,7 @@ class BeartypeHintOverrides(FrozenDict):
                     )
                 )
             ):
-                break
+                continue
 
             # Avoid circular import dependencies.
             #
