@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -21,6 +21,7 @@ from ast import (
     FunctionDef,
 )
 from beartype.typing import (
+    # TYPE_CHECKING,
     AbstractSet,
     Any,
     Callable,
@@ -34,19 +35,25 @@ from beartype.typing import (
     Literal,
     Mapping,
     Optional,
+    Set,
     Tuple,
     Type,
     TypeVar,
     Union,
 )
 from beartype._cave._cavefast import (
+    FunctionType,
+    HintPep604Type,
+    HintPep612ParamSpecType,
+    HintPep646TypeVarTupleType,
+    HintPep695TypeAlias,
     MethodBoundInstanceOrClassType,
     MethodDecoratorClassType,
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
-from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.func.datafuncarg import ARG_VALUE_UNPASSED
+from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_10
 from collections.abc import Callable as CallableABC
 from importlib.abc import PathEntryFinder
@@ -57,33 +64,6 @@ from types import (
     GeneratorType,
 )
 
-# ....................{ TYPEVARS                           }....................
-S = TypeVar('S')
-'''
-**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
-different types than the :data:`.T` type variable.
-'''
-
-
-T = TypeVar('T')
-'''
-**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
-different types than the :data:`.S` type variable.
-'''
-
-
-CallableT = TypeVar('CallableT', bound=CallableABC)
-'''
-**Callable type variable** (i.e., bound to match *only* callables).
-'''
-
-
-NodeT = TypeVar('NodeT', bound=AST)
-'''
-**Node type variable** (i.e., type variable constrained to match *only* abstract
-syntax tree (AST) nodes).
-'''
-
 # ....................{ AST                                }....................
 NodeCallable = Union[FunctionDef, AsyncFunctionDef]
 '''
@@ -162,28 +142,28 @@ PEP-compliant type hint matching any callable in a manner explicitly matching
 all possible callable signatures.
 '''
 
-# ....................{ TYPEVAR ~ early                    }....................
+# ....................{ PEP 484 ~ typevar : early          }....................
 # Type variables required by subsequent type hints below.
 
 BeartypeableT = TypeVar(
     'BeartypeableT',
     # The @beartype decorator decorates objects that are either...
     bound=Union[
-        # An arbitrary class *OR*...
+        # Arbitrary class *OR*...
         type,
 
-        # An arbitrary callable *OR*...
+        # Arbitrary callable *OR*...
         CallableAny,
 
-        # A C-based unbound class method descriptor (i.e., a pure-Python unbound
+        # C-based unbound class method descriptor (i.e., a pure-Python unbound
         # function decorated by the builtin @classmethod decorator) *OR*...
         MethodDecoratorClassType,
 
-        # A C-based unbound property method descriptor (i.e., a pure-Python
+        # C-based unbound property method descriptor (i.e., a pure-Python
         # unbound function decorated by the builtin @property decorator) *OR*...
         MethodDecoratorPropertyType,
 
-        # A C-based unbound static method descriptor (i.e., a pure-Python
+        # C-based unbound static method descriptor (i.e., a pure-Python
         # unbound function decorated by the builtin @staticmethod decorator).
         MethodDecoratorStaticType,
 
@@ -230,6 +210,13 @@ constraint *or* :data:`False` otherwise).
 '''
 
 
+CallableStrFormat = Callable[..., str]
+'''
+PEP-compliant type hint matching the signature of the standard
+:meth:`str.format` method.
+'''
+
+
 CallableTester = Callable[[object], bool]
 '''
 PEP-compliant type hint matching a **tester callable** (i.e., arbitrary callable
@@ -253,27 +240,6 @@ Specifically, this hint matches:
 * Pure-Python callable stack frames.
 '''
 
-
-MethodDescriptorNondata = Union[
-    # A C-based unbound class method descriptor (i.e., a pure-Python unbound
-    # function decorated by the builtin @classmethod decorator) *OR*...
-    MethodDecoratorClassType,
-
-    # A C-based unbound static method descriptor (i.e., a pure-Python
-    # unbound function decorated by the builtin @staticmethod decorator).
-    MethodDecoratorStaticType,
-
-    # A C-based bound method descriptor (i.e., a pure-Python unbound
-    # function bound to an object instance on Python's instantiation of that
-    # object) *OR*...
-    MethodBoundInstanceOrClassType,
-]
-'''
-PEP-compliant type hint matching any **builtin method non-data descriptor**
-(i.e., C-based descriptor builtin to Python defining only the ``__get__()``
-dunder method, encapsulating read-only access to some kind of method).
-'''
-
 # ....................{ CALLABLE ~ args                    }....................
 CallableMethodGetitemArg = Union[int, slice]
 '''
@@ -298,11 +264,44 @@ of the :func:`beartype.beartype` decorator, including calls to that decorator
 in both configuration and decoration modes.
 '''
 
-# ....................{ CALLABLE ~ decorator               }....................
-CallableStrFormat = Callable[..., str]
+# ....................{ CALLABLE ~ descriptor              }....................
+MethodDescriptorBuiltin = Union[
+    # C-based unbound class method descriptor (i.e., a pure-Python unbound
+    # function decorated by the builtin @classmethod decorator).
+    MethodDecoratorClassType,
+
+    # C-based unbound property method descriptor (i.e., a pure-Python unbound
+    # function decorated by the builtin @property decorator).
+    MethodDecoratorPropertyType,
+
+    # C-based unbound static method descriptor (i.e., a pure-Python unbound
+    # function decorated by the builtin @staticmethod decorator).
+    MethodDecoratorStaticType,
+]
 '''
-PEP-compliant type hint matching the signature of the standard
-:meth:`str.format` method.
+PEP-compliant type hint matching any **builtin unbound method descriptor**
+(i.e., C-based decorator type builtin to Python whose instance is typically
+uncallable but encapsulates a callable pure-Python method).
+'''
+
+
+MethodDescriptorNondata = Union[
+    # C-based unbound class method descriptor (i.e., a pure-Python unbound
+    # function decorated by the builtin @classmethod decorator).
+    MethodDecoratorClassType,
+
+    # C-based unbound static method descriptor (i.e., a pure-Python unbound
+    # function decorated by the builtin @staticmethod decorator).
+    MethodDecoratorStaticType,
+
+    # C-based bound method descriptor (i.e., a pure-Python unbound function
+    # bound to an object instance on Python's instantiation of that object).
+    MethodBoundInstanceOrClassType,
+]
+'''
+PEP-compliant type hint matching any **builtin method non-data descriptor**
+(i.e., C-based descriptor builtin to Python defining only the ``__get__()``
+dunder method, encapsulating read-only access to some kind of method).
 '''
 
 # ....................{ COLLECTION                         }....................
@@ -404,24 +403,6 @@ func_wrapper_scope, hint_refs_type_basename)``, where:
   List['YoClass']]``).
 '''
 
-# ....................{ FROZENSET                          }....................
-FrozenSetInts = FrozenSet[int]
-'''
-PEP-compliant type hint matching *any* frozen set of zero or more integers.
-'''
-
-
-FrozenSetStrs = FrozenSet[str]
-'''
-PEP-compliant type hint matching *any* frozen set of zero or more strings.
-'''
-
-
-FrozenSetTypes = FrozenSet[type]
-'''
-PEP-compliant type hint matching *any* frozen set of zero or more types.
-'''
-
 # ....................{ ITERABLE                           }....................
 IterableStrs = Iterable[str]
 '''
@@ -475,35 +456,86 @@ more shell words comprising a shell command, suitable for passing as the
 test-specific :mod:`beartype_test._util.command.pytcmdrun` submodule).
 '''
 
-# ....................{ TUPLE                              }....................
+# ....................{ SET ~ frozenset                    }....................
+FrozenSetInts = FrozenSet[int]
+'''
+PEP-compliant type hint matching *any* frozen set of zero or more integers.
+'''
+
+
+FrozenSetStrs = FrozenSet[str]
+'''
+PEP-compliant type hint matching *any* frozen set of zero or more strings.
+'''
+
+
+FrozenSetTypes = FrozenSet[type]
+'''
+PEP-compliant type hint matching *any* frozen set of zero or more types.
+'''
+
+# ....................{ TYPE                               }....................
+AbstractSetTypes = AbstractSet[type]
+'''
+:pep:`585`-compliant type hint matching *any* set of zero or more classes.
+'''
+
+
+IterableTypes = Iterable[type]
+'''
+PEP-compliant type hint matching an iterable of zero or more types.
+'''
+
+
+SetTypes = Set[type]
+'''
+PEP-compliant type hint matching a set of zero or more types.
+'''
+
+
 TupleTypes = Tuple[type, ...]
 '''
-PEP-compliant type hint matching a tuple of zero or more classes.
+:pep:`585`-compliant type hint matching a tuple of zero or more classes.
 
 Equivalently, this hint matches all tuples passable as the second parameters to
 the :func:`isinstance` and :func:`issubclass` builtins.
 '''
 
 
-#FIXME: *INSUFFICIENT.* Generalize this to additionally accept the types of PEP
-#604-compliant new unions (e.g., "int | str").
+IsBuiltinOrSubclassableTypes = Union[type, TupleTypes, HintPep604Type]
+'''
+PEP-compliant type hint matching any objects passable as the second parameter
+to the :func:`isinstance` and :func:`issubclass` builtins.
+
+Specifically, this hint matches either:
+
+* A single type.
+* A tuple of zero or more types.
+* A :pep:`604`-compliant **new union** (i.e., two or more types delimited by the
+  ``|`` operator under Python >= 3.10).
+'''
+
+
+SetOrTupleTypes = Union[TupleTypes, AbstractSetTypes]
+'''
+PEP-compliant type hint matching a set *or* tuple of zero or more types.
+'''
+
+
 TypeOrTupleTypes = Union[type, TupleTypes]
 '''
-PEP-compliant type hint matching either a single class *or* a tuple of zero or
-more classes.
-
-Equivalently, this hint matches all objects passable as the second parameters
-to the :func:`isinstance` and :func:`issubclass` builtins.
+PEP-compliant type hint matching either a type *or* tuple of zero or more types.
 '''
 
 
-SetOrTupleTypes = Union[AbstractSet[type], TupleTypes]
+TypeOrSetOrTupleTypes = Union[type, TupleTypes, AbstractSetTypes]
 '''
-PEP-compliant type hint matching a set *or* tuple of zero or more classes.
+PEP-compliant type hint matching either a type *or* set or tuple of zero or more
+types.
 '''
 
-# ....................{ TUPLE ~ stack                      }....................
-TypeStack = Optional[Tuple[type, ...]]
+
+TypeStack = Optional[TupleTypes]
 '''
 PEP-compliant type hint matching a **type stack** (i.e., either tuple of zero or
 more arbitrary types *or* :data:`None`).
@@ -635,6 +667,7 @@ instances definitely encapsulating pathnames).
 # edge cases, including recursive "beartype.HintOverrides" globally defined by
 # the "beartype._conf.confoverrides" submodule.
 
+#FIXME: Shift into the more appropriate "datahintpep" submodule, please.
 Pep484TowerComplex = (
     complex | float | int  # type: ignore[operator]
     if IS_PYTHON_AT_LEAST_3_10 else
@@ -656,9 +689,58 @@ Pep484TowerFloat = (
 (i.e., both floating-point numbers and integers).
 '''
 
+# ....................{ PEP 484 ~ typevar                  }....................
+S = TypeVar('S')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.T` and :data:`.U` type variables.
+'''
+
+
+T = TypeVar('T')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.S` and :data:`.U` type variables.
+'''
+
+
+U = TypeVar('U')
+'''
+**Unbound type variable** (i.e., matching *any* arbitrary type) locally bound to
+different types than the :data:`.S` and :data:`.T` type variables.
+'''
+
+
+CallableT = TypeVar('CallableT', bound=CallableABC)
+'''
+**Callable type variable** (i.e., bound to match *only* callables).
+'''
+
+
+NodeT = TypeVar('NodeT', bound=AST)
+'''
+**Node type variable** (i.e., type variable constrained to match *only* abstract
+syntax tree (AST) nodes).
+'''
+
+# ....................{ PEP 484 ~ typevar : container      }....................
+SetTypeVars = Set[TypeVar]
+'''
+:pep:`585`-compliant type hint matching a mutable set of zero or more
+:pep:`484`-compliant **type variables** (i.e., :class:`.TypeVar` objects).
+'''
+
+
+TupleTypeVars = Tuple[TypeVar, ...]
+'''
+:pep:`585`-compliant type hint matching a tuple of zero or more
+:pep:`484`-compliant **type variables** (i.e., :class:`.TypeVar` objects).
+'''
+
 # ....................{ PEP (484|585)                      }....................
 # Type hints required to fully comply with both PEP 484 *AND* 585.
 
+#FIXME: Shift into the more appropriate "datahintpep" submodule, please.
 Pep484585ForwardRef = Union[str, ForwardRef]
 '''
 Union of all :pep:`484`- or :pep:`585`-compliant **forward reference types**
@@ -666,10 +748,47 @@ Union of all :pep:`484`- or :pep:`585`-compliant **forward reference types**
 
 See Also
 --------
-:data:`HINT_PEP484585_FORWARDREF_TYPES`
+:data:`.HINT_PEP484585_FORWARDREF_TYPES`
     Further details.
 '''
 
+# ....................{ PEP (484|612|646)                  }....................
+# Type hints required to fully comply with PEP 484, 612, and 646 -- the
+# standards collectively covering type parameters.
+
+TypeParam = Union[TypeVar, HintPep612ParamSpecType, HintPep646TypeVarTupleType]
+'''
+PEP-compliant type hint matching a **type parameter** (i.e.,
+:pep:`484`-compliant type variable, pep:`612`-compliant parameter specification,
+or :pep:`646`-compliant type variable tuple).
+'''
+
+
+TupleTypeParams = Tuple[TypeParam, ...]
+'''
+:pep:`585`-compliant type hint matching a tuple of zero or more **type
+parameters** (i.e., :pep:`484`-compliant type variables, pep:`612`-compliant
+parameter specifications, or :pep:`646`-compliant type variable tuples).
+'''
+
+# ....................{ PEP 695                            }....................
+# Type hints required to fully comply with PEP 695.
+
+Pep695Parameterizable = Union[type, FunctionType, HintPep695TypeAlias]
+'''
+:pep:`695`-compliant type hint matching *any* :pep:`695` **parameterizable**
+(i.e., object that may be parametrized by a :pep:`695`-compliant list of one or
+more implicitly instantiated :pep:`484`-compliant type variables,
+pep:`612`-compliant parameter specifications, or :pep:`646`-compliant type
+variable tuples).
+
+Specifically, this hint matches:
+
+* *Any* pure-Python class.
+* *Any* pure-Python function.
+* *Any* :pep:`695`-compliant type alias.
+'''
+
 # ....................{ TYPE                               }....................
 TypeException = Type[Exception]
 '''
