@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -44,7 +44,6 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignForwardRef,
     HintSignFrozenSet,
     HintSignGenerator,
-    HintSignIO,
     HintSignItemsView,
     HintSignIterable,
     HintSignIterator,
@@ -64,8 +63,9 @@ from beartype._data.hint.pep.sign.datapepsigns import (
     HintSignParamSpec,
     HintSignParamSpecArgs,
     HintSignParamSpecKwargs,
+    HintSignPep484585GenericUnsubscripted,
     HintSignPep557DataclassInitVar,
-    HintSignPep695TypeAlias,
+    HintSignPep695TypeAliasUnsubscripted,
     HintSignReversible,
     HintSignSequence,
     HintSignSet,
@@ -113,9 +113,9 @@ HINT_REPR_PREFIX_ARGS_0_OR_MORE_TO_SIGN: DictStrToHintSign = {
     # PEP 484-compliant abstract base classes (ABCs) requiring non-standard and
     # non-trivial type-checking. Although most types are trivially type-checked
     # by the isinstance() builtin, these types break the mold in various ways.
+    "<class 'typing.IO'>":       HintSignPep484585GenericUnsubscripted,
     "<class 'typing.BinaryIO'>": HintSignBinaryIO,
-    "<class 'typing.IO'>": HintSignIO,
-    "<class 'typing.TextIO'>": HintSignTextIO,
+    "<class 'typing.TextIO'>":   HintSignTextIO,
 }
 '''
 Dictionary mapping from the **possibly unsubscripted PEP-compliant type hint
@@ -254,7 +254,8 @@ HINT_MODULE_NAME_TO_TYPE_BASENAME_TO_SIGN: Dict[str, DictStrToHintSign] = {
     # Standard builtins module.
     'builtins': {
         # ..................{ PEP 484                        }..................
-        # PEP 484-compliant forward reference type hints may be annotated either:
+        # PEP 484-compliant forward reference type hints may be annotated
+        # either:
         # * Explicitly as "typing.ForwardRef" instances, which automated
         #   inspection performed by the _init() function below already handles.
         # * Implicitly as strings, which this key-value pair here detects. Note
@@ -263,6 +264,7 @@ HINT_MODULE_NAME_TO_TYPE_BASENAME_TO_SIGN: Dict[str, DictStrToHintSign] = {
         #   * Absolute forward references (i.e., fully-qualified classnames)
         #     technically non-compliant with PEP 484 but seemingly compliant
         #     with PEP 585.
+        #
         #   Since the distinction between PEP-compliant and -noncompliant
         #   forward references is murky at best and since unconditionally
         #   matching *ALL* string as PEP-compliant substantially simplifies
@@ -376,6 +378,7 @@ HINTS_REPR_IGNORABLE_SHALLOW: FrozenSetStrs = {  # type: ignore[assignment]
     # ....................{ NON-PEP                        }....................
     # Machine-readable representations of shallowly ignorable type hints
     # published by PEP-noncompliant third-party type hints, including...
+    # ...absolutely nuthin', at the moment. :<>
 }
 '''
 Frozen set of all **shallowly ignorable PEP-compliant type hint
@@ -406,11 +409,9 @@ def _init() -> None:
     from beartype._data.hint.pep.sign.datapepsigns import (
         HintSignUnpack,
     )
-    from beartype._data.module.datamodtyping import TYPING_MODULE_NAMES
+    from beartype._data.api.standard.datamodtyping import TYPING_MODULE_NAMES
     from beartype._util.py.utilpyversion import (
         IS_PYTHON_3_11,
-        IS_PYTHON_AT_LEAST_3_9,
-        IS_PYTHON_3_8,
     )
 
     # ..................{ GLOBALS                            }..................
@@ -467,19 +468,6 @@ def _init() -> None:
         HINT_MODULE_NAME_TO_TYPE_BASENAME_TO_SIGN[
             'typing']['_UnpackGenericAlias'] = HintSignUnpack
     # Else, the active Python interpreter does *NOT* target Python 3.11.x.
-    #
-    # If the active Python interpreter targets Python 3.8.x, resynchronize the
-    # unqualified names and representations of desynchronized typing attributes.
-    # Bizarrely:
-    # * Python 3.7.0 first desynchronized these attributes, despite the
-    #   otherwise insane Python 3.6.x series having actually gotten this right.
-    # * Python 3.8.x preserved this bad behaviour.
-    # * Python 3.9.0 rectified this issue finally. *sigh*
-    elif IS_PYTHON_3_8:
-        _HINT_TYPING_ATTR_NAME_TO_REPR_PREFIX.update({
-            'AsyncContextManager': 'AbstractAsyncContextManager',
-            'ContextManager': 'AbstractContextManager',
-        })
 
     # ..................{ HINTS ~ types                      }..................
     # Dictionary mapping from the unqualified names of all classes defined by
@@ -499,7 +487,7 @@ def _init() -> None:
         # The unsubscripted PEP 484-compliant "Generic" superclass is
         # explicitly equivalent under PEP 484 to the "Generic[Any]"
         # subscription and thus slightly conveys meaningful semantics.
-        # 'Generic': HintSignGeneric,
+        # 'Generic': HintSignPep484585GenericUnsubscripted,
 
         # ....................{ PEP 612                    }....................
         # PEP 612-compliant "typing.ParamSpec" type hints as merely instances of
@@ -522,62 +510,58 @@ def _init() -> None:
         # ....................{ PEP 695                    }....................
         # PEP 695-compliant "type" aliases are merely instances of the low-level
         # C-based "typing.TypeAliasType" type.
-        'TypeAliasType': HintSignPep695TypeAlias,
+        'TypeAliasType': HintSignPep695TypeAliasUnsubscripted,
     }
 
     # ..................{ HINTS ~ deprecated                 }..................
     # Set of the unqualified names of all deprecated PEP 484-compliant typing
     # attributes.
-    _HINT_PEP484_TYPING_ATTR_NAMES_DEPRECATED: Set[str] = set()
-
-    # If the active Python interpreter targets Python >= 3.9 and thus
-    # supports PEP 585, add the names of all deprecated PEP 484-compliant
-    # typing attributes (e.g., "typing.List") that have since been obsoleted by
-    # equivalent bare PEP 585-compliant builtin classes (e.g., "list").
-    if IS_PYTHON_AT_LEAST_3_9:
-        _HINT_PEP484_TYPING_ATTR_NAMES_DEPRECATED.update((
-            # ..............{ PEP 484                            }..............
-            'AbstractSet',
-            'AsyncContextManager',
-            'AsyncGenerator',
-            'AsyncIterable',
-            'AsyncIterator',
-            'Awaitable',
-            'ByteString',
-            'Callable',
-            'ChainMap',
-            'Collection',
-            'Container',
-            'ContextManager',
-            'Coroutine',
-            'Counter',
-            'DefaultDict',
-            'Deque',
-            'Dict',
-            'FrozenSet',
-            'Generator',
-            'Hashable',
-            'ItemsView',
-            'Iterable',
-            'Iterator',
-            'KeysView',
-            'List',
-            'MappingView',
-            'Mapping',
-            'Match',
-            'MutableMapping',
-            'MutableSequence',
-            'MutableSet',
-            'OrderedDict',
-            'Pattern',
-            'Reversible',
-            'Sequence',
-            'Set',
-            'Sized',
-            'Tuple',
-            'Type',
-            'ValuesView',
-        ))
+    _HINT_PEP484_TYPING_ATTR_NAMES_DEPRECATED: Set[str] = {
+        # ..................{ PEP ~ 484                      }..................
+        # Unqualified basenames of all deprecated PEP 484-compliant
+        # typing attributes (e.g., "typing.List") that have since been obsoleted
+        # by equivalent bare PEP 585-compliant builtin classes (e.g., "list").
+        'AbstractSet',
+        'AsyncContextManager',
+        'AsyncGenerator',
+        'AsyncIterable',
+        'AsyncIterator',
+        'Awaitable',
+        'ByteString',
+        'Callable',
+        'ChainMap',
+        'Collection',
+        'Container',
+        'ContextManager',
+        'Coroutine',
+        'Counter',
+        'DefaultDict',
+        'Deque',
+        'Dict',
+        'FrozenSet',
+        'Generator',
+        'Hashable',
+        'ItemsView',
+        'Iterable',
+        'Iterator',
+        'KeysView',
+        'List',
+        'MappingView',
+        'Mapping',
+        'Match',
+        'MutableMapping',
+        'MutableSequence',
+        'MutableSet',
+        'OrderedDict',
+        'Pattern',
+        'Reversible',
+        'Sequence',
+        'Set',
+        'Sized',
+        'Tuple',
+        'Type',
+        'ValuesView',
+    }
 
     # ..................{ HINTS ~ ignorable                  }..................
     # Set of the unqualified names of all shallowly ignorable typing non-class
@@ -615,7 +599,6 @@ def _init() -> None:
         #     True
         #
         # This intentionally excludes:
-        #
         # * The "Union[Any]" and "Union[object]" singletons, since the "typing"
         #   module physically reduces:
         #   * "Union[Any]" to merely "Any" (i.e., "Union[Any] is Any"), which
@@ -636,8 +619,8 @@ def _init() -> None:
     _HINT_TYPING_TYPE_NAMES_IGNORABLE = {
         # ................{ PEP 484                            }................
         # The "Generic" superclass imposes no constraints and is thus also
-        # semantically synonymous with the "object" superclass. Since PEP
-        # 484 stipulates that *ANY* unsubscripted subscriptable PEP-compliant
+        # semantically synonymous with the "object" superclass. Since PEP 484
+        # stipulates that *ANY* unsubscripted subscriptable PEP-compliant
         # singleton including "typing.Generic" semantically expands to that
         # singleton subscripted by an implicit "Any" argument, "Generic"
         # semantically expands to the implicit "Generic[Any]" singleton.
@@ -704,7 +687,7 @@ def _init() -> None:
             #something resembling:
             ## In global scope above:
             #_HINT_SIGN_REPLACE_SOURCE_BY_TARGET = {
-            #    HintSignProtocol: HintSignGeneric,
+            #    HintSignProtocol: HintSignPep484585GenericUnsubscripted,
             #}
             #
             #    # In this iteration here:
