@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -26,7 +26,9 @@ from beartype._data.hint.datahinttyping import (
     BeartypeableT,
     TypeStack,
 )
+from beartype._decor._nontype._pep._decorpep557 import beartype_pep557_dataclass
 from beartype._util.cls.utilclsset import set_type_attr
+from beartype._util.cls.pep.clspep557 import is_type_pep557_dataclass
 from beartype._util.module.utilmodget import get_object_module_name_or_none
 from collections import defaultdict
 from functools import wraps
@@ -160,52 +162,11 @@ def beartype_type(
     # For the unqualified name and value of each direct (i.e., *NOT* indirectly
     # inherited) attribute of this class...
     for attr_name, attr_value in cls.__dict__.items():  # pyright: ignore[reportGeneralTypeIssues]
-        # True only if this attribute is directly beartypeable (e.g., is either
-        # a function, class, or builtin method descriptor).
-        is_attr_beartypeable = isinstance(attr_value, TYPES_BEARTYPEABLE)
-
-        # If this attribute is *NOT* directly beartypeable (e.g., is neither a
-        # function, class, nor builtin method descriptor), this attribute
-        # *COULD* still be indirectly beartypeable. How? By being a non-standard
-        # object implemented by some third-party package wrapping a standard
-        # object that *is* directly beartypeable. Although the original use case
-        # was non-standard function wrappers implemented by the third-party
-        # Equinox package, this logic transparently generalizes to *ALL*
-        # third-party packages. Consequently, *ALL* third-party packages
-        # defining non-standard objects wrapping standard objects should
-        # endeavour to support @beartype by reproducing the general-purpose
-        # solution that Equinox adopted.
-        #
-        # Notably, third-party packages should ideally add "support for such
-        # monkey-patching, by adding a __setattr__() that checks for functions
-        # and wraps them into one of Equinox's function-wrappers." See also:
-        #     https://github.com/patrick-kidger/equinox/issues/584#issuecomment-1806260288
-        #
-        # Specifically, if this attribute is *NOT* directly beartypeable...
-        if not is_attr_beartypeable:
-            # Uncomment to debug this insanity. *sigh*
-            # attr_value_old = attr_value
-
-            # Override the previously retrieved static value of this attribute
-            # (i.e., the direct value of this attribute *WITHOUT* regard to
-            # dynamic descriptor lookup, which in the case of a standard
-            # descriptor builtin like @classmethod is that C-based @classmethod
-            # descriptor itself) with the dynamic value of this attribute
-            # (i.e., the indirect value of this attribute *WITH* regard to
-            # dynamic descriptor lookup, which in the case of a standard
-            # descriptor builtin like @classmethod is the pure-Python function
-            # wrapped by that C-based @classmethod descriptor) if this attribute
-            # supports the descriptor protocol *OR* reduce to a noop otherwise.
-            attr_value = getattr(cls, attr_name)
-
-            # True only if this attribute is directly beartypeable.
-            is_attr_beartypeable = isinstance(attr_value, TYPES_BEARTYPEABLE)
-        # Else, this attribute is directly beartypeable.
-
         # If this attribute is...
         if (
-            # Now directly beartypeable *AND*...
-            is_attr_beartypeable and
+            # True only if this attribute is directly beartypeable (e.g., is either
+            # a function, class, or builtin method descriptor).
+            isinstance(attr_value, TYPES_BEARTYPEABLE) and
             # It is *NOT* the case that...
             #
             # Note that this condition intentionally ignores class variables
@@ -260,21 +221,44 @@ def beartype_type(
                 not attr_value.__qualname__.startswith(cls.__qualname__)
             )
         ):
+            # print(f'Decorating {repr(cls)} attribute "{attr_name}"...')
+
             # This attribute decorated with type-checking configured by this
             # configuration if *NOT* already decorated.
-            attr_value_beartyped = beartype_object(
-                obj=attr_value,
-                conf=conf,
-                cls_stack=cls_stack,
-            )
+            attr_value_beartyped = beartype_object(  # type: ignore[type-var]
+                obj=attr_value, conf=conf, cls_stack=cls_stack)
 
-            # Replace this undecorated attribute with this decorated attribute.
-            set_type_attr(cls, attr_name, attr_value_beartyped)
-            # print(f'Decorating {repr(cls)} attribute "{attr_name}"...')
+            # If this decorated attribute differs from the original attribute,
+            # @beartype actually decorated this attribute with type-checking. In
+            # this case...
+            if attr_value_beartyped is not attr_value:
+                # Safely replace this undecorated attribute with this decorated
+                # attribute.
+                set_type_attr(cls, attr_name, attr_value_beartyped)
+                # print(f'Decorated {repr(cls)} attribute "{attr_name}".')
+            # Else, this decorated attribute is the same as the original
+            # attribute, implying that @beartype refused to decorate this
+            # attribute with type-checking (e.g., due to this attribute being
+            # unannotated by type hints). In this case, silently preserve this
+            # attribute as is rather than brutally and uselessly replacing this
+            # attribute with itself.
             # print(f'type: {type(attr_value)}; dir: {dir(attr_value)}')
         # Else, this attribute is *NOT* beartypeable. In this case, silently
         # ignore this attribute.
 
+    # ....................{ DECORATION ~ pep               }....................
+    # If...
+    if (
+        # This beartype configuration enables type-checking of PEP 557-compliant
+        # dataclasses *AND*...
+        conf.is_check_pep557 and
+        # This class is a PEP 557-compliant dataclass...
+        is_type_pep557_dataclass(cls)
+    ):
+        # Monkey-patch type-checking of *ALL* PEP 557-compliant dataclass fields
+        # into this dataclass.
+        beartype_pep557_dataclass(datacls=cls, conf=conf)
+
     # ....................{ MONKEY-PATCH                   }....................
     # Pure-Python __sizeof__() dunder method wrapping the original C-based
     # __sizeof__() dunder method declared by this class.
@@ -403,13 +387,13 @@ def _uncache_beartype_if_type_redefined(cls: type) -> None:
 
             # Clear *ALL* type-checking caches. Notably:
             # * The forward reference referee cache (i.e., private
-            #   "beartype._check.forward.reference.fwdrefmeta._forwardref_to_referee"
+            #   "beartype._check.forward.reference.fwdrefmeta._forwardref_to_referent"
             #   dictionary) is problematic, due to mapping from forward
             #   reference proxies (which are themselves classes) to arbitrary
             #   (and thus usually user-defined) classes -- one or more of which
             #   might be this class or other similarly redefined classes.
             # * The type hint coercion cache (i.e., private
-            #   "beartype._check.convert.convcoerce._hint_repr_to_hint"
+            #   "beartype._check.convert._convcoerce._hint_repr_to_hint"
             #   dictionary) is problematic, due to mapping from the
             #   machine-readable representations of previously seen
             #   non-self-cached type hints (e.g., "list[MuhClass]") to the first
