@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -18,50 +18,53 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.roar import (
-    BeartypeDecorHintParamDefaultForwardRefWarning,
-    BeartypeDecorHintParamDefaultViolation,
+    # BeartypeDecorHintParamDefaultForwardRefWarning,
+    # BeartypeDecorHintParamDefaultViolation,
     BeartypeDecorHintPepException,
     BeartypeDecorParamNameException,
 )
-from beartype.roar._roarexc import _BeartypeHintForwardRefExceptionMixin
+# from beartype.roar._roarexc import _BeartypeHintForwardRefExceptionMixin
 from beartype.typing import (
+    Any,
     Optional,
     Set,
 )
 from beartype._check.metadata.metadecor import BeartypeDecorMeta
+from beartype._check.metadata.metasane import (
+    HintOrSanifiedData,
+    # HintSanifiedData,
+)
 from beartype._check.checkmagic import ARG_NAME_ARGS_NAME_KEYWORDABLE
 from beartype._check.checkmake import make_code_raiser_func_pith_check
 from beartype._check.convert.convsanify import sanify_hint_root_func
-from beartype._conf.confcls import BeartypeConf
+# from beartype._conf.confcls import BeartypeConf
 from beartype._data.error.dataerrmagic import EXCEPTION_PLACEHOLDER
 from beartype._data.func.datafuncarg import ARG_NAME_RETURN
+from beartype._data.hint.datahintpep import Hint
 from beartype._data.hint.datahinttyping import LexicalScope
 from beartype._decor.wrap.wrapsnip import (
     CODE_INIT_ARGS_LEN,
-    EXCEPTION_PREFIX_DEFAULT,
+    # EXCEPTION_PREFIX_DEFAULT,
     ARG_KIND_TO_CODE_LOCALIZE,
 )
 from beartype._decor.wrap._wraputil import unmemoize_func_wrapper_code
 from beartype._util.error.utilerrraise import reraise_exception_placeholder
 from beartype._util.error.utilerrwarn import (
-    issue_warning,
+    # issue_warning,
     reissue_warnings_placeholder,
 )
 from beartype._util.func.arg.utilfuncargiter import (
     ArgKind,
-    ArgMandatory,
+    # ArgMandatory,
     iter_func_args,
 )
 from beartype._util.func.arg.utilfuncargtest import is_func_arg_variadic_keyword
-from beartype._util.hint.utilhinttest import (
-    is_hint_ignorable,
-    is_hint_needs_cls_stack,
-)
+from beartype._util.hint.utilhinttest import is_hint_needs_cls_stack
 from beartype._util.kind.map.utilmapset import update_mapping
-from beartype._util.text.utiltextmunge import lowercase_str_char_first
+# from beartype._util.text.utiltextmunge import lowercase_str_char_first
 from beartype._util.text.utiltextprefix import (
     prefix_callable_arg_name,
-    prefix_pith_value,
+    # prefix_pith_value,
 )
 from beartype._util.utilobject import SENTINEL
 from warnings import catch_warnings
@@ -69,9 +72,9 @@ from warnings import catch_warnings
 # ....................{ CODERS                             }....................
 def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
     '''
-    Generate a Python code snippet type-checking all annotated parameters of
-    the decorated callable if any *or* the empty string otherwise (i.e., if
-    these parameters are unannotated).
+    Generate a Python code snippet type-checking all annotated parameters of the
+    decorated callable if any *or* the empty string otherwise (i.e., if these
+    parameters are unannotated).
 
     Parameters
     ----------
@@ -134,8 +137,13 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
     #FIXME: Remove the "args_name_keywordable" local variable and associated
     #"ARG_NAME_ARGS_NAME_KEYWORDABLE" global variable *AFTER* refactoring
     #@beartype to generate callable-specific wrapper signatures.
+
     # Either...
     args_name_keywordable: Optional[Set[str]] = (
+        #FIXME: [SPEED] Minor optimization. If the decorated callable *ONLY*
+        #accepts an annotated variadic keyword parameter and no other
+        #parameters, then the empty set reused from a global "SET_EMPTY" import
+        #suffices here. Probably. Consider, anyway. *sigh*
         # If the decorated callable accepts an annotated variadic keyword
         # parameter (e.g., "**kwargs: int"), the set of the names of all
         # keywordable parameters (i.e., parameters that may be passed by
@@ -165,13 +173,14 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
     )
 
     # ..................{ LOCALS ~ hint                      }..................
-    # Type hint annotating the current parameter if any *OR* "_PARAM_HINT_EMPTY"
-    # otherwise (i.e., if this parameter is unannotated).
-    hint_insane = None
+    # Possibly insane hint annotating the current parameter if any *OR* the
+    # sentinel placeholder otherwise (i.e., if this parameter is unannotated).
+    hint_insane: Hint = None  # type: ignore[assignment]
 
-    # This type hint sanitized into a possibly different type hint more readily
-    # consumable by @beartype's code generator.
-    hint = None
+    # Sane hint annotating the current parameter sanified from this possibly
+    # insane hint if sanifying this hint generated no supplementary metadata
+    # *OR* that metadata otherwise.
+    hint_or_sane: HintOrSanifiedData = None  # type: ignore[assignment]
 
     # ..................{ GENERATE                           }..................
     #FIXME: Locally remove the "arg_index" local variable (and thus avoid
@@ -232,7 +241,8 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
         # Note that "None" is a semantically meaningful PEP 484-compliant type
         # hint equivalent to "type(None)". Ergo, we *MUST* explicitly
         # distinguish between that type hint and unannotated parameters.
-        hint_insane = decor_meta.func_arg_name_to_hint_get(arg_name, SENTINEL)
+        hint_insane = decor_meta.func_arg_name_to_hint_get(  # type: ignore[assignment]
+            arg_name, SENTINEL)
 
         # If this parameter is unannotated, continue to the next parameter.
         if hint_insane is SENTINEL:
@@ -249,24 +259,23 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
                 if arg_name.startswith('__bear'):
                     raise BeartypeDecorParamNameException(
                         f'{EXCEPTION_PLACEHOLDER}reserved by @beartype.')
+                # Else, this parameter's name is *NOT* reserved for use by the
+                # @beartype decorator.
 
-                # Sanitize this hint into a possibly different type hint more
-                # readily consumable by @beartype's code generator *BEFORE*
-                # passing this hint to any further callables.
-                hint = sanify_hint_root_func(
-                    hint=hint_insane,
+                # Sane hint sanified from this possibly insane parameter hint if
+                # sanifying this hint generated no supplementary metadata *OR*
+                # that metadata otherwise. Additionally, if this hint is
+                # unsupported by @beartype, raise an exception.
+                hint_or_sane = sanify_hint_root_func(
                     decor_meta=decor_meta,
+                    hint=hint_insane,
                     pith_name=arg_name,
                     arg_kind=arg_kind,
+                    exception_prefix=EXCEPTION_PLACEHOLDER,
                 )
 
                 # If this hint is ignorable, continue to the next parameter.
-                #
-                # Note that this is intentionally tested *AFTER* this hint has
-                # been coerced into a PEP-compliant type hint to implicitly
-                # ignore PEP-noncompliant type hints as well (e.g., "(object,
-                # int, str)").
-                if is_hint_ignorable(hint):
+                if hint_or_sane is Any:
                     # print(f'Ignoring {decor_meta.func_name} parameter {arg_name} hint {repr(hint)}...')
                     continue
                 # Else, this hint is unignorable.
@@ -311,6 +320,9 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
                     is_args_positional = True
                 # Else, this parameter *CANNOT* be passed positionally.
 
+                #FIXME: [SPEED] Negligibly optimized the ".get" access away:
+                #    ARG_LOCALIZE_TEMPLATE = ARG_KIND_TO_CODE_LOCALIZE_get(  # type: ignore
+                #        arg_kind, None)
                 # Python code template localizing this parameter if this kind of
                 # parameter is supported *OR* "None" otherwise.
                 ARG_LOCALIZE_TEMPLATE = ARG_KIND_TO_CODE_LOCALIZE.get(  # type: ignore
@@ -328,6 +340,20 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
                 # Else, this kind of parameter is supported. Ergo, this code is
                 # non-"None".
 
+                #FIXME: DRY violation. The same logic appears in "_wrapreturn"
+                #as well. It looks like what we *PROBABLY* want to do here is:
+                #* Rename the existing make_code_raiser_func_pith_check()
+                #  factory to _make_code_raiser_func_pith_check_cached().
+                #* Define a new make_code_raiser_func_pith_check() factory that
+                #  is unmemoized and has a simpler public API. Notably, this new
+                #  factory should:
+                #  * Accept a new "decor_meta" parameter.
+                #  * Drop the existing "conf" and "cls_stack" parameters.
+                #  * Pass parameters by keyword rather than positionally. This
+                #    would be especially useful for the "is_param" parameter,
+                #    which would suddenly become readable below.
+                #  * Internally compute the "cls_stack" as given below.
+
                 # Type stack if required by this hint *OR* "None" otherwise. See
                 # the is_hint_needs_cls_stack() tester for further discussion.
                 #
@@ -355,7 +381,7 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
                     func_scope,
                     hint_refs_type_basename,
                 ) = make_code_raiser_func_pith_check(
-                    hint,
+                    hint_or_sane,
                     decor_meta.conf,
                     cls_stack,
                     True,  # <-- True only for parameters
@@ -415,6 +441,7 @@ def code_check_args(decor_meta: BeartypeDecorMeta) -> str:
                 ),
             )
 
+    # ..................{ RETURN                             }..................
     # If that callable accepts an annotated variadic keyword parameter, expose
     # the set of the names of all keywordable parameters to this wrapper
     # function needed to type-check that annotated variadic keyword parameter.
@@ -449,123 +476,121 @@ _ARG_KINDS_POSITIONAL = frozenset((
     ArgKind.POSITIONAL_OR_KEYWORD,
 ))
 '''
-Frozen set of all **positional parameter kinds** (i.e.,
-:attr:`ArgKind` enumeration members signifying that a callable parameter
-either may *or* must be passed positionally).
+Frozen set of all **positional parameter kinds** (i.e., :class:`.ArgKind`
+enumeration members signifying that a callable parameter either may *or* must be
+passed positionally).
 '''
 
 # ....................{ PRIVATE ~ raisers                  }....................
-def _die_if_arg_default_unbearable(
-    decor_meta: BeartypeDecorMeta, arg_default: object, hint: object) -> None:
-    '''
-    Raise a violation exception if the annotated optional parameter of the
-    decorated callable with the passed default value violates the type hint
-    annotating that parameter at decoration time.
-
-    Parameters
-    ----------
-    decor_meta : BeartypeDecorMeta
-        Decorated callable to be type-checked.
-    arg_default : object
-        Either:
-
-        * If this parameter is mandatory, the :data:`.ArgMandatory` singleton.
-        * If this parameter is optional, the default value of this optional
-          parameter to be type-checked.
-    hint : object
-        Type hint to type-check against this default value.
-
-    Warns
-    -----
-    BeartypeDecorHintParamDefaultForwardRefWarning
-        If this type hint contains one or more forward references that *cannot*
-        be resolved at decoration time. While this does *not* necessarily
-        constitute a fatal error from the end user perspective, this does
-        constitute a non-fatal issue worth informing the end user of.
-
-    Raises
-    ------
-    BeartypeDecorHintParamDefaultViolation
-        If this default value violates this type hint.
-    '''
-
-    # ..................{ PREAMBLE                           }..................
-    # If this parameter is mandatory, silently reduce to a noop.
-    if arg_default is ArgMandatory:
-        return
-    # Else, this parameter is optional and thus defaults to a default value.
-
-    assert isinstance(decor_meta, BeartypeDecorMeta), (
-        f'{repr(decor_meta)} not beartype call.')
-
-    # ..................{ IMPORTS                            }..................
-    # Defer heavyweight imports prohibited at global scope.
-    from beartype.door import (
-        die_if_unbearable,
-        is_bearable,
-    )
-
-    # ..................{ MAIN                               }..................
-    # Attempt to...
-    try:
-        # If this default value satisfies this hint, silently reduce to a noop.
-        #
-        # Note that this is a non-negligible optimization. Technically, this
-        # preliminary test is superfluous: only the call to the
-        # die_if_unbearable() raiser below is required. Pragmatically, this
-        # preliminary test avoids a needlessly expensive dictionary copy in the
-        # common case that this value satisfies this hint.
-        if is_bearable(
-            obj=arg_default,
-            hint=hint,
-            conf=decor_meta.conf,
-        ):
-            return
-        # Else, this default value violates this hint.
-    # If doing so raises a forward hint exception, this hint contains one or
-    # more unresolvable forward references to user-defined objects that have yet
-    # to be defined. In all likelihood, these objects are subsequently defined
-    # after the definition of this decorated callable. While this does *NOT*
-    # necessarily constitute a fatal error from the end user perspective, this
-    # does constitute a non-fatal issue worth informing the end user of. In this
-    # case, we coerce this exception into a warning.
-    except _BeartypeHintForwardRefExceptionMixin as exception:
-        # Forward hint exception message raised above. To readably embed this
-        # message in the longer warning message emitted below, the first
-        # character of this message is lowercased as well.
-        exception_message = lowercase_str_char_first(str(exception))
-
-        # Emit this non-fatal warning.
-        issue_warning(
-            cls=BeartypeDecorHintParamDefaultForwardRefWarning,
-            message=(
-                f'{EXCEPTION_PREFIX_DEFAULT}value '
-                f'{prefix_pith_value(pith=arg_default, is_color=decor_meta.conf.is_color)}'
-                f'uncheckable at @beartype decoration time, as '
-                f'{exception_message}'
-            ),
-        )
-
-        # Loudly reduce to a noop. Since this forward reference is unresolvable,
-        # further type-checking attempts are entirely fruitless.
-        return
-
-    # Modifiable keyword dictionary encapsulating this beartype configuration.
-    conf_kwargs = decor_meta.conf.kwargs.copy()
-
-    #FIXME: This should probably be configurable as well. For now, this is fine.
-    #We shrug noncommittally. We shrug, everyone! *shrug*
-    # Set the type of violation exception raised by the subsequent call to the
-    # die_if_unbearable() function to the expected type.
-    conf_kwargs['violation_door_type'] = BeartypeDecorHintParamDefaultViolation
-
-    # New beartype configuration initialized by this dictionary.
-    conf = BeartypeConf(**conf_kwargs)
-
-    # Raise this type of violation exception.
-    die_if_unbearable(
-        obj=arg_default,
-        hint=hint,
-        conf=conf,
-        exception_prefix=EXCEPTION_PREFIX_DEFAULT,
-    )
+#FIXME: Preserved for posterity. We'll almost certainly want to restore this at
+#some future date. Until then, we sigh. *sigh*
+# def _die_if_arg_default_unbearable(
+#     decor_meta: BeartypeDecorMeta, arg_default: object, hint: Hint) -> None:
+#     '''
+#     Raise a violation exception if the annotated optional parameter of the
+#     decorated callable with the passed default value violates the type hint
+#     annotating that parameter at decoration time.
+#
+#     Parameters
+#     ----------
+#     decor_meta : BeartypeDecorMeta
+#         Decorated callable to be type-checked.
+#     arg_default : object
+#         Either:
+#
+#         * If this parameter is mandatory, the :data:`.ArgMandatory` singleton.
+#         * If this parameter is optional, the default value of this optional
+#           parameter to be type-checked.
+#     hint : Hint
+#         Type hint to type-check against this default value.
+#
+#     Warns
+#     -----
+#     BeartypeDecorHintParamDefaultForwardRefWarning
+#         If this type hint contains one or more forward references that *cannot*
+#         be resolved at decoration time. While this does *not* necessarily
+#         constitute a fatal error from the end user perspective, this does
+#         constitute a non-fatal issue worth informing the end user of.
+#
+#     Raises
+#     ------
+#     BeartypeDecorHintParamDefaultViolation
+#         If this default value violates this type hint.
+#     '''
+#     assert isinstance(decor_meta, BeartypeDecorMeta), (
+#         f'{repr(decor_meta)} not beartype call.')
+#
+#     # ..................{ PREAMBLE                           }..................
+#     # If this parameter is mandatory, silently reduce to a noop.
+#     if arg_default is ArgMandatory:
+#         return
+#     # Else, this parameter is optional and thus defaults to a default value.
+#
+#     # ..................{ IMPORTS                            }..................
+#     # Defer heavyweight imports prohibited at global scope.
+#     from beartype.door import (
+#         die_if_unbearable,
+#         is_bearable,
+#     )
+#
+#     # ..................{ MAIN                               }..................
+#     # Attempt to...
+#     try:
+#         # If this default value satisfies this hint, silently reduce to a noop.
+#         #
+#         # Note that this is a non-negligible optimization. Technically, this
+#         # preliminary test is superfluous: only the call to the
+#         # die_if_unbearable() raiser below is required. Pragmatically, this
+#         # preliminary test avoids a needlessly expensive dictionary copy in the
+#         # common case that this value satisfies this hint.
+#         if is_bearable(obj=arg_default, hint=hint, conf=decor_meta.conf):
+#             return
+#         # Else, this default value violates this hint.
+#     #FIXME: Probably generalize this to *ANY* exception whatsoever, no?
+#     # If doing so raises a forward hint exception, this hint contains one or
+#     # more unresolvable forward references to user-defined objects that have yet
+#     # to be defined. In all likelihood, these objects are subsequently defined
+#     # after the definition of this decorated callable. While this does *NOT*
+#     # necessarily constitute a fatal error from the end user perspective, this
+#     # does constitute a non-fatal issue worth informing the end user of. In this
+#     # case, we coerce this exception into a warning.
+#     except _BeartypeHintForwardRefExceptionMixin as exception:
+#         # Forward hint exception message raised above. To readably embed this
+#         # message in the longer warning message emitted below, the first
+#         # character of this message is lowercased as well.
+#         exception_message = lowercase_str_char_first(str(exception))
+#
+#         # Emit this non-fatal warning.
+#         issue_warning(
+#             cls=BeartypeDecorHintParamDefaultForwardRefWarning,
+#             message=(
+#                 f'{EXCEPTION_PREFIX_DEFAULT}value '
+#                 f'{prefix_pith_value(pith=arg_default, is_color=decor_meta.conf.is_color)}'
+#                 f'uncheckable at @beartype decoration time, as '
+#                 f'{exception_message}'
+#             ),
+#         )
+#
+#         # Loudly reduce to a noop. Since this forward reference is unresolvable,
+#         # further type-checking attempts are entirely fruitless.
+#         return
+#
+#     # Modifiable keyword dictionary encapsulating this beartype configuration.
+#     conf_kwargs = decor_meta.conf.kwargs.copy()
+#
+#     #FIXME: This should probably be configurable as well. For now, this is fine.
+#     #We shrug noncommittally. We shrug, everyone! *shrug*
+#     # Set the type of violation exception raised by the subsequent call to the
+#     # die_if_unbearable() function to the expected type.
+#     conf_kwargs['violation_door_type'] = BeartypeDecorHintParamDefaultViolation
+#
+#     # New beartype configuration initialized by this dictionary.
+#     conf = BeartypeConf(**conf_kwargs)
+#
+#     # Raise this type of violation exception.
+#     die_if_unbearable(
+#         obj=arg_default,
+#         hint=hint,
+#         conf=conf,
+#         exception_prefix=EXCEPTION_PREFIX_DEFAULT,
+#     )
