@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -21,7 +21,7 @@ from beartype.typing import (
 from beartype._data.hint.datahinttyping import (
     TypeException,
 )
-from beartype._data.kind.datakinddict import DICT_EMPTY
+from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
 from beartype._util.func.arg.utilfuncarglen import get_func_args_lens
 from beartype._util.utilobject import Iota
 from collections.abc import Callable
@@ -257,7 +257,7 @@ def iter_func_args(
 
         * This generator to transparently support bound method descriptors,
           which then enables...
-        * The private :func:`beartype._decor._decornontype.beartype_pseudofunc`
+        * The private :func:`beartype._decor._nontype.decornontype.beartype_pseudofunc`
           decorator to type-check the bound ``__call__()`` method descriptor
           encapsulating the unbound ``__call__()`` dunder method defined on the
           class of pseudo-callable objects, which then enables...
@@ -418,7 +418,7 @@ def iter_func_args(
     #     True
     #     >>> {} is {}
     #     False
-    args_defaults_kwonly = func.__kwdefaults__ or DICT_EMPTY  # type: ignore[attr-defined]
+    args_defaults_kwonly = func.__kwdefaults__ or FROZENDICT_EMPTY  # type: ignore[attr-defined]
 
     # ..................{ LOCALS ~ len                       }..................
     # Number of both optional and mandatory positional-only parameters accepted
@@ -557,7 +557,7 @@ def iter_func_args(
             # * Handling this common edge case enables:
             #   * This generator to transparently support bound method
             #     descriptors, which then enables...
-            #   * The private @beartype._decor._decornontype.beartype_pseudofunc
+            #   * The private @beartype._decor._nontype.decornontype.beartype_pseudofunc
             #     decorator to type-check the bound __call__() method descriptor
             #     encapsulating the unbound __call__() dunder method defined on
             #     the class of pseudo-callable objects, which then enables...
