@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -338,14 +338,14 @@ def get_func_args_flexible_len(
     '''
 
     # Avoid circular import dependencies.
-    from beartype._util.api.utilapifunctools import (
+    from beartype._util.api.standard.utilfunctools import (
         get_func_functools_partial_args_flexible_len,
         is_func_functools_partial,
     )
-    from beartype._util.func.utilfunctest import is_func_python
+    from beartype._util.func.utilfunctest import is_func_codeobjable
 
     # If the passed callable is pure-Python...
-    if is_func_python(func):
+    if is_func_codeobjable(func):
         # Number of various kinds of parameters accepted by that callable.
         func_args_lens = get_func_args_lens(
             func=func,
