@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -17,7 +17,7 @@ from collections.abc import Callable
 # ....................{ TESTERS                            }....................
 def is_func_pep484_notypechecked(func: Callable) -> bool:
     '''
-    ``True`` only if the passed callable was decorated by the
+    :data:`True` only if the passed callable was decorated by the
     :pep:`484`-compliant :func:`typing.no_type_check` decorator instructing
     both static and runtime type checkers to ignore that callable with respect
     to type-checking (and thus preserve that callable as is).
@@ -28,9 +28,9 @@ def is_func_pep484_notypechecked(func: Callable) -> bool:
         Callable to be inspected.
 
     Returns
-    ----------
+    -------
     bool
-        ``True`` only if that callable was decorated by the
+        :data:`True` only if that callable was decorated by the
         :pep:`484`-compliant :func:`typing.no_type_check` decorator.
     '''
 
