@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -27,7 +27,7 @@ from types import (
     FrameType,
     FunctionType,
     GeneratorType,
-    MethodType,
+    # MethodType,
 )
 
 # ....................{ GETTERS                            }....................
