@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -25,7 +25,7 @@ from beartype._data.hint.datahinttyping import (
     LexicalScope,
     TypeException,
 )
-from beartype._data.kind.datakinddict import DICT_EMPTY
+from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
 from collections.abc import Callable
 from types import CodeType
 
@@ -222,13 +222,8 @@ def get_func_locals(
     from beartype._util.module.utilmodget import get_object_module_name_or_none
 
     # ..................{ NOOP                               }..................
-    # Fully-qualified name of the module declaring the passed callable if that
-    # callable was physically declared by an on-disk module *OR* "None"
-    # otherwise (i.e., if that callable was dynamically declared in-memory).
-    func_module_name = get_object_module_name_or_none(func)
-
     # Note that we intentionally return the local scope for this wrapper rather
-    # than wrappee callable, as local scope can *ONLY* be obtained by
+    # than wrappee callable, as a local scope can *ONLY* be obtained by
     # dynamically inspecting local attributes bound to call frames on the
     # current call stack. However, this wrapper was called at a higher call
     # frame than this wrappee. All local attributes declared within the body of
@@ -237,7 +232,12 @@ def get_func_locals(
     # returned the local scope for this wrappee rather than wrapper callable,
     # we would erroneously return local attributes that this wrappee callable
     # originally had no lexical access to. That's bad. So, we don't do that.
-    #
+
+    # Fully-qualified name of the module declaring the passed callable if that
+    # callable was physically declared by an on-disk module *OR* "None"
+    # otherwise (i.e., if that callable was dynamically declared in-memory).
+    func_module_name = get_object_module_name_or_none(func)
+
     # If either...
     if (
         # The passed callable is dynamically declared in-memory...
@@ -247,7 +247,7 @@ def get_func_locals(
     # Then silently reduce to a noop by treating this nested callable as
     # module-scoped by preserving "func_locals" as the empty dictionary.
     ):
-        return DICT_EMPTY
+        return FROZENDICT_EMPTY
     # Else, all of the following constraints hold:
     # * The passed callable is physically declared on-disk.
     # * The passed callable is nested.
@@ -356,7 +356,7 @@ def get_func_locals(
     # implying that there is *NO* parent lexical scope to search for. In this
     # case, silently reduce to a noop by returning the empty dictionary.
     if func_scope_names_search_len == 0:
-        return DICT_EMPTY
+        return FROZENDICT_EMPTY
     # If a *NEGATIVE* number of unignorable lexical scopes encapsulate that
     # callable, the caller erroneously insists that there exist more ignorable
     # lexical scopes encapsulating that callable than there actually exist
@@ -516,16 +516,15 @@ def get_func_locals(
             #   currently just a readable alias for "DictStrToAny", which is
             #   itself an efficiency alias for "Dict[Str, object]". Ergo, static
             #   type-checkers expect this getter to return "dict" instances.
-            # * Under Python <= 3.12, the "func_frame.f_locals" instance
+            # * Under Python < 3.12, the "func_frame.f_locals" instance
             #   variable actually is a "dict" instance.
             # * Under Python >= 3.12, the "func_frame.f_locals" instance
             #   variable actually is instead a "mappingproxy" instance. Although
-            #   interchangeable for many purposes, "dict" and "mappingproxy"
+            #   interchangeable for most purposes, "dict" and "mappingproxy"
             #   instances are *NOT* perfectly interchangeable. In particular,
             #   callers of this function frequently pass this local scope to
             #   the dict.update() method -- which expects the passed mapping to
             #   also be a "dict" instance: e.g.,
-            #
             #       cls_curr_locals = get_type_locals(
             #           cls=cls_curr, exception_cls=exception_cls)
             #   >   func_locals.update(cls_curr_locals)
