@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -21,7 +21,10 @@ from beartype.roar._roarexc import _BeartypeUtilTypeException
 from beartype.typing import (
     Any,
     Optional,
-    # Union,
+)
+from beartype._data.hint.datahintpep import (
+    Hint,
+    HintOrNone,
 )
 from beartype._data.hint.datahinttyping import (
     # HintSignTrie,
@@ -35,98 +38,41 @@ from beartype._data.hint.pep.datapeprepr import (
 )
 from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from beartype._data.hint.pep.sign.datapepsigns import (
-    HintSignGeneric,
+    HintSignPep484585GenericSubscripted,
+    HintSignPep484585GenericUnsubscripted,
     HintSignNewType,
     HintSignTypedDict,
     HintSignPep585BuiltinSubscriptedUnknown,
+    HintSignPep695TypeAliasSubscripted,
 )
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_ORIGIN_ISINSTANCEABLE,
 )
-from beartype._data.kind.datakinddict import DICT_EMPTY
+from beartype._data.kind.datakindmap import FROZENDICT_EMPTY
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
+from beartype._util.hint.pep.proposal.pep484.pep484newtype import (
     is_hint_pep484_newtype_pre_python310)
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
-    is_hint_pep484585_generic)
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585tuple import (
+from beartype._util.hint.pep.proposal.pep484585.generic.pep484585gentest import (
+    is_hint_pep484585_generic_subscripted,
+    is_hint_pep484585_generic_unsubscripted,
+)
+from beartype._util.hint.pep.proposal.pep484585.pep484585tuple import (
     get_hint_pep484585_sign_tuplefixed_or_same)
-from beartype._util.hint.pep.proposal.utilpep585 import (
+from beartype._util.hint.pep.proposal.pep484604 import (
+    die_if_hint_pep604_inconsistent)
+from beartype._util.hint.pep.proposal.pep585 import (
     get_hint_pep585_generic_typevars,
     is_hint_pep585_builtin_subscripted,
-    is_hint_pep585_generic,
+    is_hint_pep585_generic_unsubscripted,
 )
-from beartype._util.hint.pep.proposal.utilpep589 import is_hint_pep589
-from beartype._util.hint.pep.proposal.utilpep484604 import (
-    die_if_hint_pep604_inconsistent)
-from beartype._util.py.utilpyversion import (
-    # IS_PYTHON_AT_LEAST_3_10,
-    IS_PYTHON_AT_MOST_3_9,
-    IS_PYTHON_AT_LEAST_3_9,
-)
-from beartype._data.hint.datahinttyping import TupleTypes
+from beartype._util.hint.pep.proposal.pep589 import is_hint_pep589
+from beartype._util.hint.pep.proposal.pep695 import is_hint_pep695_subscripted
+from beartype._util.py.utilpyversion import IS_PYTHON_AT_MOST_3_9
+from beartype._data.hint.datahinttyping import TupleTypeVars
 
 # ....................{ GETTERS ~ args                     }....................
-# If the active Python interpreter targets Python >= 3.9, implement this
-# getter to directly access the "__args__" dunder attribute.
-if IS_PYTHON_AT_LEAST_3_9:
-    def get_hint_pep_args(hint: object) -> tuple:
-
-        # Tuple of the zero or more child type hints subscripting this hint if
-        # this hint defines of the "__args__" dunder attribute *OR* "None"
-        # otherwise (i.e., if this hint fails to define this attribute).
-        hint_args = getattr(hint, '__args__', None)
-
-        # If this hint does *NOT* define this attribute, return the empty tuple.
-        if hint_args is None:
-            return ()
-        # Else, this hint defines this attribute.
-        #
-        # If this hint is subscripted by zero child type hints, this hint only
-        # superficially appears to be unsubscripted but was actually subscripted
-        # by the empty tuple (e.g., "tuple[()]", "typing.Tuple[()]"). Why?
-        # Because:
-        # * Python 3.11 made the unfortunate decision of ambiguously conflating
-        #   unsubscripted type hints (e.g., "tuple", "typing.Tuple") with type
-        #   hints subscripted by the empty tuple, preventing downstream
-        #   consumers from reliably distinguishing these two orthogonal cases.
-        # * Python 3.9 made a similar decision but constrained to only PEP
-        #   585-compliant empty tuple type hints (i.e., "tuple[()]"). PEP
-        #   484-compliant empty tuple type hints (i.e., "typing.Tuple[()]")
-        #   continued to correctly declare an "__args__" dunder attribute of
-        #   "((),)" until Python 3.11.
-        #
-        # Disambiguate these two cases on behalf of callers by returning a
-        # 1-tuple containing only the empty tuple (i.e., "((),)") rather than
-        # returning the empty tuple (i.e., "()").
-        elif not hint_args:
-            return _HINT_ARGS_EMPTY_TUPLE
-        # Else, this hint is either subscripted *OR* is unsubscripted but not
-        # PEP 585-compliant.
-
-        # In this case, return this tuple as is.
-        return hint_args
-# Else, the active Python interpreter targets Python < 3.9. In this case,
-# implement this getter to directly access the "__args__" dunder attribute.
-else:
-    def get_hint_pep_args(hint: object) -> tuple:
-
-        # Under Python < 3.9, unparametrized generics have the attribute
-        # "_special" set to True despite the actual "__args__" typically being a
-        # "TypeVar" instance. Because we want to differentiate between
-        # unparametrized and parametrized generics, we check whether this hint
-        # is "_special" and if so, return the empty tuple instead of that
-        # "TypeVar" instance.
-        if getattr(hint, '_special', False):
-            return ()
-
-        # Return the value of the "__args__" dunder attribute if this hint
-        # defines this attribute *OR* the empty tuple otherwise.
-        return getattr(hint, '__args__', ())
-
-
-# Document this function regardless of implementation details above.
-get_hint_pep_args.__doc__ = '''
+def get_hint_pep_args(hint: object) -> tuple:
+    '''
     Tuple of the zero or more **child type hints** subscripting (indexing) the
     passed PEP-compliant type hint if this hint was subscripted *or* the empty
     tuple otherwise (i.e., if this hint is unsubscripted and is thus either an
@@ -149,7 +95,7 @@ get_hint_pep_args.__doc__ = '''
 
     **This getter lies rarely due to subscription erasure** (i.e., the malicious
     destruction of child type hints by parent type hint factories at
-    subscription time). Callers should not assume that the objects originally
+    subscription time). Callers should *not* assume that the objects originally
     subscripting this hint are still accessible. Although *most* hints preserve
     their subscripted objects over their lifetimes, a small subset of edge-case
     hints erase those objects at subscription time. This includes:
@@ -161,8 +107,8 @@ get_hint_pep_args.__doc__ = '''
       preserve that subscripted empty tuple.
 
     **This getter lies less than the comparable**
-    :func:`get_hint_pep_typevars` **getter.** Whereas
-    :func:`get_hint_pep_typevars` synthetically propagates type variables from
+    :func:`.get_hint_pep_typevars` **getter.** Whereas
+    :func:`.get_hint_pep_typevars` synthetically propagates type variables from
     child to parent type hints (rather than preserving the literal type
     variables subscripting this type hint), this getter preserves the literal
     arguments subscripting this type hint if any. Notable cases where the two
@@ -189,7 +135,7 @@ get_hint_pep_args.__doc__ = '''
 
     Examples
     --------
-    .. code-block:: python
+    .. code-block:: pycon
 
        >>> import typing
        >>> from beartype._util.hint.pep.utilpepget import (
@@ -200,54 +146,45 @@ get_hint_pep_args.__doc__ = '''
        (int, str, typing.Dict[str, str])
     '''
 
+    # Tuple of the zero or more child type hints subscripting this hint if
+    # this hint defines of the "__args__" dunder attribute *OR* "None"
+    # otherwise (i.e., if this hint fails to define this attribute).
+    hint_args = getattr(hint, '__args__', None)
+
+    # If this hint does *NOT* define this attribute, return the empty tuple.
+    if hint_args is None:
+        return ()
+    # Else, this hint defines this attribute.
+    #
+    # If this hint is subscripted by zero child type hints, this hint only
+    # superficially appears to be unsubscripted but was actually subscripted
+    # by the empty tuple (e.g., "tuple[()]", "typing.Tuple[()]"). Why?
+    # Because:
+    # * Python 3.11 made the unfortunate decision of ambiguously conflating
+    #   unsubscripted type hints (e.g., "tuple", "typing.Tuple") with type
+    #   hints subscripted by the empty tuple, preventing downstream
+    #   consumers from reliably distinguishing these two orthogonal cases.
+    # * Python 3.9 made a similar decision but constrained to only PEP
+    #   585-compliant empty tuple type hints (i.e., "tuple[()]"). PEP
+    #   484-compliant empty tuple type hints (i.e., "typing.Tuple[()]")
+    #   continued to correctly declare an "__args__" dunder attribute of
+    #   "((),)" until Python 3.11.
+    #
+    # Disambiguate these two cases on behalf of callers by returning a
+    # 1-tuple containing only the empty tuple (i.e., "((),)") rather than
+    # returning the empty tuple (i.e., "()").
+    elif not hint_args:
+        return _HINT_ARGS_EMPTY_TUPLE
+    # Else, this hint is either subscripted *OR* is unsubscripted but not
+    # PEP 585-compliant.
+
+    # In this case, return this tuple as is.
+    return hint_args
+
+
 # ....................{ GETTERS ~ typevars                 }....................
-# If the active Python interpreter targets Python >= 3.9, implement this
-# function to either directly access the "__parameters__" dunder attribute for
-# type hints that are not PEP 585-compliant generics *OR* to synthetically
-# reconstruct that attribute for PEP 585-compliant generics. *sigh*
-if IS_PYTHON_AT_LEAST_3_9:
-    def get_hint_pep_typevars(hint: object) -> TupleTypes:
-
-        # Value of the "__parameters__" dunder attribute on this object if this
-        # object defines this attribute *OR* "None" otherwise.
-        hint_pep_typevars = getattr(hint, '__parameters__', None)
-
-        # If this object defines *NO* such attribute...
-        if hint_pep_typevars is None:
-            # Return either...
-            return (
-                # If this hint is a PEP 585-compliant generic, the tuple of all
-                # typevars declared on pseudo-superclasses of this generic.
-                get_hint_pep585_generic_typevars(hint)
-                if is_hint_pep585_generic(hint) else
-                # Else, the empty tuple.
-                ()
-            )
-        # Else, this object defines this attribute.
-
-        # Return this attribute.
-        return hint_pep_typevars
-# Else, the active Python interpreter targets Python < 3.9. In this case,
-# implement this function to directly access the "__parameters__" dunder
-# attribute.
-else:
-    def get_hint_pep_typevars(hint: object) -> TupleTypes:
-
-        # Value of the "__parameters__" dunder attribute on this object if this
-        # object defines this attribute *OR* the empty tuple otherwise. Note:
-        # * The "typing._GenericAlias.__parameters__" dunder attribute tested
-        #   here is defined by the typing._collect_type_vars() function at
-        #   subscription time. Yes, this is insane. Yes, this is PEP 484.
-        # * This trivial test implicitly handles superclass parametrizations.
-        #   Thankfully, the "typing" module percolates the "__parameters__"
-        #   dunder attribute from "typing" pseudo-superclasses to user-defined
-        #   subclasses during PEP 560-style type erasure. Finally: they did
-        #   something slightly right.
-        return getattr(hint, '__parameters__', ())
-
-
-# Document this function regardless of implementation details above.
-get_hint_pep_typevars.__doc__ = '''
+def get_hint_pep_typevars(hint: Hint) -> TupleTypeVars:
+    '''
     Tuple of all **unique type variables** (i.e., subscripted :class:`TypeVar`
     instances of the passed PEP-compliant type hint listed by the caller at
     hint declaration time ignoring duplicates) if any *or* the empty tuple
@@ -302,7 +239,7 @@ get_hint_pep_typevars.__doc__ = '''
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Object to be inspected.
 
     Returns
@@ -349,6 +286,30 @@ get_hint_pep_typevars.__doc__ = '''
        (T, S)
     '''
 
+    # Value of the "__parameters__" dunder attribute on this object if this
+    # object defines this attribute (e.g., is *NOT* a PEP 585-compliant
+    # unsubscripted generic) *OR* "None" otherwise (e.g., is such a generic).
+    hint_pep_typevars = getattr(hint, '__parameters__', None)
+
+    # If this object defines *NO* such attribute, synthetically reconstruct
+    # this attribute for PEP 585-compliant unsubscripted generics. Notably...
+    if hint_pep_typevars is None:
+        # Reconstruct this attribute as either...
+        hint_pep_typevars = (
+            # If this hint is a PEP 585-compliant unsubscripted generic, the
+            # tuple of all type variables parametrizing all pseudo-superclasses
+            # of this generic;
+            get_hint_pep585_generic_typevars(hint)
+            if is_hint_pep585_generic_unsubscripted(hint) else
+            # Else, this hint is *NOT* a PEP 585-compliant unsubscripted
+            # generic. In this case, the empty tuple.
+            ()
+        )
+    # Else, this object defines this attribute.
+
+    # Return this attribute.
+    return hint_pep_typevars
+
 # ....................{ GETTERS ~ sign                     }....................
 def get_hint_pep_sign(
     # Mandatory parameters.
@@ -444,8 +405,8 @@ def get_hint_pep_sign(
 def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     '''
     **Sign** (i.e., :class:`HintSign` instance) uniquely identifying the passed
-    PEP-compliant type hint if PEP-compliant *or* ``None`` otherwise (i.e., if
-    this hint is *not* PEP-compliant).
+    PEP-compliant type hint if PEP-compliant *or* :data:`None` otherwise (i.e.,
+    if this hint is *not* PEP-compliant).
 
     This getter function associates the passed hint with a public attribute of
     the :mod:`typing` module effectively acting as a superclass of this hint
@@ -465,8 +426,9 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
       :class:`collections.abc.Iterable` or :class:`collections.abc.Sequence`),
       this function returns ::class:`beartype.cave.HintGenericSubscriptedType`.
     * A **generic** (i.e., subclass of the :class:`typing.Generic` abstract
-      base class (ABC)), this function returns :class:`HintSignGeneric`. Note
-      this includes :pep:`544`-compliant **protocols** (i.e., subclasses of the
+      base class (ABC)), this function returns
+      :class:`HintSignPep484585GenericUnsubscripted`. Note this includes
+      :pep:`544`-compliant **protocols** (i.e., subclasses of the
       :class:`typing.Protocol` ABC), which implicitly subclass the
       :class:`typing.Generic` ABC as well.
     * A **forward reference** (i.e., string or instance of the concrete
@@ -490,28 +452,26 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     external callers any means of deciding the categories of arbitrary
     PEP-compliant type hints. For example, there exists no general-purpose
     means of identifying a parametrized subtype (e.g., ``typing.List[int]``) as
-    a parametrization of its unparameterized base type (e.g., ``type.List``).
-    Thus this function, which "fills in the gaps" by implementing this
-    oversight.
+    a parametrization of its unparameterized base type (e.g.,
+    :obj:`typing.List`). Thus this function, which "fills in the gaps" by
+    implementing this oversight.
 
     Parameters
     ----------
-    hint : object
+    hint : Any
         Type hint to be inspected.
 
     Returns
     -------
-    dict
-        Sign uniquely identifying this hint.
+    Optional[HintSign]
+        Either:
 
-    Raises
-    ------
-    BeartypeDecorHintPepException
-        If this hint is *not* PEP-compliant.
+        * If this hint is PEP-compliant, a sign uniquely identifying this hint.
+        * If this hint is PEP-noncompliant, :data:`None`.
 
     Examples
     --------
-    .. code-block:: python
+    .. code-block:: pycon
 
        >>> import typing
        >>> from beartype._util.hint.pep.utilpepget import (
@@ -528,11 +488,11 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
 
        >>> class Genericity(typing.Generic[T]): pass
        >>> get_hint_pep_sign_or_none(Genericity)
-       HintSignGeneric
+       HintSignPep484585GenericUnsubscripted
 
        >>> class Duplicity(typing.Iterable[T], typing.Container[T]): pass
        >>> get_hint_pep_sign_or_none(Duplicity)
-       HintSignGeneric
+       HintSignPep484585GenericUnsubscripted
     '''
 
     # ..................{ IMPORTS                            }..................
@@ -592,7 +552,7 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # package is recognized *OR* the empty dictionary otherwise (i.e., if the
     # package defining this hint is unrecognized).
     hint_type_name_to_sign = HINT_MODULE_NAME_TO_TYPE_BASENAME_TO_SIGN.get(
-        hint_type.__module__, DICT_EMPTY)
+        hint_type.__module__, FROZENDICT_EMPTY)
 
     # Sign identifying this hint if this hint is identifiable by its classname
     # *OR* "None" otherwise.
@@ -725,9 +685,9 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # For minor efficiency gains, the following tests are intentionally ordered
     # in descending likelihood of a match.
 
-    # If this hint is a PEP 484- or 585-compliant generic (i.e., user-defined
-    # class superficially subclassing at least one PEP 484- or 585-compliant
-    # type hint), return that sign. However, note that:
+    # If this hint is a PEP 484- or 585-compliant unsubscripted generic (i.e.,
+    # user-defined class superficially subclassing at least one PEP 484- or
+    # 585-compliant type hint), return that sign. However, note that:
     # * Generics *CANNOT* be detected by the general-purpose logic performed
     #   above, as the "typing.Generic" ABC does *NOT* define a __repr__()
     #   dunder method returning a string prefixed by the "typing." substring.
@@ -759,9 +719,18 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     # Ergo, the "typing.Generic" ABC uniquely identifies many but *NOT* all
     # generics. While non-ideal, the failure of PEP 585-compliant generics to
     # subclass a common superclass leaves us with little alternative.
-    if is_hint_pep484585_generic(hint):
-        return HintSignGeneric
-    # Else, this hint is *NOT* a PEP 484- or 585-compliant generic.
+    if is_hint_pep484585_generic_unsubscripted(hint):
+        return HintSignPep484585GenericUnsubscripted
+    # Else, this hint is *NOT* a PEP 484- or 585-compliant unsubscripted
+    # generic.
+    #
+    # If this hint is a PEP 484- or 585-compliant subscripted generic (i.e.,
+    # object subscripted by one or more child type hints originating from a
+    # user-defined class superficially subclassing at least one PEP 484- or
+    # 585-compliant type hint), return that sign. See above for commentary.
+    elif is_hint_pep484585_generic_subscripted(hint):
+        return HintSignPep484585GenericSubscripted
+    # Else, this hint is *NOT* a PEP 484- or 585-compliant subscripted generic.
     #
     # If this hint is a PEP 589-compliant typed dictionary, return that sign.
     elif is_hint_pep589(hint):
@@ -807,13 +776,21 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     #FIXME: Unit test us up, please.
     # If this hint is an unrecognized subscripted builtin type hint (i.e.,
     # C-based type hint instantiated by subscripting a pure-Python origin class
-    # unrecognized by @beartype and thus PEP-noncompliant), return this sign.
-    # Examples include "os.PathLike[...]" and "weakref.weakref[...]" type hints.
-    #
-    # This is a last-ditch fallback preferable to merely returning "None", which
-    # conveys substantially less semantics and would imply this object to be an
-    # isinstanceable class, which subscripted builtin type hints are *NOT*.
+    # unrecognized by @beartype and thus PEP-noncompliant)...
     if is_hint_pep585_builtin_subscripted(hint):
+        # If this hint is a PEP 695-compliant subscripted type alias (i.e.,
+        # object created by subscripting an object created by a statement of the
+        # form "type {alias_name}[{type_var}] = {alias_value}" by one or more
+        # child type hints), return the corresponding sign.
+        if is_hint_pep695_subscripted(hint):
+            return HintSignPep695TypeAliasSubscripted
+        # Else, this hint is *NOT* a PEP 695-compliant subscripted type alias.
+
+        # Return this ambiguous sign. This is a last-ditch fallback preferable
+        # to merely returning "None", which conveys substantially less semantics
+        # and would imply this object to be an isinstanceable class, which
+        # subscripted builtin type hints are *NOT*. Examples include
+        # "os.PathLike[...]" and "weakref.weakref[...]" type hints.
         return HintSignPep585BuiltinSubscriptedUnknown
     # Else, this hint is *NOT* an unrecognized subscripted builtin type hint.
 
@@ -821,14 +798,73 @@ def get_hint_pep_sign_or_none(hint: Any) -> Optional[HintSign]:
     return None
 
 # ....................{ GETTERS ~ origin                   }....................
-def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
+def get_hint_pep_origin(
+    # Mandatory parameters.
+    hint: Hint,
+
+    # Optional parameters.
+    #FIXME: This should probably be a new "BeartypeDecorHintPepOriginException"
+    #type, instead. But it's unclear whether users will even ever see this
+    #exception. So, for now, laziness prevails. Huzzah! *sigh*
+    exception_cls: TypeException = _BeartypeUtilTypeException,
+    exception_prefix: str = '',
+) -> Hint:
     '''
     **Unsafe origin object** (i.e., arbitrary object originating the passed
     PEP-compliant type hint but *not* necessarily an isinstanceable class such
     that all objects satisfying this hint are instances of this class)
-    originating this hint if this hint originates from an object *or*
-    :data:`None` otherwise (i.e., if this hint originates from *no* such
-    object).
+    originating this hint if this hint originates from an origin *or*
+    raise an exception otherwise (i.e., if this hint originates from *no*
+    origin).
+
+    This getter is intentionally *not* memoized (e.g., by the
+    :func:`.callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
+
+    Parameters
+    ----------
+    hint : Hint
+        Object to be inspected.
+    exception_cls : TypeException, optional
+        Type of exception to be raised in the event of a fatal error. Defaults
+        to :exc:`._BeartypeUtilTypeException`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing the representation of this object in
+        the exception message. Defaults to the empty string.
+
+    Returns
+    -------
+    Hint
+        Arbitrary object this hint originates from.
+
+    Raises
+    ------
+    exception_cls
+        If this hint originates from *no* object.
+    '''
+
+    # Origin originating this hint if any *OR* "None" otherwise.
+    hint_origin = get_hint_pep_origin_or_none(hint)
+
+    # If this hint does *NOT* originate from anything, raise an exception.
+    if hint_origin is None:
+        raise exception_cls(
+            f'{exception_prefix}type hint {repr(hint)} '
+            f'originates from no other object.'
+        )
+    # Else, this hint originates from something.
+
+    # Return that something.
+    return hint_origin
+
+
+def get_hint_pep_origin_or_none(hint: Hint) -> HintOrNone:
+    '''
+    **Unsafe origin object** (i.e., arbitrary object originating the passed
+    PEP-compliant type hint but *not* necessarily an isinstanceable class such
+    that all objects satisfying this hint are instances of this class)
+    originating this hint if this hint originates from an origin *or*
+    :data:`None` otherwise (i.e., if this hint originates from *no* origin).
 
     This getter is intentionally *not* memoized (e.g., by the
     :func:`callable_cached` decorator), as the implementation trivially reduces
@@ -860,12 +896,12 @@ def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Object to be inspected.
 
     Returns
     -------
-    Optional[Any]
+    Optional[Hint]
         Either:
 
         * If this hint originates from an arbitrary object, that object.
@@ -913,7 +949,7 @@ def get_hint_pep_origin_or_none(hint: Any) -> Optional[Any]:
 #FIXME: Unit test us up, please.
 def get_hint_pep_origin_type(
     # Mandatory parameters.
-    hint: object,
+    hint: Hint,
 
     # Optional parameters.
     #FIXME: This should probably be a new "BeartypeDecorHintPepOriginException"
@@ -926,9 +962,11 @@ def get_hint_pep_origin_type(
     **Origin type** (i.e., class such that *all* objects satisfying the passed
     PEP-compliant type hint are instances of this class) originating this hint
     if this hint originates from such a type *or* raise an exception otherwise
-    (i.e., if this hint does *not* originate from such a type).
+    (i.e., if this hint originates from *no* such type).
 
-    This getter is memoized for efficiency.
+    This getter is intentionally *not* memoized (e.g., by the
+    :func:`.callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
 
     Parameters
     ----------
@@ -947,7 +985,7 @@ def get_hint_pep_origin_type(
         Type originating this hint.
 
     Raises
-    -------
+    ------
     exception_cls
         If this hint either:
 
@@ -971,11 +1009,11 @@ def get_hint_pep_origin_type(
             f'{exception_prefix} not string.')
 
         # Origin non-type originating this hint if any *OR* "None" otherwise.
-        hint_origin = get_hint_pep_origin_or_none(hint)
+        hint_origin_nontype = get_hint_pep_origin_or_none(hint)
 
         # If this hint does *NOT* originate from another object, raise an
         # appropriate exception.
-        if hint_origin is None:
+        if hint_origin_nontype is None:
             raise exception_cls(
                 f'{exception_prefix}type hint {repr(hint)} '
                 f'originates from no other object.'
@@ -986,7 +1024,7 @@ def get_hint_pep_origin_type(
         # Raise an appropriate exception.
         raise exception_cls(
             f'{exception_prefix}type hint {repr(hint)} '
-            f'originates from non-type {repr(hint_origin)}.'
+            f'originates from non-type {repr(hint_origin_nontype)}.'
         )
     # Else, this origin type originates this hint.
 
@@ -995,26 +1033,43 @@ def get_hint_pep_origin_type(
 
 
 #FIXME: Unit test us up, please.
-@callable_cached
-def get_hint_pep_origin_type_or_none(hint: Any) -> Optional[type]:
+def get_hint_pep_origin_type_or_none(
+    # Mandatory parameters.
+    hint: Any,
+
+    # Optional parameters.
+    is_self_fallback: bool = False,
+) -> Optional[type]:
     '''
     **Origin type** (i.e., class such that *all* objects satisfying the passed
     PEP-compliant type hint are instances of this class) originating this hint
     if this hint originates from such a type *or* :data:`None` otherwise (i.e.,
-    if this hint does *not* originate from such a type).
+    if this hint originates from *no* such type).
 
-    This getter is memoized for efficiency.
+    This getter is intentionally *not* memoized (e.g., by the
+    :func:`.callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
 
     Caveats
     -------
-    **This high-level getter should always be called in lieu of the low-level**
-    :func:`get_hint_pep_origin_or_none` **getter on attempting to
-    directly access the low-level** ``__origin__`` **dunder attribute.**
+    **This high-level getter should always be called in lieu of either calling
+    the low-level** :func:`.get_hint_pep_origin_or_none` **getter or attempting
+    to directly access the low-level** ``__origin__`` **dunder attribute.**
 
     Parameters
     ----------
     hint : object
         Type hint to be inspected.
+    is_self_fallback : bool = False
+        :data:`True` only if returning the passed hint as a last-ditch fallback
+        when this hint is a type defining the ``__origin__`` dunder attribute to
+        be a non-type. Equivalently, if the passed hint is such a hint *and*
+        this parameter is:
+
+        * :data:`True`, this getter returns this hint as is.
+        * :data:`False`, this getter returns :data:`None`.
+
+        Defaults to :data:`False`. Explicit is better than implicit.
 
     Returns
     -------
@@ -1029,12 +1084,15 @@ def get_hint_pep_origin_type_or_none(hint: Any) -> Optional[type]:
     :func:`.get_hint_pep_origin_or_none`
         Further details.
     '''
+    assert isinstance(is_self_fallback, bool), (
+        f'{repr(is_self_fallback)} not boolean.')
 
-    # Origin type originating this hint if any *OR* "None" otherwise,
+    # Unsafe origin type originating this hint if any *OR* "None" otherwise,
     # initialized to the arbitrary object set as the "hint.__origin__" dunder
     # attribute if this hint defines that attribute.
     hint_origin: Optional[type] = get_hint_pep_origin_or_none(hint)  # type: ignore[assignment]
 
+    #FIXME: Unit test this up, please. *shrug*
     # If this origin is *NOT* a type...
     #
     # Ideally, this attribute would *ALWAYS* be a type for all possible
@@ -1050,12 +1108,17 @@ def get_hint_pep_origin_type_or_none(hint: Any) -> Optional[type]:
     if not isinstance(hint_origin, type):
         # Default this origin type to either...
         hint_origin = (
-            # If this hint is itself a type, this hint could be euphemistically
-            # said to originate from "itself." In this case, this hint.
-            #
-            # Look. Just go with it. We wave our hands in the air.
-            hint if isinstance(hint, type) else
-            # Else, this hint is *NOT* a type. Default to "None". No choice, yo!
+            # If...
+            hint if (
+                # The caller requests the "self" fallback logic *AND*...
+                is_self_fallback and
+                # This hint is itself a type, this hint could be euphemistically
+                # said to originate from "itself." Fallback to this hint itself.
+                # Look. Just go with it. We wave our hands in the air
+                isinstance(hint, type)
+            ) else
+            # Else, either the caller did not request the "self" fallback logic
+            # *OR* this hint is not a type. In either case, fallback to "None".
             None
         )
     # Else, this origin is a type.
@@ -1064,10 +1127,7 @@ def get_hint_pep_origin_type_or_none(hint: Any) -> Optional[type]:
     return hint_origin
 
 
-#FIXME: Is this even required or desired anymore? Can't we just replace all
-#calls to this frankly non-ideal getter with calls to a dramatically superior
-#get_hint_pep_origin_type() getter? Excise us up, please.
-def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
+def get_hint_pep_origin_type_isinstanceable(hint: Hint) -> type:
     '''
     **Isinstanceable origin type** (i.e., class passable as the second argument
     to the :func:`isinstance` builtin such that *all* objects satisfying the
@@ -1081,7 +1141,7 @@ def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be inspected.
 
     Returns
@@ -1115,11 +1175,8 @@ def get_hint_pep_origin_type_isinstanceable(hint: object) -> type:
     return hint_origin_type
 
 
-#FIXME: Is this even required or desired anymore? Can't we just replace all
-#calls to this frankly non-ideal getter with calls to the dramatically superior
-#get_hint_pep_origin_type_or_none() getter? Excise us up, please.
 def get_hint_pep_origin_type_isinstanceable_or_none(
-    hint: Any) -> Optional[type]:
+    hint: Hint) -> Optional[type]:
     '''
     **Standard origin type** (i.e., isinstanceable class declared by Python's
     standard library such that *all* objects satisfying the passed
@@ -1139,7 +1196,7 @@ def get_hint_pep_origin_type_isinstanceable_or_none(
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Object to be inspected.
 
     Returns
@@ -1164,13 +1221,14 @@ def get_hint_pep_origin_type_isinstanceable_or_none(
     # Return either...
     return (
         # If this sign originates from an origin type, that type;
-        get_hint_pep_origin_or_none(hint)
+        get_hint_pep_origin_or_none(hint)  # type: ignore[return-value]
         if hint_sign in HINT_SIGNS_ORIGIN_ISINSTANCEABLE else
         # Else, "None".
         None
     )
 
 # ....................{ PRIVATE ~ args                     }....................
+#FIXME: Shift into the "beartype._data.hint" subpackage somewhere, please.
 _HINT_ARGS_EMPTY_TUPLE = ((),)
 '''
 Tuple containing only the empty tuple, to be returned from the
