@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -17,42 +17,17 @@ from beartype.roar import (
     BeartypeDecorHintPep484Exception,
 )
 from beartype.typing import (
-    Dict,
     NoReturn,
 )
 from beartype._data.hint.datahinttyping import TypeException
-from beartype._data.hint.pep.sign.datapepsigncls import HintSign
-from beartype._data.hint.pep.sign.datapepsigns import (
-    HintSignAnnotated,
-    HintSignGeneric,
-    HintSignOptional,
-    HintSignNewType,
-    HintSignPep695TypeAlias,
-    HintSignProtocol,
-    HintSignTypeVar,
-    HintSignUnion,
-)
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED,
     HINT_SIGNS_TYPE_MIMIC,
 )
-from beartype._data.module.datamodtyping import TYPING_MODULE_NAMES
+from beartype._data.api.standard.datamodtyping import TYPING_MODULE_NAMES
 from beartype._util.cache.utilcachecall import callable_cached
-from beartype._util.hint.pep.proposal.pep484.utilpep484 import (
-    is_hint_pep484_typevar_ignorable,
-)
-from beartype._util.hint.pep.proposal.pep484.utilpep484newtype import (
-    is_hint_pep484_newtype_ignorable)
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585generic import (
-    is_hint_pep484585_generic_ignorable)
-from beartype._util.hint.pep.proposal.utilpep484604 import (
-    is_hint_pep484604_union_ignorable)
-from beartype._util.hint.pep.proposal.utilpep544 import is_hint_pep544_ignorable
-from beartype._util.hint.pep.proposal.utilpep593 import is_hint_pep593_ignorable
-from beartype._util.hint.pep.proposal.utilpep695 import is_hint_pep695_ignorable
 from beartype._util.module.utilmodget import get_object_module_name_or_none
 from beartype._util.utilobject import get_object_type_unless_type
-from collections.abc import Callable
 
 # ....................{ EXCEPTIONS                         }....................
 def die_if_hint_pep(
@@ -115,7 +90,7 @@ def die_unless_hint_pep(
     hint** (i.e., :mod:`beartype`-agnostic annotation compliant with
     annotation-centric PEPs).
 
-    This validator is effectively (but technically *not*) memoized. See the
+    This validator is effectively (but technically *not*) memoized. See also the
     :func:`beartype._util.hint.utilhinttest.die_unless_hint` validator.
 
     Parameters
@@ -126,8 +101,8 @@ def die_unless_hint_pep(
         Type of the exception to be raised by this function. Defaults to
         :class:`.BeartypeDecorHintPepException`.
     exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to the empty string.
+        Human-readable substring prefixing raised exception messages. Defaults
+        to the empty string.
 
     Raises
     ------
@@ -146,10 +121,6 @@ def die_unless_hint_pep(
             f'{exception_prefix}type hint {repr(hint)} not PEP-compliant.')
 
 # ....................{ EXCEPTIONS ~ supported             }....................
-#FIXME: *DANGER.* This function makes beartype more fragile. Instead, refactor
-#all or most calls to this function into calls to the
-#warn_if_hint_pep_unsupported() function; then, consider excising this as well
-#as exception classes (e.g., "BeartypeDecorHintPepUnsupportedException").
 def die_if_hint_pep_unsupported(
     # Mandatory parameters.
     hint: object,
@@ -181,8 +152,8 @@ def die_if_hint_pep_unsupported(
     hint : object
         Object to be validated.
     exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to the empty string.
+        Human-readable substring prefixing raised exception messages. Defaults
+        to the empty string.
 
     Raises
     ------
@@ -208,13 +179,14 @@ def die_if_hint_pep_unsupported(
     # case, subsequent logic raises an exception specific to the passed
     # parameters.
 
-    # If this hint is *NOT* PEP-compliant, raise an exception.
+    # If this hint is *NOT* PEP-compliant, raise a more readable exception.
     die_unless_hint_pep(hint=hint, exception_prefix=exception_prefix)
     assert isinstance(exception_prefix, str), (
         f'{repr(exception_prefix)} not string.')
-
     # Else, this hint is PEP-compliant.
-    #
+
+    #FIXME: Pretty weird, honestly. This would almost certainly better be
+    #raised in a reducer testing whether "arg_name == ARG_NAME_RETURN".
     # If this is the PEP 484-compliant "typing.NoReturn" type hint permitted
     # *ONLY* as a return annotation, raise an exception specific to this hint.
     if hint is NoReturn:
@@ -407,63 +379,6 @@ def is_hint_pep(hint: object) -> bool:
 #     )
 
 
-def is_hint_pep_ignorable(hint: object) -> bool:
-    '''
-    :data:`True` only if the passed PEP-compliant type hint is **deeply
-    ignorable** (i.e., shown to be ignorable only after recursively inspecting
-    the contents of this hint).
-
-    This tester is intentionally *not* memoized (e.g., by the
-    :func:`beartype._util.cache.utilcachecall.callable_cached` decorator), as
-    This tester is only safely callable by the memoized parent
-    :func:`beartype._util.hint.utilhinttest.is_hint_ignorable` tester.
-
-    Parameters
-    ----------
-    hint : object
-        PEP-compliant type hint to be inspected.
-
-    Returns
-    -------
-    bool
-        :data:`True` only if this PEP-compliant type hint is deeply ignorable.
-
-    Warns
-    -----
-    BeartypeDecorHintPepIgnorableDeepWarning
-        If this object is a deeply ignorable PEP-compliant type hint. Why?
-        Because deeply ignorable PEP-compliant type hints convey *no*
-        meaningful semantics but superficially appear to do so. Consider
-        ``Union[str, List[int], NewType('MetaType', Annotated[object, 53])]``,
-        for example; this PEP-compliant type hint effectively reduces to
-        :obj:`typing.Any` and thus conveys *no* meaningful semantics despite
-        superficially appearing to do so.
-    '''
-
-    # Avoid circular import dependencies.
-    from beartype._util.hint.pep.utilpepget import get_hint_pep_sign
-    # print(f'Testing PEP hint {repr(hint)} deep ignorability...')
-
-    # Sign uniquely identifying this hint.
-    hint_sign = get_hint_pep_sign(hint)
-
-    # Ignorer (i.e., callable testing whether this hint is ignorable) if an
-    # ignorer for hints of this sign was registered *OR* "None" otherwise (i.e.,
-    # if *NO* ignorer was registered, in which case this hint is unignorable).
-    is_hint_ignorable = _HINT_SIGN_TO_IS_HINT_IGNORABLE.get(hint_sign)
-
-    # Return either...
-    return (
-        # If an ignorer for hints of this sign was registered, the boolean
-        # returned when passing this ignorer this hint);
-        is_hint_ignorable(hint)
-        if is_hint_ignorable else
-        # Else, *NO* ignorer for hints of this sign was registered, implying
-        # this hint to be unignorable. Return false.
-        False
-    )
-
-
 #FIXME: Unit test us up, please.
 def is_hint_pep_subscripted(hint: object) -> bool:
     '''
@@ -542,17 +457,18 @@ def is_hint_pep_supported(hint: object) -> bool:
 # ....................{ TESTERS ~ typing                   }....................
 #FIXME: Replace all hardcoded "'typing" strings throughout the codebase with
 #access of "TYPING_MODULE_NAMES" instead. We only see one remaining in:
-#* beartype._util.hint.pep.proposal.pep484.utilpep484.py
+#* beartype._util.hint.pep.proposal.pep484.pep484.py
 #Thankfully, nobody really cares about generalizing this one edge case to
 #"testing_extensions", so it's mostly fine for various definitions of fine.
-@callable_cached
 def is_hint_pep_typing(hint: object) -> bool:
     '''
     :data:`True` only if the passed object is an attribute of a **typing
     module** (i.e., module officially declaring attributes usable for creating
     PEP-compliant type hints accepted by both static and runtime type checkers).
 
-    This tester is memoized for efficiency.
+    This tester is intentionally *not* memoized (e.g., by the
+    :func:`.callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
 
     Parameters
     ----------
@@ -657,71 +573,3 @@ def is_hint_pep_type_typing(hint: object) -> bool:
     #
     # In short, there is no general-purpose clever solution. *sigh*
     return hint_type.__module__ in TYPING_MODULE_NAMES
-
-# ....................{ PRIVATE ~ dicts                    }....................
-# Note that these type hints would ideally be defined with the mypy-specific
-# "callback protocol" pseudostandard, documented here:
-#     https://mypy.readthedocs.io/en/stable/protocols.html#callback-protocols
-#
-# Doing so would enable static type-checkers to type-check that the values of
-# this dictionary are valid ignorer functions. Sadly, that pseudostandard is
-# absurdly strict to the point of practical uselessness. Attempting to conform
-# to that pseudostandard would require refactoring *ALL* ignorer functions to
-# explicitly define the same signature. However, we have intentionally *NOT*
-# done that. Why? Doing so would substantially increase the fragility of this
-# API by preventing us from readily adding and removing infrequently required
-# parameters (e.g., "cls_stack", "pith_name"). Callback protocols suck, frankly.
-_HINT_SIGN_TO_IS_HINT_IGNORABLE: Dict[HintSign, Callable] = {
-    # ..................{ PEP 484                            }..................
-    # Ignore *ALL* PEP 484-compliant "NewType"-style type aliases aliasing
-    # ignorable type hints.
-    HintSignNewType: is_hint_pep484_newtype_ignorable,
-
-    # Ignore *ALL* PEP 484-compliant type variables.
-    HintSignTypeVar: is_hint_pep484_typevar_ignorable,
-
-    # ..................{ PEP (484|585)                      }..................
-    # Ignore *ALL* PEP 484- and 585-compliant "Generic[...]" subscriptions.
-    HintSignGeneric: is_hint_pep484585_generic_ignorable,
-
-    # ..................{ PEP (484|604)                      }..................
-    # Ignore *ALL* PEP 484- and 604-compliant unions subscripted by one or more
-    # ignorable type hints.
-    HintSignOptional: is_hint_pep484604_union_ignorable,
-    HintSignUnion:    is_hint_pep484604_union_ignorable,
-
-    # ..................{ PEP 544                            }..................
-    # Ignore *ALL* PEP 544-compliant "typing.Protocol[...]" subscriptions.
-    HintSignProtocol: is_hint_pep544_ignorable,
-
-    # ..................{ PEP 593                            }..................
-    # Ignore *ALL* PEP 593-compliant "typing.Annotated[...]" type hints except
-    # those indexed by one or more beartype validators.
-    HintSignAnnotated: is_hint_pep593_ignorable,
-
-    # ..................{ PEP 695                            }..................
-    # Ignore *ALL* PEP 695-compliant type aliases aliasing ignorable type hints.
-    HintSignPep695TypeAlias: is_hint_pep695_ignorable,
-}
-'''
-Dictionary mapping from each sign uniquely identifying PEP-compliant type hints
-to that sign's **ignorer** (i.e., low-level function testing whether the passed
-type hint identified by that sign is deeply ignorable).
-
-Each value of this dictionary is expected to have a signature resembling:
-
-.. code-block:: python
-
-   def is_hint_pep{pep_number}_ignorable(hint: object) -> bool: ...
-
-Note that:
-
-* Ignorers do *not* need to validate the passed type hint as being of the
-  expected sign. By design, an ignorer is only ever passed a type hint of the
-  expected sign.
-* Ignorers should *not* be memoized (e.g., by the
-  `callable_cached`` decorator). Since the higher-level
-  :func:`.is_hint_pep_ignorable` function that is the sole entry point to
-  calling all lower-level ignorers is itself effectively memoized, ignorers
-  themselves neither require nor benefit from memoization.
-'''
