@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -12,22 +12,29 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
-from beartype._data.hint.pep.datapeprepr import HINTS_REPR_IGNORABLE_SHALLOW
+from beartype.meta import URL_ISSUES
+from beartype.roar import BeartypeDecorHintNonpepException
+from beartype._data.hint.datahintpep import Hint
+from beartype._data.hint.datahinttyping import TypeException
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.nonpep.utilnonpeptest import (
     die_unless_hint_nonpep,
     is_hint_nonpep,
 )
+from beartype._util.hint.pep.utilpepget import get_hint_pep_typevars
 from beartype._util.hint.pep.utilpeptest import (
     die_if_hint_pep_unsupported,
     is_hint_pep,
     is_hint_pep_supported,
 )
+from beartype._util.hint.pep.proposal.pep585 import (
+    is_hint_pep585_builtin_subscripted)
+from beartype._util.hint.pep.proposal.pep484604 import is_hint_pep604
 
 # ....................{ RAISERS                            }....................
 def die_unless_hint(
     # Mandatory parameters.
-    hint: object,
+    hint: Hint,
 
     # Optional parameters.
     exception_prefix: str = '',
@@ -51,19 +58,19 @@ def die_unless_hint(
     ``exception_prefix`` parameter is usually unique to each call to this
     validator; memoizing this validator would uselessly consume excess space
     *without* improving time efficiency. Instead, this validator first calls the
-    memoized :func:`is_hint_pep` tester. If that tester returns ``True``, this
-    validator immediately returns ``True`` and is thus effectively memoized;
-    else, this validator inefficiently raises a human-readable exception without
-    memoization. Since efficiency is mostly irrelevant in exception handling,
-    this validator remains effectively memoized.
+    memoized :func:`.is_hint_pep` tester. If that tester returns :data:`True`,
+    this validator immediately returns :data:`True` and is thus effectively
+    memoized; else, this validator inefficiently raises a human-readable
+    exception without memoization. Since efficiency is mostly irrelevant in
+    exception handling, this validator remains effectively memoized.
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Object to be validated.
     exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to the empty string.
+        Human-readable substring prefixing raised exception messages. Defaults
+        to the empty string.
 
     Raises
     ------
@@ -98,6 +105,62 @@ def die_unless_hint(
     # an exception.
     die_unless_hint_nonpep(hint=hint, exception_prefix=exception_prefix)
 
+
+#FIXME: This same exception message is repeated ad naseum throughout the
+#codebase at least three or four times. Reduce DRY by instead deferring to this
+#function, please. *sigh*
+def die_as_hint_unsupported(
+    # Mandatory parameters.
+    hint: object,
+
+    # Optional parameters.
+    exception_cls: TypeException = BeartypeDecorHintNonpepException,
+    exception_prefix: str = '',
+) -> None:
+    '''
+    Unconditionally raise an exception describing the failure of the passed
+    object to be a **supported type hint** (i.e., object supported by the
+    :func:`beartype.beartype` decorator as a valid type hint annotating callable
+    parameters and return values).
+
+    This low-level raiser is intended to be called only after this object has
+    already been validated to *not* be a supported type hint. This raiser
+    centralizes similar logic previously duplicated throughout the codebase.
+
+    Parameters
+    ----------
+    hint : object
+        Object to be validated.
+    exception_cls : type[Exception]
+        Type of exception to be raised. Defaults to
+        :exc:`.BeartypeDecorHintNonpepException`.
+    exception_prefix : str, optional
+        Human-readable substring prefixing the raised exception message.
+        Defaults to the empty string.
+
+    Raises
+    ------
+    exception_cls
+        Unconditionally.
+    '''
+    assert isinstance(exception_cls, type), f'{repr(exception_cls)} not type.'
+    assert isinstance(exception_prefix, str), (
+        f'{repr(exception_prefix)} not string.')
+
+    # Raise this generic exception message.
+    raise exception_cls(
+        f'{exception_prefix}type hint {repr(hint)} invalid or unrecognized. '
+        f'This hint is either:\n'
+        f'* PEP-noncompliant (and thus invalid). '
+        f"This is your bad. Rejoice! @beartype isn't to blame for once.\n"
+        f'* PEP-compliant but currently unsupported by @beartype '
+        f'(and thus unrecognized). '
+        f'This is our bad. Disaster! @beartype is to blame like always. '
+        f'You suddenly feel encouraged to submit a feature request '
+        f'for this unsupported hint to our friendly issue tracker at:\n'
+        f'\t{URL_ISSUES}'
+    )
+
 # ....................{ TESTERS                            }....................
 @callable_cached
 def is_hint(hint: object) -> bool:
@@ -146,57 +209,55 @@ def is_hint(hint: object) -> bool:
     )
 
 
-@callable_cached
-def is_hint_ignorable(hint: object) -> bool:
-    '''
-    :data:`True` only if the passed type hint is **ignorable** (i.e., conveys
-    *no* meaningful semantics despite superficially appearing to do so).
-
-    This tester is memoized for efficiency.
-
-    Parameters
-    ----------
-    hint : object
-        Type hint to be inspected.
-
-    Returns
-    -------
-    bool
-        :data:`True` only if this type hint is ignorable.
-    '''
-
-    # Avoid circular import dependencies.
-    from beartype._util.hint.utilhintget import get_hint_repr
-
-    # Machine-readable representation of this hint.
-    hint_repr = get_hint_repr(hint)
-
-    # If this hint is shallowly ignorable, return true.
-    if hint_repr in HINTS_REPR_IGNORABLE_SHALLOW:
-        return True
-    # Else, this hint is *NOT* shallowly ignorable.
-    #
-    # If this hint is PEP-compliant...
-    elif is_hint_pep(hint):
-        # Avoid circular import dependencies.
-        from beartype._util.hint.pep.utilpeptest import (
-            is_hint_pep_ignorable)
-
-        # Defer to the function testing whether this hint is an ignorable
-        # PEP-compliant type hint.
-        return is_hint_pep_ignorable(hint)
-    # Else, this hint is PEP-noncompliant and thus *NOT* deeply ignorable.
-
-    # Since this hint is also *NOT* shallowly ignorable, this hint is
-    # unignorable. In this case, return false.
-    return False
-
-
 #FIXME: Unit test us up, please.
-def is_hint_uncached(hint: object) -> bool:
+def is_hint_cacheworthy(hint: Hint) -> bool:
     '''
-    :data:`True` only if the passed type hint is **uncached** (i.e., hint *not*
-    already internally cached by its parent class or module).
+    :data:`True` only if the passed type hint is **cache-worthy.**
+
+    A hint is cache-worthy if *all* of the following constraints hold:
+
+    * This hint is *not* already **self-cached** (i.e., internally memoized) by
+      its owner class or module. Although most hints *used* to self-cache, most
+      modern hints no longer self-cache. Why? No idea. It's probably an
+      accidental oversight in PEP implementations across different CPython
+      developers that nobody ever bothered to report: e.g.,
+
+      .. code-block:: pycon
+
+         # PEP 585 type hints do *NOT* self-cache and are thus cache-worthy.
+         >>> list[int] is list[int]
+         False  # <-- horrible! pep 585, you are horrible!
+
+         # PEP 484 type hints do self-cache and are thus *NOT* cache-worthy.
+         >>> import typing
+         >>> typing.List[int] is typing.List[int]
+         True  # <-- wonderful. pep 484, you are wonderful.
+
+    * The **machine-readable representation** (i.e., string returned by passing
+      this hint to the :func:`repr` builtin) of this hint is **unambiguous**
+      (i.e., there exists a one-to-one mapping between this representation and
+      the contents of this representation such that only equal hints have equal
+      representations). Although most hints have unambiguous representations,
+      some hints have ambiguous representations -- including:
+
+      * Type hints transitively parametrized by one or more **type variables**
+        (i.e., :obj:`typing.TypeVar` objects) have ambiguous representations and
+        are thus *not* cache-worthy. Note that the existence of even a single
+        type variable parametrizing a single child type hint subscripting a
+        parent type hint sadly renders the *entire* representation of that
+        parent type hint ambiguous: e.g.,
+
+        .. code-block:: pycon
+
+           >>> from typing import TypeVar
+           >>> T_int = TypeVar('T', bound=int)
+           >>> T_str = TypeVar('T', bound=str)
+           >>> repr(list[T_int])
+           list[T]  # <-- ...ok
+           >>> repr(list[T_str])
+           list[T]  # <-- WUT U SAY!?
+           >>> repr(list[T_int]) == repr(list[T_str])
+           True  # <-- horrible! "TypeVar", you are horrible!
 
     Caveats
     -------
@@ -209,7 +270,7 @@ def is_hint_uncached(hint: object) -> bool:
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be inspected.
 
     Returns
@@ -218,16 +279,11 @@ def is_hint_uncached(hint: object) -> bool:
         :data:`True` only if this type hint is uncached.
 
     See Also
-    ----------
-    :func:`beartype._check.convert.convcoerce.coerce_hint_any`
+    --------
+    :func:`beartype._check.convert._convcoerce.coerce_hint_any`
         Further details.
     '''
 
-    # Avoid circular import dependencies.
-    from beartype._util.hint.pep.proposal.utilpep585 import (
-        is_hint_pep585_builtin_subscripted)
-    from beartype._util.hint.pep.proposal.utilpep484604 import is_hint_pep604
-
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Avoid detecting the kind of this hint by calling any of the
     # get_hint_pep_sign_*() family of memoized getters. Doing so would consume
@@ -236,29 +292,40 @@ def is_hint_uncached(hint: object) -> bool:
     # functionally useless to cache against.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-    # Return true only if this hint is either...
+    # Return true only if this hint is...
     return (
-        # PEP 585-compliant (e.g., "list[str]"), this hint is *NOT* self-caching
-        # (e.g., "list[str] is not list[str]").
-        #
-        # Note that this additionally includes all third-party type hints that
-        # derive from the "types.GenericAlias" superclass, including:
-        # * "numpy.typing.NDArray[...]" type hints.
-        is_hint_pep585_builtin_subscripted(hint) or
-        # PEP 604-compliant (e.g., "int | str"), this hint is *NOT* self-caching
-        # (e.g., "int | str is not int | str").
-        #
-        # Note that this hint could also be implicitly cached by coercing this
-        # non-self-caching PEP 604-compliant union into a self-caching PEP
-        # 484-compliant union (e.g., from "int | str" to "Union[int, str]").
-        # Since doing so would consume substantially more time for *NO* tangible
-        # gain, we strongly prefer the current trivial and efficient approach.
-        is_hint_pep604(hint)
+        # *NOT* transitively parametrized by one or type variables (e.g.,
+        # "list[tuple[T]]"). All first-party hints (i.e., hints defined by
+        # CPython's standard library) and all third-party hints supported by
+        # @beartype have unambiguous representations *EXCEPT* for hints
+        # transitively parametrized by one or type variables, as type variables
+        # themselves have ambiguous representations.
+        not get_hint_pep_typevars(hint) and
+        # Either...
+        (
+            # PEP 585-compliant (e.g., "list[str]"). This hint is *NOT*
+            # self-caching (e.g., "list[str] is not list[str]").
+            #
+            # Note that this additionally includes all third-party type hints
+            # that derive from the "types.GenericAlias" superclass, including:
+            # * "numpy.typing.NDArray[...]" type hints.
+            is_hint_pep585_builtin_subscripted(hint) or
+            # PEP 604-compliant (e.g., "int | str"). This hint is *NOT*
+            # self-caching (e.g., "int | str is not int | str").
+            #
+            # Note that this hint could also be implicitly cached by coercing
+            # this non-self-caching PEP 604-compliant union into a self-caching
+            # PEP 484-compliant union (e.g., from "int | str" to "Union[int,
+            # str]"). Since doing so would consume substantially more time for
+            # *NO* tangible gain, we strongly prefer the current trivial and
+            # efficient approach.
+            is_hint_pep604(hint)
+        )
     )
 
 # ....................{ TESTERS ~ needs                    }....................
 @callable_cached
-def is_hint_needs_cls_stack(hint: object) -> bool:
+def is_hint_needs_cls_stack(hint: Hint) -> bool:
     '''
     :data:`True` only if the passed type hint is **type stack-dependent** (i.e.,
     if :mod:`beartype` requires the tuple of all classes lexically declaring the
@@ -296,7 +363,7 @@ def is_hint_needs_cls_stack(hint: object) -> bool:
 
     Parameters
     ----------
-    hint : object
+    hint : Hint
         Type hint to be inspected.
 
     Returns
