@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -178,36 +178,6 @@ IS_PYTHON_AT_MOST_3_9 = not IS_PYTHON_AT_LEAST_3_10
 :data:`True` only if the active Python interpreter targets at most Python 3.9.x.
 '''
 
-
-#FIXME: After dropping Python 3.8 support:
-#* Refactor all code conditionally testing this global to be unconditional.
-#* Remove this global.
-#* Remove all decorators resembling:
-#  @skip_if_python_version_less_than('3.9.0')
-IS_PYTHON_AT_LEAST_3_9 = IS_PYTHON_AT_LEAST_3_10 or version_info >= (3, 9)
-'''
-:data:`True` only if the active Python interpreter targets at least Python
-3.9.0.
-'''
-
-
-#FIXME: After dropping Python 3.8 support:
-#* Remove all code conditionally testing this global.
-#* Remove this global.
-IS_PYTHON_AT_MOST_3_8 = not IS_PYTHON_AT_LEAST_3_9
-'''
-:data:`True` only if the active Python interpreter targets at most Python 3.8.x.
-'''
-
-
-#FIXME: After dropping Python 3.8 support:
-#* Refactor all code conditionally testing this global to be unconditional.
-#* Remove this global.
-IS_PYTHON_3_8 = version_info[:2] == (3, 8)
-'''
-:data:`True` only if the active Python interpreter targets exactly Python 3.8.x.
-'''
-
 # ....................{ GETTERS                            }....................
 def get_python_version_major_minor() -> str:
     '''
