@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -41,26 +41,38 @@ def label_beartypeable_kind(obj: BeartypeableT) -> str:  # pyright: ignore
         Human-readable label describing the kind of this beartypeable.
     '''
 
+    # ....................{ IMPORTS                        }....................
     # Avoid circular import dependencies.
     from beartype._util.func.utilfunctest import (
         is_func_async,
         is_func_async_generator,
+        is_func_classmethod,
         is_func_coro,
-        is_func_python,
+        is_func_codeobjable,
+        is_func_property,
+        is_func_staticmethod,
         is_func_sync_generator,
     )
     from beartype._util.func.arg.utilfuncargget import (
         get_func_arg_name_first_or_none)
 
-    #FIXME: Globalize magic strings for efficiency, please.
+
+    # ....................{ LOCALS                         }....................
+    # String to be returned, defaulting to a sensible placeholder.
+    obj_label = 'object'
+
+    # ....................{ TYPE                           }....................
+    #FIXME: [SPEED] Globalize all magic strings below for efficiency, please.
+    #Actually, is there any point? Does Python itself automatically intern?
 
     # If this object is a pure-Python class, return an appropriate string.
     if isinstance(obj, type):
-        return 'class'
+        obj_label = 'class'
     # Else, this object is *NOT* a pure-Python class.
     #
-    # If this object is a pure-Python callable...
-    elif is_func_python(obj):
+    # ....................{ CODEOBJABLE                    }....................
+    # If this object is (or encapsulates) a pure-Python callable...
+    elif is_func_codeobjable(obj):
         # Human-readable prefix describing the exotic nature of this callable if
         # this is callable is exotic (e.g., coroutine or generator factory)
         # suffixed by trailing whitespace *OR* the empty string otherwise.
@@ -131,17 +143,38 @@ def label_beartypeable_kind(obj: BeartypeableT) -> str:  # pyright: ignore
         elif arg_first_name == 'cls':
             func_suffix = 'class method'
         # Else, this is neither the canonical first "self" nor "cls" parameter.
-        # In this case, this is assumed to be a non-method callable.
+        # In this case, assume this to be a non-method callable.
         else:
             func_suffix = 'function'
 
         # Return the concatenation of these substrings.
         # print(f'func_prefix: {func_prefix}; func_suffix: {func_suffix}')
-        return f'{func_prefix}{func_suffix}'
-    # Else, this object is neither a pure-Python class *NOR* callable.
+        obj_label = f'{func_prefix}{func_suffix}'
+    # Else, this object is *NOT* a pure-Python callable.
+    #
+    # ....................{ DESCRIPTOR                     }....................
+    # If this object is a C-based uncallable class method descriptor, return an
+    # appropriate string.
+    elif is_func_classmethod(obj):
+        obj_label = 'class method descriptor'
+    # Else, this object is *NOT* a C-based uncallable class method descriptor.
+    #
+    # If this object is a C-based uncallable property method descriptor, return
+    # an appropriate string.
+    elif is_func_property(obj):
+        obj_label = 'property method descriptor'
+    # Else, this object is *NOT* a C-based uncallable property method
+    # descriptor.
+    #
+    # If this object is a C-based uncallable static method descriptor, return
+    # an appropriate string.
+    elif is_func_staticmethod(obj):
+        obj_label = 'static method descriptor'
+    # Else, this object is *NOT* a C-based uncallable static method descriptor.
 
-    # Return a sane placeholder.
-    return 'object'
+    # ....................{ RETURN                         }....................
+    # Return this label.
+    return obj_label
 
 # ....................{ LABELLERS ~ callable               }....................
 #FIXME: Unit test up the "is_context" parameter, which is currently untested.
@@ -223,7 +256,7 @@ def label_callable(
 
         # Substring preceding the string to be returned.
         func_label_prefix = (
-            f'lambda function of '
+            f'lambda function accepting '
             f'{get_func_args_flexible_len(func_codeobj)} argument(s)'
         )
 
@@ -384,60 +417,78 @@ def label_type(
 
     # Avoid circular import dependencies.
     from beartype._util.cls.utilclstest import is_type_builtin
-    from beartype._util.hint.pep.proposal.utilpep544 import (
+    from beartype._util.hint.pep.proposal.pep544 import (
         is_hint_pep544_protocol)
-    from beartype._util.text.utiltextansi import color_attr_name
+    from beartype._util.hint.pep.proposal.pep484585.generic.pep484585gentest import (
+        is_hint_pep484585_generic_subscripted)
+    from beartype._util.text.utiltextansi import color_type
 
-    # Label to be returned, initialized to this class' fully-qualified name.
-    classname = get_object_type_name(cls)
-    # print(f'cls {cls} classname: {classname}')
+    # Label to be returned.
+    classname: str = None  # type: ignore[assignment]
 
-    # If this name contains *NO* periods, this class is actually a builtin type
-    # (e.g., "list"). Since builtin types are well-known and thus
-    # self-explanatory, this name requires no additional labelling. In this
-    # case, return this name as is.
-    if '.' not in classname:
-        pass
-    # Else, this name contains one or more periods but could still be a
-    # builtin indirectly accessed via the standard "builtins" module.
-    #
-    # If this name is that of a builtin type uselessly prefixed by the name of
-    # the module declaring all builtin types (e.g., "builtins.list"), reduce
-    # this name to the unqualified basename of this type (e.g., "list").
-    elif is_type_builtin(cls):
-        classname = cls.__name__
-    # Else, this is a non-builtin class. Non-builtin classes are *NOT*
-    # well-known and thus benefit from additional labelling.
-    #
-    # If this class is a PEP 544-compliant protocol supporting structural
-    # subtyping, label this protocol.
-    elif is_hint_pep544_protocol(cls):
-        # print(f'cls {cls} is protocol!')
-        classname = f'<protocol "{classname}">'
-    # Else if this class is a standard abstract base class (ABC) defined by a
-    # standard submodule also known to support structural subtyping (e.g.,
-    # "collections.abc.Hashable", "contextlib.AbstractContextManager"), label
-    # this ABC as a protocol.
-    #
-    # Note that user-defined ABCs do *NOT* generally support structural
-    # subtyping. Doing so requires esoteric knowledge of undocumented and
-    # mostly private "abc.ABCMeta" metaclass internals unlikely to be
-    # implemented by third-party developers. Thanks to the lack of both
-    # publicity and standardization, there exists *NO* general-purpose means of
-    # detecting whether an arbitrary class supports structural subtyping.
-    elif (
-        classname.startswith('collections.abc.') or
-        classname.startswith('contextlib.')
-    ):
-        classname = f'<protocol ABC "{classname}">'
-    # Else, this is a standard class. In this case, label this class as such.
+    # If this type is a PEP 484- or 585-compliant subscripted generic, the best
+    # label is simply the machine-readable representation of this generic (e.g.,
+    # the string "MuhGeneric[str]" given the generic type declaration "class
+    # MuhGeneric[T](typing.Generic[T]):"). Alternative labels defined below fail
+    # to include the child hint subscripting this subscripted generic.
+    if is_hint_pep484585_generic_subscripted(cls):  # pyright: ignore
+        classname = repr(cls)
+    # Else, this type is *NOT* a PEP 484- or 585-compliant subscripted generic.
+    # In this case...
     else:
-        classname = f'<class "{classname}">'
+        # Fully-qualified name of this type.
+        classname = get_object_type_name(cls)
+        # print(f'cls {cls} classname: {classname}')
+
+        # If this name contains *NO* periods, this class is actually a builtin
+        # type (e.g., "list"). Since builtin types are well-known and thus
+        # self-explanatory, this name requires no additional labelling. In this
+        # case, return this name as is.
+        if '.' not in classname:
+            pass
+        # Else, this name contains one or more periods but could still be a
+        # builtin indirectly accessed via the standard "builtins" module.
+        #
+        # If this name is that of a builtin type uselessly prefixed by the name
+        # of the module declaring all builtin types (e.g., "builtins.list"),
+        # reduce this name to the unqualified basename of this type (e.g.,
+        # "list").
+        elif is_type_builtin(cls):
+            classname = cls.__name__
+        # Else, this is a non-builtin class. Non-builtin classes are *NOT*
+        # well-known and thus benefit from additional labelling.
+        #
+        # If this class is a PEP 544-compliant protocol supporting structural
+        # subtyping, label this protocol.
+        elif is_hint_pep544_protocol(cls):
+            # print(f'cls {cls} is protocol!')
+            classname = f'<protocol "{classname}">'
+        # Else if this class is a standard abstract base class (ABC) defined by
+        # a standard submodule also known to support structural subtyping (e.g.,
+        # "collections.abc.Hashable", "contextlib.AbstractContextManager"),
+        # label this ABC as a protocol.
+        #
+        # Note that user-defined ABCs do *NOT* generally support structural
+        # subtyping. Doing so requires esoteric knowledge of undocumented and
+        # mostly private "abc.ABCMeta" metaclass internals unlikely to be
+        # implemented by third-party developers. Thanks to the lack of both
+        # publicity and standardization, there exists *NO* general-purpose means
+        # of detecting whether an arbitrary class supports structural subtyping.
+        elif (
+            classname.startswith('collections.abc.') or
+            classname.startswith('contextlib.')
+        ):
+            classname = f'<protocol ABC "{classname}">'
+        # Else, this is a standard class. In this case, label this class as such.
+        else:
+            classname = f'<class "{classname}">'
 
     # Return this labelled classname, possibly coloured.
-    return color_attr_name(text=classname, is_color=is_color)
+    return color_type(text=classname, is_color=is_color)
 
 
+#FIXME: Silly, honestly. Is this still called anywhere? Simplify to trivial
+#calls to the vastly superior label_type() function defined above, please.
 def label_object_type(obj: object) -> str:
     '''
     Human-readable label describing the class of the passed object.
