@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -70,8 +70,8 @@ from beartype.door._func.doorcheck import (
 # iterator (i.e., generator iteratively creating and yielding one forward
 # reference proxy for each unqualified relative forward reference in the passed
 # PEP 695-compliant type alias).
-from beartype._util.hint.pep.proposal.utilpep695 import (
-    iter_hint_pep695_forwardrefs as __iter_hint_pep695_forwardref_beartype__)
+from beartype._util.hint.pep.proposal.pep695 import (
+    iter_hint_pep695_unsubscripted_forwardrefs as __iter_hint_pep695_forwardref_beartype__)
 
 # ....................{ GLOBALS                            }....................
 __all__ = [
