@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -42,6 +42,8 @@ from beartype.door._cls.pep.doorpep586 import (
     LiteralTypeHint as LiteralTypeHint)
 from beartype.door._cls.pep.doorpep593 import (
     AnnotatedTypeHint as AnnotatedTypeHint)
+from beartype.door._cls.pep.pep484.doorpep484any import (
+    AnyTypeHint as AnyTypeHint)
 from beartype.door._cls.pep.pep484.doorpep484class import (
     ClassTypeHint as ClassTypeHint)
 from beartype.door._cls.pep.pep484.doorpep484newtype import (
@@ -50,6 +52,10 @@ from beartype.door._cls.pep.pep484.doorpep484typevar import (
     TypeVarTypeHint as TypeVarTypeHint)
 from beartype.door._cls.pep.pep484585.doorpep484585callable import (
     CallableTypeHint as CallableTypeHint)
+from beartype.door._cls.pep.pep484585.doorpep484585generic import (
+    GenericTypeHint as GenericTypeHint)
+from beartype.door._cls.pep.pep484585.doorpep484585subscripted import (
+    SubscriptedTypeHint as SubscriptedTypeHint)
 from beartype.door._cls.pep.pep484585.doorpep484585tuple import (
     TupleFixedTypeHint,
     TupleVariableTypeHint,
