@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -14,12 +14,23 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from abc import ABCMeta
-from beartype.typing import Any
+from beartype.typing import (
+    TYPE_CHECKING,
+    # MutableMapping,
+    # Union,
+)
 from beartype._cave._cavefast import NoneType
+from beartype._data.hint.datahintpep import Hint
 from beartype._util.cache.map.utilmapbig import CacheUnboundedStrong
-from beartype._util.hint.utilhinttest import is_hint_uncached
+from beartype._util.hint.utilhinttest import is_hint_cacheworthy
 from threading import RLock
 
+# If @beartype is currently being statically type-checking (e.g., by mypy),
+# import the top-level "beartype" package to assist static type-checkers in
+# resolving @beartype-specific forward references below.
+if TYPE_CHECKING:
+    import beartype
+
 # ....................{ METACLASSES                        }....................
 #FIXME: Unit test us up, please.
 class _TypeHintMeta(ABCMeta):
@@ -51,7 +62,7 @@ class _TypeHintMeta(ABCMeta):
           instance of that class has *not* yet been instantiated (i.e., if the
           :meth:`__call__` method of this metaclass calling the :meth:`__new__`
           and :meth:`__init__` methods of that class (in that order) has been
-          called), ``None``.
+          called), :data:`None`.
         * Else, the current singleton ABC has been initialized and a singleton
           instance of that class has been instantiated. In this case, that
           instance.
@@ -61,13 +72,14 @@ class _TypeHintMeta(ABCMeta):
         obfuscated by Python to be externally inaccessible.
 
     See Also
-    ----------
+    --------
     https://stackoverflow.com/a/8665179/2809027
         StackOverflow answers strongly inspiring this implementation.
     '''
 
     # ..................{ INSTANTIATORS                      }..................
-    def __call__(cls: '_TypeHintMeta', hint: object) -> Any:  # type: ignore[override]
+    def __call__(cls: '_TypeHintMeta', hint: Hint) -> (
+        'beartype.door.TypeHint'):  # pyright: ignore
         '''
         Factory constructor magically instantiating and returning a singleton
         instance of the concrete subclass of the :class:`beartype.door.TypeHint`
@@ -78,10 +90,15 @@ class _TypeHintMeta(ABCMeta):
         ----------
         cls : _TypeHintMeta
             The :class:`beartype.door.TypeHint` ABC.
-        hint : object
+        hint : Hint
             Low-level type hint to be wrapped by a singleton
             :class:`beartype.door.TypeHint` instance.
 
+        Returns
+        -------
+        beartype.door.TypeHint
+            :class:`beartype.door.TypeHint` object wrapping this hint.
+
         Raises
         ------
         BeartypeDoorNonpepException
@@ -132,7 +149,7 @@ class _TypeHintMeta(ABCMeta):
             # * "typing.ParamSpec".
             # * "typing.TypeVar".
             repr(hint)
-            if is_hint_uncached(hint) else
+            if is_hint_cacheworthy(hint) else
             # Else, this hint is self-caching and thus already reduced to a
             # singleton object. In this case, the identifier identifying this
             # singleton object.
@@ -142,13 +159,13 @@ class _TypeHintMeta(ABCMeta):
         # Type hint wrapper wrapping this hint, efficiently cached such that
         # each hint that evaluates to the same key is wrapped by the same
         # instance of the "TypeHint" class under this Python interpreter.
-        wrapper = (
-            _HINT_KEY_TO_WRAPPER.cache_or_get_cached_func_return_passed_arg(
+        wrapper: 'beartype.door.TypeHint' = (
+            _HINT_KEY_TO_WRAPPER.cache_or_get_cached_func_return_passed_arg(  # type: ignore[assignment]
                 # Cache this wrapper singleton under this key.
                 key=hint_key,
                 # If a wrapper singleton has yet to be instantiated for this
                 # hint, do so by calling this private factory method...
-                value_factory=cls._make_wrapper,
+                value_factory=cls._make_wrapper,  # type: ignore[arg-type]
                 # ...with this hint passed as the sole parameter to that method.
                 arg=hint,
             ))
@@ -157,7 +174,8 @@ class _TypeHintMeta(ABCMeta):
         return wrapper
 
     # ..................{ PRIVATE                            }..................
-    def _make_wrapper(cls: '_TypeHintMeta', hint: object) -> object:
+    def _make_wrapper(cls: '_TypeHintMeta', hint: Hint) -> (
+        'beartype.door.TypeHint'):  # pyright: ignore
         '''
         **Type hint wrapper factory** (i.e., low-level private method creating
         and returning a new :class:`beartype.door.TypeHint` instance wrapping
@@ -169,10 +187,15 @@ class _TypeHintMeta(ABCMeta):
         ----------
         cls : _TypeHintMeta
             The :class:`beartype.door.TypeHint` ABC.
-        hint : object
+        hint : Hint
             Low-level type hint to be wrapped by a singleton
             :class:`beartype.door.TypeHint` instance.
 
+        Returns
+        -------
+        beartype.door.TypeHint
+            :class:`beartype.door.TypeHint` object wrapping this hint.
+
         Raises
         ------
         BeartypeDoorNonpepException
@@ -183,7 +206,7 @@ class _TypeHintMeta(ABCMeta):
 
         # ................{ IMPORTS                            }................
         # Avoid circular import dependencies.
-        from beartype.door._doormap import get_typehint_subclass
+        from beartype.door._cls.util.doorclsget import get_typehint_subclass
 
         # ................{ REDUCTION                          }................
         # Reduce this hint to a more amenable form suitable for mapping to a
@@ -208,14 +231,14 @@ class _TypeHintMeta(ABCMeta):
         # The "None" singleton is used to type callables lacking an explicit
         # "return" statement and thus absurdly common. Ergo, detect this early.
         if hint is None:
-            hint = NoneType  # pyright: ignore[reportGeneralTypeIssues]
+            hint = NoneType  # type: ignore[assignment]
         # Else, this is *NOT* the PEP 484-compliant "None" singleton.
 
         # ................{ INSTANTIATION                      }................
         # Concrete "TypeHint" subclass handling this hint if this hint is
         # supported by an existing "TypeHint" subclass *OR* raise an exception
         # otherwise (i.e., if this hint is currently unsupported).
-        wrapper_subclass = get_typehint_subclass(hint)
+        wrapper_subclass = get_typehint_subclass(hint)  # pyright: ignore
         # print(f'!!!!!!!!!!!!! [ in {repr(cls)}.__new__() ] !!!!!!!!!!!!!!!')
 
         # Type hint wrapper wrapping this hint as a new singleton instance of
@@ -228,9 +251,18 @@ class _TypeHintMeta(ABCMeta):
         return wrapper
 
 # ....................{ PRIVATE ~ mappings                 }....................
+#FIXME: Would've been nice if this had worked, but "pyright" gonna be "pyright".
+# _HINT_KEY_TO_WRAPPER_HINT = MutableMapping[
+#     Union[int, str], 'beartype.door.TypeHint']
+# '''
+# PEP-compliant type hint matching the type hint wrapper cache defined below.
+# '''
+# _HINT_KEY_TO_WRAPPER: _HINT_KEY_TO_WRAPPER_HINT = CacheUnboundedStrong(  # type: ignore[assignment]
+
+
 _HINT_KEY_TO_WRAPPER = CacheUnboundedStrong(
-    # Prefer the slower reentrant lock type for safety. As the subpackage name
-    # implies, the DOOR API is fundamentally recursive and requires reentrancy.
+    # Prefer the slower reentrant lock type for safety. As the subpackage
+    # name implies, the DOOR API is recursive and requires reentrancy.
     lock_type=RLock,
 )
 '''
@@ -240,7 +272,7 @@ of concrete subclasses of the :class:`beartype.door.TypeHint` abstract base
 class (ABC) wrapping those hints).
 
 Design
---------------
+------
 **This dictionary is intentionally thread-safe.** Why? Because this dictionary
 is used to ensure that :class:`beartype.door.TypeHint` instances are singletons,
 enabling callers to reliably implement higher-level abstractions memoized (i.e.,
