@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -17,12 +17,14 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                            }....................
 from beartype.door._cls.doormeta import _TypeHintMeta
-from beartype.door._doortest import die_unless_typehint
+from beartype.door._cls.util.doorclstest import die_unless_typehint
 from beartype.door._func.doorcheck import (
     die_if_unbearable,
     is_bearable,
 )
+from beartype.roar import BeartypeDoorIsSubhintException
 from beartype.typing import (
+    # TYPE_CHECKING,
     Any,
     FrozenSet,
     Generic,
@@ -30,8 +32,10 @@ from beartype.typing import (
     Tuple,
     overload,
 )
+from beartype._check.convert.convsanify import sanify_hint_child
 from beartype._conf.confcls import BeartypeConf
 from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
+from beartype._data.hint.datahintpep import T_Hint
 from beartype._data.hint.datahinttyping import T
 from beartype._util.cache.utilcachecall import (
     method_cached_arg_by_id,
@@ -42,13 +46,12 @@ from beartype._util.hint.pep.utilpepget import (
     get_hint_pep_origin_type_or_none,
     get_hint_pep_sign_or_none,
 )
-from beartype._util.hint.utilhinttest import is_hint_ignorable
 from beartype._util.utilobject import get_object_type_basename
 
 # ....................{ SUPERCLASSES                       }....................
 #FIXME: Subclass all applicable "collections.abc" ABCs for explicitness, please.
 #FIXME: Document all public and private attributes of this class, please.
-class TypeHint(Generic[T], metaclass=_TypeHintMeta):
+class TypeHint(Generic[T_Hint], metaclass=_TypeHintMeta):
     '''
     Abstract base class (ABC) of all **type hint wrapper** (i.e., high-level
     object encapsulating a low-level type hint augmented with a magically
@@ -92,10 +95,10 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
     Attributes
     ----------
-    _args : Tuple[object, ...]
+    _args : Tuple[Hint, ...]
         Tuple of the zero or more low-level child type hints subscripting
         (indexing) the low-level parent type hint wrapped by this wrapper.
-    _hint : T
+    _hint : T_Hint
         Low-level type hint wrapped by this wrapper.
     _hint_sign : beartype._data.hint.pep.sign.datapepsigncls.HintSign | None
         Either:
@@ -114,13 +117,13 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
     '''
 
     # ..................{ INITIALIZERS                       }..................
-    def __init__(self, hint: T) -> None:
+    def __init__(self, hint: T_Hint) -> None:
         '''
         Initialize this type hint wrapper from the passed low-level type hint.
 
         Parameters
         ----------
-        hint : object
+        hint : Hint
             Low-level type hint to be wrapped by this wrapper.
         '''
 
@@ -136,7 +139,13 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         # defined as either...
         self._origin: type = (
             # If this hint originates from an origin type, that type;
-            get_hint_pep_origin_type_or_none(hint) or
+            get_hint_pep_origin_type_or_none(
+                hint=hint,
+                # If this hint is a type defining the "__origin__" dunder
+                # attribute to be a non-type, fallback to euphemistically
+                # claiming that this hint originates from "itself." Boooo!
+                is_self_fallback=True,
+            ) or
             # Else, this hint does *NOT* originate from an origin type. In this
             # case, the root superclass "object" of *ALL* classes, guaranteeing
             # sanity when this instance variable is passed as either the first
@@ -189,7 +198,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
     @method_cached_arg_by_id
     def __eq__(self, other: object) -> bool:
         '''
-        ``True`` only if the low-level type hint wrapped by this wrapper is
+        :data:`True`` only if the low-level type hint wrapped by this wrapper is
         semantically equivalent to the other low-level type hint wrapped by the
         passed wrapper.
 
@@ -205,25 +214,37 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         Returns
         -------
         bool
-            ``True`` only if this type hint is equal to that other hint.
+            :data:`True` only if this type hint is equal to that other hint.
         '''
 
-        # If that object is *NOT* a type hint wrapper, defer to either:
-        # * If the class of that object defines a similar __eq__() method
-        #   supporting the "TypeHint" API, that method.
-        # * Else, Python's builtin C-based fallback equality comparator that
-        #   merely compares whether two objects are identical (i.e., share the
-        #   same object ID).
-        if not isinstance(other, TypeHint):
-            return NotImplemented
-        # Else, that object is also a type hint wrapper.
-
-        # Defer to the subclass-specific implementation of this test.
-        return self._is_equal(other)
+        # Return either...
+        return (
+            # If that object is a type hint wrapper, defer to the
+            # subclass-specific implementation of this test;
+            self._is_equal(other)
+            if isinstance(other, TypeHint) else
+            # Else, that object is *NOT* a type hint wrapper. In this case,
+            # defer to either:
+            # * If the class of that object defines a similar __eq__() method
+            #   supporting the "TypeHint" API, that method.
+            # * Else, Python's builtin C-based fallback equality comparator that
+            #   merely compares whether two objects are identical (i.e., share
+            #   the same object ID).
+            NotImplemented
+        )
 
 
     def __ne__(self, other: object) -> bool:
-        return not (self == other)
+
+        # Return either...
+        return (
+            # If that object is a type hint wrapper, defer to the
+            # subclass-specific implementation of this test;
+            not self._is_equal(other)
+            if isinstance(other, TypeHint) else
+            # Else, that object is *NOT* a type hint wrapper. See __eq__().
+            NotImplemented
+        )
 
     # ..................{ DUNDERS ~ compare : rich           }..................
     def __le__(self, other: object) -> bool:
@@ -231,10 +252,15 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         :data:`True` if this hint is a subhint of the passed hint.
         '''
 
-        if not isinstance(other, TypeHint):
-            return NotImplemented
-
-        return self.is_subhint(other)
+        # Return either...
+        return (
+            # If that object is a type hint wrapper, defer to the
+            # subclass-specific implementation of this test;
+            self.is_subhint(other)
+            if isinstance(other, TypeHint) else
+            # Else, that object is *NOT* a type hint wrapper. See __eq__().
+            NotImplemented
+        )
 
 
     def __lt__(self, other: object) -> bool:
@@ -242,10 +268,15 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         :data:`True` if this hint is a strict subhint of the passed hint.
         '''
 
-        if not isinstance(other, TypeHint):
-            return NotImplemented
-
-        return self.is_subhint(other) and self != other
+        # Return either...
+        return (
+            # If that object is a type hint wrapper, defer to the
+            # subclass-specific implementation of this test;
+            (self.is_subhint(other) and self != other)
+            if isinstance(other, TypeHint) else
+            # Else, that object is *NOT* a type hint wrapper. See __eq__().
+            NotImplemented
+        )
 
 
     def __ge__(self, other: object) -> bool:
@@ -253,10 +284,15 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         :data:`True` if this hint is a superhint of the passed hint.
         '''
 
-        if not isinstance(other, TypeHint):
-            return NotImplemented
-
-        return self.is_superhint(other)
+        # Return either...
+        return (
+            # If that object is a type hint wrapper, defer to the
+            # subclass-specific implementation of this test;
+            self.is_superhint(other)
+            if isinstance(other, TypeHint) else
+            # Else, that object is *NOT* a type hint wrapper. See __eq__().
+            NotImplemented
+        )
 
 
     def __gt__(self, other: object) -> bool:
@@ -264,10 +300,15 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         :data:`True` if this hint is a strict superhint of the passed hint.
         '''
 
-        if not isinstance(other, TypeHint):
-            return NotImplemented
-
-        return self.is_superhint(other) and self != other
+        # Return either...
+        return (
+            # If that object is a type hint wrapper, defer to the
+            # subclass-specific implementation of this test;
+            (self.is_superhint(other) and self != other)
+            if isinstance(other, TypeHint) else
+            # Else, that object is *NOT* a type hint wrapper. See __eq__().
+            NotImplemented
+        )
 
     # ..................{ DUNDERS ~ iterable                 }..................
     def __contains__(self, hint_child: 'TypeHint') -> bool:
@@ -393,6 +434,17 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         '''
         Tuple of the zero or more low-level child type hints subscripting
         (indexing) the low-level parent type hint wrapped by this wrapper.
+
+        Caveats
+        -------
+        Note that this property is intentionally *not* annotated as returning a
+        tuple of valid type hints (e.g., ``Tuple[Hint, ...]``). Although most
+        child hints *are* valid type hints outside the context of this parent
+        hint, some are not. Examples include:
+
+        * :pep:`586`-compliant ``typing.Literal[...]`` hints, subscripted by
+          literal objects that are *not* valid hints (e.g.,
+          ``typing.Literal['totally', 'not', 'a', 'type']``,).
         '''
 
         # Who could argue with a working one-liner? Not you. Surely, not you.
@@ -400,7 +452,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
 
     @property
-    def hint(self) -> T:
+    def hint(self) -> T_Hint:
         '''
         **Original type hint** (i.e., low-level PEP-compliant type hint wrapped
         by this wrapper at :meth:`TypeHint.__init__` instantiation time).
@@ -491,8 +543,8 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
             :data:`True` only if this type hint is ignorable.
         '''
 
-        # Mechanic: Somebody set up us the bomb.
-        return is_hint_ignorable(self._hint)
+        # Return true only if this hint is ignorable.
+        return sanify_hint_child(self._hint) is Any  # pyright: ignore
 
     # ..................{ CHECKERS                           }..................
     def die_if_unbearable(
@@ -598,7 +650,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
         Examples
         --------
-        .. code-block:: python
+        .. code-block:: pycon
 
            >>> from beartype.door import TypeHint
            >>> TypeHint(list[str]).is_bearable(['Things', 'fall', 'apart;'])
@@ -642,6 +694,7 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         :func:`beartype.door.is_subhint`
             Further details.
         '''
+        # print(f'[TypeHint.is_subhint] Comparing {self} to {other}...')
 
         # If the passed object is *NOT* a type hint wrapper, raise an exception.
         die_unless_typehint(other)
@@ -649,12 +702,11 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
         # Return true only if either...
         return (
-            # That other hint is the "typing.Any" catch-all. By definition, that
-            # hint is the superhint of *ALL* hints -- including "typing.Any"
-            # itself. Ergo, this hint is necessarily a subhint of that hint.
+            # That hint is the "typing.Any" catch-all (then this hint is
+            # necessarily a subhint of that hint) *OR*...
             other._hint is Any or
-            # Else, that other hint is *NOT* the "typing.Any" catch-all. In this
-            # case, defer to the subclass-specific implementation of this test.
+            # This hint is a subhint of that hint (according to the
+            # subclass-specific implementation of this test).
             self._is_subhint(other)
         )
 
@@ -704,6 +756,17 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
 
         Subclasses are advised to override this method to set the :attr:`_args`
         instance variable of this wrapper in a subclass-specific manner.
+
+        Caveats
+        -------
+        Note that this method is intentionally *not* annotated as returning a
+        tuple of valid type hints (e.g., ``Tuple[Hint, ...]``). Although most
+        child hints *are* valid type hints outside the context of this parent
+        hint, some are not. Examples include:
+
+        * :pep:`586`-compliant ``typing.Literal[...]`` hints, subscripted by
+          literal objects that are *not* valid hints (e.g.,
+          ``typing.Literal['totally', 'not', 'a', 'type']``,).
         '''
 
         # We are the one-liner. We are the codebase.
@@ -783,13 +846,27 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         :func:`beartype.door.is_subhint`
             Further details.
         '''
+        # print(f'[TypeHint._is_subhint] Comparing {self} to {other}...')
 
-        # Return true only if this hint is a subhint of *ANY* branch of that
-        # other hint.
-        return any(
-            self._is_subhint_branch(other_branch)
-            for other_branch in other._branches
-        )
+        # For each branch of that hint...
+        for other_branch in other._branches:
+            # If either...
+            if (
+                # That branch is the "typing.Any" catch-all (then this hint is
+                # necessarily a subhint of that branch) *OR*...
+                other_branch._hint is Any or
+                # This hint is a subhint of that branch (according to the
+                # subclass-specific implementation of this test)...
+                self._is_subhint_branch(other_branch)
+            ):
+                # Then this hint is a subhint of that hint.
+                return True
+            # Else, this hint is *NOT* a subhint of that branch. In this case,
+            # continue to the next branch of that other hint.
+        # Else, this hint is *NOT* a subhint of any branch of that other hint.
+
+        # Return false as a fallback.
+        return False
 
 
     def _is_subhint_branch(self, branch: 'TypeHint') -> bool:
@@ -803,35 +880,100 @@ class TypeHint(Generic[T], metaclass=_TypeHintMeta):
         branch : TypeHint
             Conditional branch of another type hint to be tested against.
 
+        Raises
+        ------
+        BeartypeDoorIsSubhintException
+            If this type hint and the passed branch are **incommensurable**
+            (i.e., incomparable with respect to the subhint relation). This rare
+            edge case typically arises due to an unexpected internal issue
+            (i.e., bug) within the :mod:beartype.door` API. Computing the
+            subhint relation between any two type hints is a surprisingly
+            non-trivial decision problem. Unsurprisingly, doing so mostly
+            rarely blows up with this exception.
+
         See Also
         --------
         :meth:`__le__`
             Further details.
         '''
+        # print(f'Entering is_subhint_branch({self}, {branch})...')
 
+        # If the type originating this hint is *NOT* a subclass of the type
+        # originating that branch, this hint *CANNOT* be a subhint of that
+        # branch. Return false immediately.
+        if not issubclass(self._origin, branch._origin):
+            return False
+        # Else, the class originating this hint is a subclass of the class
+        # originating that branch. In this case, this hint *COULD* be a subhint
+        # of that branch. Further tests are warranted.
+        #
         # If that branch is unsubscripted, assume that branch to have been
-        # subscripted by "Any" by simply checking for compatible origin types.
-        if branch._is_args_ignorable:
+        # subscripted by "Any". Since *ANY* child hint subscripting this hint is
+        # necessarily a subhint of "Any", this hint is a subhint of that branch.
+        # Return true immediately.
+        elif branch._is_args_ignorable:
             # print(f'is_subhint_branch({self}, {branch} [unsubscripted])')
-            return issubclass(self._origin, branch._origin)
+            return True
         # Else, that branch is subscripted.
+        #
+        # If that branch is *NOT* also a type hint wrapper of the same subclass
+        # as this type hint wrapper, these two wrappers are incommensurable
+        # (i.e., *NOT* comparable). Return false immediately.
+        elif not isinstance(branch, type(self)):
+            return False
+        # Else, that branch is also a type hint wrapper of the same subclass
+        # as this type hint wrapper, implying these two wrappers are
+        # incommensurable (i.e., comparable). In this case, this hint *COULD* be
+        # a subhint of that branch. Further tests are warranted.
 
-        # Return true only if...
-        return (
-            # That branch is also a type hint wrapper of the same concrete
-            # subclass as this type hint wrapper *AND*...
-            isinstance(branch, type(self)) and
-            # The class originating this hint is a subclass of the class
-            # originating that branch...
-            issubclass(self._origin, branch._origin) and
-            # All child type hints of this parent type hint are subhints of the
-            # corresponding child type hints of that branch.
-            all(
-                self_child <= branch_child
-                for self_child, branch_child in zip(
-                    self._args_wrapped_tuple, branch._args_wrapped_tuple)
+        # If these two hints are subscripted by a differing number of child
+        # hints, raise an exception. Why? Because this rare edge case almost
+        # certainly signifies a low-level issue internal to this "beartype.door"
+        # subpackage. Silently "accepting" this issue by instead returning a
+        # boolean would constitute a false negative or positive. Moreover, the
+        # zip() builtin called below silently ignores the trailing portion of
+        # the longest iterable exceeding the length of the smallest iterable.
+        # Silently permitting that would invite issues throughout this API.
+        if len(self._args_wrapped_tuple) != len(branch._args_wrapped_tuple):
+            # Number of child hints subscripting these two hints.
+            self_args_len = len(self._args_wrapped_tuple)
+            branch_args_len = len(branch._args_wrapped_tuple)
+
+            # Raise an exception embedding these numbers.
+            raise BeartypeDoorIsSubhintException(
+                f'{self} <= {branch} undecidable, as '
+                f'{self._hint} and {branch._hint} subscripted by '
+                f'differing number of child type hints '
+                f'(i.e., {self_args_len} != {branch_args_len}).'
             )
-        )
+        # Else, these two hints are subscripted by the same number of child
+        # hints.
+
+        # For each pair of corresponding child hints subscripting these two
+        # hints, encapsulated as type hint wrappers...
+        #
+        # Note that the zip() builtin has been quantitatively profiled to be
+        # approximately as fast as manual iteration (e.g., leveraging some
+        # combination of the enumerate(), len(), and range() builtins). Since
+        # zip() is likely to be optimized even further *AND* since this approach
+        # is substantially more concise, let's go. See also:
+        #     https://stackoverflow.com/a/62479781/2809027
+        for self_child, branch_child in zip(
+            self._args_wrapped_tuple, branch._args_wrapped_tuple):
+            # If this child hint is *NOT* a subhint of that child hint, this
+            # hint is *NOT* a subhint of that branch. In this case,
+            # short-circuit by immediately returning false.
+            if not self_child.is_subhint(branch_child):
+                return False
+            # Else, this child hint is a subhint of that child hint. In this
+            # case, this hint *COULD* be a subhint of that branch. Decide by
+            # continuing to the next pair of child hints.
+        # Else, each child hint of this hint is a subhint of the corresponding
+        # child hint of that branch. In this case, this hint is a subhint of
+        # that branch.
+
+        # Return true! We have liftoff.
+        return True
 
     # ..................{ PRIVATE ~ properties : read-only   }..................
     # Read-only properties intentionally defining *NO* corresponding setter.
