@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -12,6 +12,7 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
+from beartype.door._cls.doorhint import TupleTypeHints
 from beartype.door._cls.doorsuper import TypeHint
 from beartype.roar import BeartypeDoorPepUnsupportedException
 from beartype.typing import (
@@ -20,9 +21,8 @@ from beartype.typing import (
 )
 from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_CALLABLE_PARAMS)
-# from beartype._data.kind.datakindsequence import TUPLE_EMPTY
 from beartype._util.cache.utilcachecall import property_cached
-from beartype._util.hint.pep.proposal.pep484585.utilpep484585callable import (
+from beartype._util.hint.pep.proposal.pep484585.pep484585callable import (
     get_hint_pep484585_callable_params,
     get_hint_pep484585_callable_return,
 )
@@ -97,7 +97,6 @@ class CallableTypeHint(TypeHint):
             args = (..., Any,)
         else:
             # Parameters type hint(s) subscripting this callable type hint.
-            #
             # Note that this:
             # * May be a special object (e.g., ellipsis) rather than a tuple of
             #   zero or more parameter type hints.
@@ -144,7 +143,7 @@ class CallableTypeHint(TypeHint):
     # ..................{ PRIVATE ~ properties               }..................
     @property
     # @property_cached
-    def _args_wrapped_tuple(self) -> Tuple[TypeHint, ...]:
+    def _args_wrapped_tuple(self) -> TupleTypeHints:
 
         # Tuple of all child type hints subscripting this callable type hint.
         args = self._args
@@ -154,7 +153,7 @@ class CallableTypeHint(TypeHint):
 
         # Tuple of all child type hint wrappers subscripting this callable type
         # hint wrapper, initialized to the empty tuple for simplicity.
-        args_wrapped_tuple: Tuple[TypeHint, ...] = ()
+        args_wrapped_tuple: TupleTypeHints = ()
 
         # If this type hint is unsubscripted, return the empty tuple.
         if not args_len:
@@ -168,7 +167,7 @@ class CallableTypeHint(TypeHint):
             # Return a 2-tuple consisting of...
             args_wrapped_tuple = (
                 # Empty parameter list.
-                TypeHint(Tuple[()]),
+                TypeHint(Tuple[()]),  # pyright: ignore
                 # Return type hint.
                 TypeHint(args[-1]),
             )
@@ -181,7 +180,7 @@ class CallableTypeHint(TypeHint):
             # Return a 2-tuple consisting of...
             args_wrapped_tuple = (
                 # Variadic parameter list.
-                TypeHint(Any),
+                TypeHint(Any),  # pyright: ignore
                 # Return type hint.
                 TypeHint(args[-1]),
             )
@@ -197,7 +196,7 @@ class CallableTypeHint(TypeHint):
     # ..................{ PROPERTIES ~ hints                 }..................
     @property  # type: ignore
     @property_cached
-    def param_hints(self) -> Tuple[TypeHint, ...]:
+    def param_hints(self) -> TupleTypeHints:
         '''
         Tuple of the one or more parameter type hints subscripting this
         callable type hint.
@@ -224,17 +223,6 @@ class CallableTypeHint(TypeHint):
         return self._args_wrapped_tuple[-1]
 
     # ..................{ PROPERTIES ~ bools                 }..................
-    # FIXME: Remove this by instead adding support for ignoring ignorable
-    # callable type hints to our core is_hint_ignorable() tester. Specifically:
-    # * Ignore "Callable[..., {hint_ignorable}]" type hints, where "..." is the
-    #  ellipsis singleton and "{hint_ignorable}" is any ignorable type hint.
-    #  This has to be handled in a deep manner by:
-    #  * Defining a new is_hint_pep484585_ignorable_or_none() tester in the
-    #    existing "utilpep484585" submodule, whose initial implementation tests
-    #    for *ONLY* ignorable callable type hints.
-    #  * Import that tester in the "utilpeptest" submodule.
-    #  * Add that tester to the "_IS_HINT_PEP_IGNORABLE_TESTERS" tuple.
-    #  * Add example ignorable callable type hints to our test suite's data.
     @property
     def is_ignorable(self) -> bool:
         # Callable[..., Any] (or just `Callable`)
@@ -253,18 +241,28 @@ class CallableTypeHint(TypeHint):
         return self.return_hint.is_ignorable
 
     # ..................{ PRIVATE ~ testers                  }..................
-    #FIXME: Internally comment us up, please.
     def _is_subhint_branch(self, branch: TypeHint) -> bool:
+        # print(f'Entering _is_subhint_branch({self}, {branch})...')
+        # print(f'{branch}._is_args_ignorable: {branch._is_args_ignorable}')
 
         # If that branch is unsubscripted (e.g., "typing.Callable"), assume that
-        # branch to be subscripted as "typing.Callable[..., Any]" by reducing to
-        # a test for compatible origin types.
+        # branch to be subscripted as the maximally wide callable type hint
+        # "typing.Callable[..., Any]". Since *ALL* callable type hints are
+        # necessarily subhints of that hint, return true only if the class
+        # originating this hint is a subclass of the class
+        # originating that branch.
         if branch._is_args_ignorable:
             return issubclass(self._origin, branch._origin)
+        # Else, that branch is subscripted (e.g., "typing.Callable[..., int]").
+        #
+        # If that branch is *NOT* a callable type hint, this callable type hint
+        # is incommensurable with that branch and thus *CANNOT* be a subhint of
+        # that branch. Return false.
         elif not isinstance(branch, CallableTypeHint):
             return False
-        elif not issubclass(self._origin, branch._origin):
-            return False
+        # Else, that branch is a callable type hint.
+
+        #FIXME: Internally comment us up, please.
         elif not branch.is_params_ignorable and (
             (
                 self.is_params_ignorable or
