@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -22,12 +22,12 @@ This private submodule is *not* intended for importation by downstream callers.
 # ....................{ IMPORTS                            }....................
 from beartype.roar import BeartypePep563Exception
 from beartype._check.metadata.metadecor import make_beartype_call
-from beartype._check.forward.fwdmain import resolve_hint
+from beartype._check.forward.fwdresolve import resolve_hint
 from beartype._conf.confcls import BeartypeConf
 from beartype._conf.confcommon import BEARTYPE_CONF_DEFAULT
 from beartype._data.hint.datahinttyping import TypeStack
-from beartype._util.cache.pool.utilcachepoolobjecttyped import (
-    release_object_typed)
+from beartype._util.cache.pool.utilcachepoolinstance import (
+    release_instance)
 from beartype._util.func.utilfuncget import get_func_annotations
 from collections.abc import Callable
 
@@ -44,7 +44,7 @@ def resolve_pep563(
     Resolve all :pep:`563`-based **postponed annotations** (i.e., strings that
     when dynamically evaluated as Python expressions yield actual annotations)
     on the passed callable to their **referents** (i.e., the actual annotations
-    to which those postponed annotations evaluate) if `PEP 563`_ is active for
+    to which those postponed annotations evaluate) if :pep:`563` is active for
     that callable *or* silently reduce to a noop otherwise (i.e., if :pep:`563`
     is *not* active for that callable).
 
@@ -135,7 +135,7 @@ def resolve_pep563(
         lexically nesting the current class. In short, just pass everything.
 
     Raises
-    ----------
+    ------
     BeartypePep563Exception
         If either:
 
@@ -199,7 +199,7 @@ def resolve_pep563(
     #
     # For the name of each annotated parameter and return of the passed callable
     # and the type hint annotating that parameter or return...
-    for arg_name, hint in arg_name_to_hint.items():
+    for hint in arg_name_to_hint.values():
         # If this hint is *NOT* stringified, this hint was either:
         # * Never postponed under PEP 563 (i.e., the module defining that
         #   callable did *NOT* import "from __future__ import annotations").
@@ -236,13 +236,9 @@ def resolve_pep563(
 
     # ..................{ LOCALS                             }..................
     # Beartype call metadata describing the passed callable.
-    decor_meta = make_beartype_call(
-        func=func,
-        conf=conf,
-        cls_stack=cls_stack,
-    )
+    decor_meta = make_beartype_call(func=func, conf=conf, cls_stack=cls_stack)
 
-    # Make a shallow copy of the dictionary to be returned. Why? Because the
+    # Shallow copy of the dictionary to be returned. Why? Because the
     # "func.__annotations__" dictionary *CANNOT* be safely directly assigned to
     # below, as the loop performing that assignment below necessarily iterates
     # over that dictionary. As with most languages, Python containers cannot be
@@ -261,30 +257,20 @@ def resolve_pep563(
     #   no faster or even slower than explicit iteration for small dictionary
     #   sizes, as "func.__annotations__" usually is).
     for arg_name, hint in arg_name_to_hint.items():
-        # If this hint is stringified, resolve this stringified type hint to the
-        # non-string type hint to which this string refers.
-        #
-        # Note that this test could technically yield a false positive in the
-        # unlikely edge case that this hint was previously postponed but has
-        # since been replaced in-place by its referent that is itself a PEP
-        # 484-compliant forward reference matching the PEP 563 format without
-        # actually being a PEP 563-postponed type hint. Since PEP 563 failed to
-        # provide solutions to this or any other outstanding runtime issues with
-        # PEP 563, there is *NOTHING* we can differentiate these two edge cases.
-        # Instead, we pretend everything will be okay. "Trust me, bro!"
-        if isinstance(hint, str):
-            arg_name_to_hint[arg_name] = resolve_hint(
-                hint=hint,
-                decor_meta=decor_meta,
-                exception_cls=BeartypePep563Exception,
-            )
-        # Else, this hint is *NOT* stringified. In this case, preserve this hint
-        # as is.
+        # Resolve this stringified type hint to the non-string type hint to
+        # which this string refers.
+        arg_name_to_hint[arg_name] = resolve_hint(
+            hint=hint,
+            decor_meta=decor_meta,
+            exception_cls=BeartypePep563Exception,
+        )
 
     # ..................{ RETURN                             }..................
     # Release this beartype call metadata back to its object pool.
-    release_object_typed(decor_meta)
+    release_instance(decor_meta)
 
+    #FIXME: Shift this logic into a new set_object_annotations() function. Under
+    #Python >= 3.14, this logic is likely to require delicate surgery. *sigh*
     # Attempt to...
     try:
         # Atomically (i.e., all-at-once) replace that callable's postponed
