@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -49,9 +49,25 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
     # Defer fixture-specific imports.
     import collections.abc
     import typing
-    from beartype._data.hint.datahinttyping import S, T
+    from abc import ABCMeta
+    from beartype._data.hint.datahinttyping import (
+        S,
+        T,
+    )
+    from beartype._util.cls.utilclstest import is_type_subclass_proper
     from beartype._util.hint.pep.utilpepget import get_hint_pep_typevars
-    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
+    from beartype_test.a00_unit.data.hint.pep.proposal.data_pep484 import (
+        T_sequence,
+        T_int_or_str,
+    )
+    from beartype_test.a00_unit.data.hint.pep.proposal.pep484585.data_pep484585generic import (
+        Pep484GenericT,
+        Pep484GenericSubT,
+        Pep484GenericST,
+        Pep484GenericSInt,
+        # Pep484GenericIntInt,
+        Pep585SequenceT,
+    )
     from collections.abc import (
         Collection as CollectionABC,
         Sequence as SequenceABC,
@@ -60,14 +76,7 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
     # Intentionally import from "beartype.typing" rather than "typing" to
     # guarantee PEP 544-compliant caching protocol type hints.
     from beartype.typing import (
-        Literal,
-        Protocol,
-        TypedDict,
-    )
-
-    # Intentionally import from "typing" rather than "beartype.typing" to
-    # guarantee PEP 484-compliant type hints.
-    from typing import (
+        Annotated,
         Any,
         Awaitable,
         ByteString,
@@ -75,31 +84,28 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         Collection,
         DefaultDict,
         Dict,
-        Generic,
         Hashable,
         Iterable,
         List,
+        Literal,
         Mapping,
         NamedTuple,
         NewType,
         Optional,
+        Protocol,
         Reversible,
         Sequence,
         Sized,
         Tuple,
         Type,
-        TypeVar,
+        TypedDict,
+        # TypeVar,
         Union,
     )
 
     # ..................{ NEWTYPES                           }..................
     NewStr = NewType('NewStr', str)
 
-    # ..................{ TYPEVARS                           }..................
-    # Arbitrary constrained type variables.
-    T_sequence = TypeVar('T_sequence', bound=SequenceABC)
-    T_int_or_str = TypeVar('T_int_or_str', int, str)
-
     # ..................{ CLASSES                            }..................
     class MuhThing:
         def muh_method(self):
@@ -139,32 +145,6 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         thing_one: str
         thing_two: int
 
-    # ..................{ CLASSES ~ generics                 }..................
-    class MuhGeneric(Generic[T]):
-        '''
-        Arbitrary generic parametrized by one unconstrained type variable.
-        '''
-
-        pass
-
-
-    class MuhGenericTwo(Generic[S, T]):
-        '''
-        Arbitrary generic parametrized by two unconstrained type variables.
-        '''
-
-        pass
-
-
-    class MuhGenericTwoIntInt(MuhGenericTwo[int, int]):
-        '''
-        Arbitrary concrete generic subclass inheriting the
-        :class:`.MuhGenericTwo` generic superclass subscripted twice by the
-        builtin :class:`int` type.
-        '''
-
-        pass
-
     # ..................{ LISTS ~ cases                      }..................
     # List of all hint subhint cases (i.e., 3-tuples "(subhint, superhint,
     # is_subhint)" describing the subhint relations between two PEP-compliant
@@ -176,7 +156,7 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         (Tuple[object, ...], Any, True),
         (Union[int, MuhThing], Any, True),
 
-        # Although *ALL* type hints are subhints of "Any", "Any" is only a
+        # Although *ALL* type hints are subhints of "Any", "Any" is *ONLY* a
         # subhint of itself.
         (Any, Any, True),
         (Any, object, False),
@@ -238,7 +218,72 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         (int, float, False),
         (float, complex, False),
 
-        # ..................{ PEP 484 ~ arg : callable       }..................
+        # ..................{ PEP 484 ~ generic              }..................
+        # "typing.Generic"-centric tests.
+
+        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+        # CAUTION: Synchronize changes below by replacing all references in
+        # the first tuple item to "Pep484GenericT" with "Pep484GenericSubT".
+        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+        # PEP 484-compliant generic superclasses parametrized by one
+        # unconstrained type variables.
+        (Pep484GenericT, Pep484GenericT, True),
+        (Pep484GenericT, Pep484GenericT[int], False),
+        (Pep484GenericT[int], Pep484GenericT, True),
+        (Pep484GenericT[int], Pep484GenericT[T_sequence], False),
+        (Pep484GenericT[list], Pep484GenericT[T_sequence], True),
+        (Pep484GenericT[list], Pep484GenericT[Sequence], True),
+        (Pep484GenericT[str], Pep484GenericT[T_sequence], True),
+        (Pep484GenericT[Sequence], Pep484GenericT[list], False),
+        (Pep484GenericT[T_sequence], Pep484GenericT, True),
+
+        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+        # CAUTION: Synchronize changes above.
+        #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+        # PEP 484-compliant generic subclasses parametrized by one unconstrained
+        # type variables.
+        (Pep484GenericSubT, Pep484GenericT, True),
+        (Pep484GenericSubT, Pep484GenericT[int], False),
+        (Pep484GenericSubT[int], Pep484GenericT, True),
+        (Pep484GenericSubT[int], Pep484GenericT[T_sequence], False),
+        (Pep484GenericSubT[list], Pep484GenericT[T_sequence], True),
+        (Pep484GenericSubT[list], Pep484GenericT[Sequence], True),
+        (Pep484GenericSubT[str], Pep484GenericT[T_sequence], True),
+        (Pep484GenericSubT[Sequence], Pep484GenericT[list], False),
+        (Pep484GenericSubT[T_sequence], Pep484GenericT, True),
+
+        # PEP 484-compliant generic subclasses parametrized by one unconstrained
+        # type variables and one concrete type.
+        (Pep484GenericSInt, Pep484GenericST, True),
+        (Pep484GenericSInt, Pep484GenericST[int, int], False),
+        (Pep484GenericSInt[int], Pep484GenericST, True),
+        (Pep484GenericSInt[int], Pep484GenericST[S, T_sequence], False),
+        (Pep484GenericSInt[list], Pep484GenericST[T_sequence, object], True),
+        (Pep484GenericSInt[list], Pep484GenericST[Sequence, Any], True),
+        (Pep484GenericSInt[str], Pep484GenericST[T_sequence, S], True),
+        (Pep484GenericSInt[Sequence], Pep484GenericST[list, object], False),
+        (Pep484GenericSInt[T_sequence], Pep484GenericST, True),
+
+        # ..................{ PEP 484 ~ optional             }..................
+        # "typing.Optional"-centric tests.
+
+        # PEP 484-compliant optionals.
+        (int, Optional[int], True),
+        (Optional[int], int, False),
+        (list, Optional[Sequence], True),
+
+        # ..................{ PEP 484 ~ union                }..................
+        # "typing.Union"-centric tests.
+
+        # PEP 484-compliant unions.
+        (int, Union[int, str], True),
+        (Union[int, str], Union[list, int, str], True),
+        (Union[str, int], Union[int, str, list], True),  # order doesn't matter
+        (Union[str, list], Union[str, int], False),
+        (Union[int, str, list], list, False),
+        (Union[int, str, list], Union[int, str], False),
+
+        # ..................{ PEP (484|585) ~ callable       }..................
         # PEP 484-compliant callable type hints.
         (Callable, Callable[..., Any], True),
         (Callable[[], int], Callable[..., Any], True),
@@ -257,23 +302,21 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         (Callable[[int, str], int], Callable[[int, str], Any], True),
         # (types.FunctionType, Callable, True),  # FIXME
 
-        # ..................{ PEP 484 ~ arg : generic        }..................
-        # PEP 484-compliant generics parametrized by one type variable.
-        (MuhGeneric, MuhGeneric, True),
-        (MuhGeneric, MuhGeneric[int], False),
-        (MuhGeneric[int], MuhGeneric, True),
-        (MuhGeneric[int], MuhGeneric[T_sequence], False),
-        (MuhGeneric[list], MuhGeneric[T_sequence], True),
-        (MuhGeneric[list], MuhGeneric[Sequence], True),
-        (MuhGeneric[str], MuhGeneric[T_sequence], True),
-        (MuhGeneric[Sequence], MuhGeneric[list], False),
-        (MuhGeneric[T_sequence], MuhGeneric, True),
+        # ..................{ PEP (484|585) ~ generic        }..................
+        # PEP 484- or 585-compliant generic subclasses inheriting PEP 484- or
+        # 585-compliant type hints parametrized by one unconstrained type
+        # variables.
+        (Pep585SequenceT, Sequence[T], True),
+        (Pep585SequenceT, Sequence[int], False),
+        (Pep585SequenceT[int], Sequence[T], True),
+        (Pep585SequenceT[int], Sequence[T_sequence], False),
+        (Pep585SequenceT[list], Sequence[T_sequence], True),
+        (Pep585SequenceT[list], Sequence[Sequence], True),
+        (Pep585SequenceT[str], Sequence[T_sequence], True),
+        (Pep585SequenceT[Sequence], Sequence[list], False),
+        (Pep585SequenceT[T_sequence], Sequence[T], True),
 
-        #FIXME: Uncomment after resolving open issue #271, please.
-        # PEP 484-compliant generics parametrized by two type variables.
-        # (MuhGenericTwoIntInt, MuhGenericTwo[int, int], True),
-
-        # ..................{ PEP 484 ~ arg : mapping        }..................
+        # ..................{ PEP (484|585) ~ mapping        }..................
         # PEP 484-compliant mapping type hints.
         (dict, Dict, True),
         (Dict[str, int], Dict, True),
@@ -284,7 +327,7 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
             True,
         ),
 
-        # ..................{ PEP 484 ~ arg : sequence       }..................
+        # ..................{ PEP (484|585) ~ sequence       }..................
         # PEP 484-compliant sequence type hints.
         (List[int], List[int], True),
         (List[int], Sequence[int], True),
@@ -317,7 +360,7 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         # PEP 484-compliant nested sequence type hints.
         (List[int], Union[str, List[Union[int, str]]], True),
 
-        # ..................{ PEP 484 ~ arg : subclass       }..................
+        # ..................{ PEP (484|585) ~ subclass       }..................
         # PEP 484-compliant subclass type hints.
         (Type[int], Type[int], True),
         (Type[int], Type[str], False),
@@ -325,24 +368,17 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         (Type[MuhThing], Type[MuhSubThing], False),
         (MuhThing, Type[MuhThing], False),
 
-        # ..................{ PEP 484 ~ arg : union          }..................
-        # PEP 484-compliant unions.
-        (int, Union[int, str], True),
-        (Union[int, str], Union[list, int, str], True),
-        (Union[str, int], Union[int, str, list], True),  # order doesn't matter
-        (Union[str, list], Union[str, int], False),
-        (Union[int, str, list], list, False),
-        (Union[int, str, list], Union[int, str], False),
-        (int, Optional[int], True),
-        (Optional[int], int, False),
-        (list, Optional[Sequence], True),
-
         # ..................{ PEP 544                        }..................
         # PEP 544-compliant type hints.
         (MuhThing, MuhThingP, True),
         (MuhNutherThing, MuhThingP, False),
         (MuhThingP, MuhThing, False),
 
+        # ..................{ PEP 585                        }..................
+        # PEP 585-compliant type hints.
+        (tuple, Tuple, True),
+        (tuple[()], Tuple[()], True),
+
         # ..................{ PEP 586                        }..................
         # PEP 586-compliant type hints.
         (Literal[7], int, True),
@@ -357,22 +393,39 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         # ..................{ PEP 589                        }..................
         # PEP 589-compliant type hints.
         (MuhDict, dict, True),
+
+        # ..................{ PEP 593                        }..................
+        # PEP 593-compliant type hints.
+        (Annotated[int, "a note"], int, True),  # annotated is subtype of unannotated
+        (int, Annotated[int, "a note"], False),  # but not vice versa
+        (Annotated[list, True], Annotated[Sequence, True], True),
+        (Annotated[list, False], Annotated[Sequence, True], False),
+        (Annotated[list, 0, 0], Annotated[list, 0], False),  # must have same num args
+        (Annotated[List[int], "metadata"], List[int], True),
     ]
 
     # ..................{ LISTS ~ typing                     }..................
     # List of the unqualified basenames of all standard ABCs published by
-    # the standard "collections.abc" module, defined as...
-    COLLECTIONS_ABC_BASENAMES = [
-        # For the unqualified basename of each attribute defined by the standard
-        # "collections.abc" module...
-        COLLECTIONS_ABC_BASENAME
-        for COLLECTIONS_ABC_BASENAME in dir(collections.abc)
-        # If this basename is *NOT* prefixed by an underscore, this attribute is
-        # public and thus an actual ABC. In this case, include this ABC.
-        if not COLLECTIONS_ABC_BASENAME.startswith('_')
-        # Else, this is an unrelated private attribute. In this case, silently
-        # ignore this attribute and continue to the next.
-    ]
+    # the standard "collections.abc" module, initialized to the empty list.
+    COLLECTIONS_ABC_BASENAMES = []
+
+    # For the unqualified basename of each attribute and that attribute defined
+    # by the standard "collections.abc" submodule...
+    for collections_abc_basename, collections_abc in (
+        collections.abc.__dict__.items()):
+        # If this attribute is a public ABC, include this ABC, where public ABCs
+        # are detected as...
+        if (
+            # The unqualified basename of this attribute is not prefixed by an
+            # underscore (and is thus public) *AND*...
+            not collections_abc_basename.startswith('_') and
+            # This attribute is an ABC but *NOT* the semantically meaningless
+            # "abc.ABCMeta" superclass itself.
+            is_type_subclass_proper(collections_abc, ABCMeta)
+        ):
+            COLLECTIONS_ABC_BASENAMES.append(collections_abc_basename)
+        # Else, this is an unrelated attribute. In this case, silently ignore
+        # this attribute and continue to the next.
 
     # List of the unqualified basenames of all standard abstract base classes
     # (ABCs) supported by the standard "typing" module, defined as the
@@ -386,6 +439,7 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         # supported by the standard "typing" module.
         ['Deque']
     )
+    # print(f'TYPING_ABC_BASENAMES: {TYPING_ABC_BASENAMES}')
 
     # ..................{ HINTS ~ abcs                       }..................
     # For the unqualified basename of each standard ABCs supported by the
@@ -399,66 +453,37 @@ def door_cases_is_subhint() -> 'Iterable[Tuple[object, object, bool]]':
         # Type hint factory published by the "typing" module corresponding to
         # this ABC if any *OR* "None" otherwise (i.e., if "typing" publishes
         # *NO* such type hint factory).
-        TypingABC = getattr(typing, TYPING_ABC_BASENAME, None)
+        typing_abc = getattr(typing, TYPING_ABC_BASENAME, None)
 
         # If "typing" publishes *NO* such type hint factory, silently ignore
         # this ABC and continue to the next.
-        if TypingABC is None:
+        if typing_abc is None:
             continue
         # Else, "typing" publishes this type hint factory.
 
-        # Number of type variables parametrizing this ABC, defined as either...
-        TYPING_ABC_TYPEVARS_LEN = (
-            # If the active Python interpreter targets Python >= 3.9, a private
-            # instance variable of this type hint factory yielding this
-            # metadata. Under Python >= 3.9, unsubscripted type hint factories
-            # are *NOT* parametrized by type variables.
-            TypingABC._nparams
-            if IS_PYTHON_AT_LEAST_3_9 else
-            # Else, the active Python interpreter targets Python < 3.9. In this
-            # case, the number of type variables directly parametrizing this
-            # ABC.
-            len(get_hint_pep_typevars(TypingABC))
-        )
+        # Number of type variables parametrizing this ABC, defined as a private
+        # instance variable of this type hint factory yielding this metadata.
+        # Under Python >= 3.9, unsubscripted type hint factories are *NOT*
+        # parametrized by type variables.
+        typing_abc_typevars_len = typing_abc._nparams
 
         # If this ABC is parametrized by one or more type variables, exercise
         # that this ABC subscripted by one or more arbitrary concrete types is a
         # non-trivial subhint of this same ABC subscripted by one or more
         # arbitrary different ABCs of those concrete types.
-        if TYPING_ABC_TYPEVARS_LEN:
-            subhint =   TypingABC[(list,)     * TYPING_ABC_TYPEVARS_LEN]
-            superhint = TypingABC[(Sequence,) * TYPING_ABC_TYPEVARS_LEN]
+        if typing_abc_typevars_len:
+            subhint =   typing_abc[(list,)     * typing_abc_typevars_len]
+            superhint = typing_abc[(Sequence,) * typing_abc_typevars_len]
         # Else, this ABC is parametrized by *NO* type variables. In this case,
         # fallback to exercising that this ABC is a trivial subhint of itself.
         else:
-            subhint =   TypingABC
-            superhint = TypingABC
+            subhint =   typing_abc
+            superhint = typing_abc
 
         # Append a new hint subhint case exercising that this subhint is
         # actually a subhint of this superhint.
         HINT_SUBHINT_CASES.append((subhint, superhint, True))
 
-    # ..................{ HINTS ~ version                    }..................
-    # If the active Python interpreter targets Python >= 3.9 and thus supports
-    # both PEP 585 and 593...
-    if IS_PYTHON_AT_LEAST_3_9:
-        # Defer version-specific imports.
-        from beartype.typing import Annotated
-
-        # Append cases exercising version-specific relations.
-        HINT_SUBHINT_CASES.extend((
-            # PEP 585-compliant type hints.
-            (tuple, Tuple, True),
-            (tuple[()], Tuple[()], True),
-
-            # PEP 593-compliant type hints.
-            (Annotated[int, "a note"], int, True),  # annotated is subtype of unannotated
-            (int, Annotated[int, "a note"], False),  # but not vice versa
-            (Annotated[list, True], Annotated[Sequence, True], True),
-            (Annotated[list, False], Annotated[Sequence, True], False),
-            (Annotated[list, 0, 0], Annotated[list, 0], False),  # must have same num args
-            (Annotated[List[int], "metadata"], List[int], True),
-        ))
-
+    # ..................{ RETURN                             }..................
     # Return this mutable list coerced into an immutable tuple for safety.
     return tuple(HINT_SUBHINT_CASES)
