@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -16,6 +16,7 @@ This submodule unit tests the subset of the public API of the public
 # WARNING: To raise human-readable test errors, avoid importing from
 # package-specific submodules at module scope.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+from beartype_test._util.mark.pytmark import ignore_warnings
 
 # ....................{ TESTS ~ dunder ~ creation          }....................
 def test_door_typehint_new() -> None:
@@ -370,6 +371,9 @@ def test_door_typehint_len():
 #                 hint_pep_meta.is_ignorable)
 
 
+# Prevent pytest from capturing and displaying all expected non-fatal
+# beartype-specific warnings emitted by this test. Urgh!
+@ignore_warnings(DeprecationWarning)
 def test_door_typehint_is_ignorable(hints_pep_meta, hints_ignorable) -> None:
     '''
     Test the :meth:`beartype.door.TypeHint.is_ignorable` property.
@@ -387,9 +391,12 @@ def test_door_typehint_is_ignorable(hints_pep_meta, hints_ignorable) -> None:
     # Defer test-specific imports.
     from beartype.door import TypeHint
     from beartype.roar import BeartypeDoorException, BeartypeDoorNonpepException
-    from beartype.typing import TypeVar
-    from beartype._util.hint.utilhinttest import is_hint_ignorable
-    from beartype._util.hint.pep.proposal.pep484.utilpep484typevar import (
+    from beartype.typing import (
+        Any,
+        TypeVar,
+    )
+    from beartype._check.convert.convsanify import sanify_hint_child
+    from beartype._util.hint.pep.proposal.pep484.pep484typevar import (
         get_hint_pep484_typevar_bound_or_none)
     from contextlib import suppress
 
@@ -434,7 +441,7 @@ def test_door_typehint_is_ignorable(hints_pep_meta, hints_ignorable) -> None:
                 hint_typevar_bound is None or
                 # This type hint is constrained by one or more ignorable
                 # constraints.
-                is_hint_ignorable(hint_typevar_bound)
+                sanify_hint_child(hint_typevar_bound) is Any
             )
         # Else, this hint is *NOT* a type variable.
 
