@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -168,7 +168,7 @@ def test_door_infer_hint_numpy(
         IsAttr,
         IsEqual,
     )
-    from beartype._util.api.utilapityping import import_typing_attr_or_none
+    from beartype._util.api.standard.utiltyping import import_typing_attr_or_none
     from numpy import unsignedinteger
     from numpy.typing import NDArray
 
