@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 
@@ -13,7 +13,7 @@ child submodules of the test subpackage containing this :mod:`pytest` plugin).
 # ....................{ IMPORTS                            }....................
 # Import all subpackage-specific fixtures implicitly required by tests defined
 # by submodules of this subpackage.
-from beartype_test.a00_unit.data.api.data_apinumpy import numpy_arrays
+from beartype_test.a00_unit.data.api.external.data_apinumpy import numpy_arrays
 from beartype_test.a00_unit.data.hint.data_hint import (
     hints_meta,
     hints_ignorable,
