@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -29,7 +29,7 @@ def hints_nonpepbeartype_meta() -> 'List[HintNonpepMetadata]':
     # Defer test-specific imports.
     from beartype.plug import BeartypeHintable
     from beartype.vale import Is
-    from beartype._util.api.utilapityping import iter_typing_attrs
+    from beartype._util.api.standard.utiltyping import iter_typing_attrs
     from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
         HintNonpepMetadata,
         HintPithSatisfiedMetadata,
